@@ -1,7 +1,7 @@
 /*****************************************************************
  * drkonqi - The KDE Crash Handler
  *
- * $Id: main.cpp,v 1.25 2002/03/19 18:54:32 ossi Exp $
+ * $Id: main.cpp,v 1.27 2002/07/29 01:01:26 mhunter Exp $
  *
  * Copyright (C) 2000 Hans Petter Bieker <bieker@kde.org>
  *
@@ -45,13 +45,14 @@ static const char *description = I18N_NOOP( "KDE Crash Handler gives the user fe
 
 static const KCmdLineOptions options[] =
 {
-  {"signal <number>", I18N_NOOP("The signal number we caught."), 0},
-  {"appname <name>",  I18N_NOOP("Name of the program."), 0},
-  {"apppath <path>",  I18N_NOOP("Path to the executable."), 0},
-  {"appversion <version>", I18N_NOOP("The version of the program."), 0},
-  {"bugaddress <address>", I18N_NOOP("The bug address to use."), 0},
-  {"programname <name>", I18N_NOOP("Translated name of the program."), 0},
+  {"signal <number>", I18N_NOOP("The signal number that was caught"), 0},
+  {"appname <name>",  I18N_NOOP("Name of the program"), 0},
+  {"apppath <path>",  I18N_NOOP("Path to the executable"), 0},
+  {"appversion <version>", I18N_NOOP("The version of the program"), 0},
+  {"bugaddress <address>", I18N_NOOP("The bug address to use"), 0},
+  {"programname <name>", I18N_NOOP("Translated name of the program"), 0},
   {"pid <pid>", I18N_NOOP("The PID of the program"), 0},
+  {"startupid <id>", I18N_NOOP("Startup ID of the program"), 0},
   {"kdeinit", I18N_NOOP("The program was started by kdeinit"), 0},
   { 0, 0, 0 }
 };
