@@ -104,6 +104,7 @@ class KateFileSelector : public QWidget
     void btnFilterClick();
     void autoSync();
     void autoSync( Kate::Document * );
+	void initialDirChangeHack();
   protected:
     void focusInEvent( QFocusEvent * );
     void showEvent( QShowEvent * );
@@ -126,7 +127,7 @@ class KateFileSelector : public QWidget
     QString lastFilter;
     int autoSyncEvents; // enabled autosync events
     QString waitingUrl; // maybe display when we gets visible
-
+    QString waitingDir;
 };
 
 /*  TODO anders
