@@ -41,6 +41,9 @@
 #include <kstdaction.h>
 #include <kstandarddirs.h>
 #include <qfileinfo.h>
+
+#include <kio/netaccess.h>
+
 #include <qlayout.h>
 #include <qobjectlist.h>
 #include <qstringlist.h>
@@ -787,7 +790,7 @@ void KateViewManager::reopenDocuments(bool isRestore)
   {
     scfg->setGroup("open files");
     // try to focus the file that had focus at close down
-    QString curfile = scfg->readEntry("current file");
+    QString curfile = scfg->readPathEntry("current file");
 
     if (curfile.isEmpty()) {
         delete scfg;
@@ -806,9 +809,19 @@ void KateViewManager::reopenDocuments(bool isRestore)
 
     int i = 0;
     QString fn;
+    // check all remote files for existance in a syncrounous way
+    // so that the password dialog only appears ones for every remote source
     while (scfg->hasKey(QString("File%1").arg(i)))
     {
-      fn = scfg->readEntry( QString("File%1").arg( i ) );
+      fn = scfg->readPathEntry( QString("File%1").arg( i ) );
+      if ( !fn.isEmpty() && !KURL( fn ).isLocalFile() )
+          KIO::NetAccess::exists(KURL( fn ), true);
+      i++;
+    }    
+    i = 0;
+    while (scfg->hasKey(QString("File%1").arg(i)))
+    {
+      fn = scfg->readPathEntry( QString("File%1").arg( i ) );
       if ( !fn.isEmpty() ) {
         kdDebug(13001)<<"reopenDocuments(): opening file : "<<fn<<endl;
         scfg->setGroup( fn );
@@ -975,7 +988,7 @@ void KateViewManager::restoreSplitter( KSimpleConfig* config, QString group, QWi
        config->setGroup( (*it) );  // "viewspace<n>"
        while ( config->hasKey( file ) ) {     // FIXME FIXME
          Kate::View* v;
-         KURL url( config->readEntry( file ) );
+         KURL url( config->readPathEntry( file ) );
          if ( ! m_docManager->isOpen( url ) ) {
            openURL( url );
            v = activeView();
