@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgdefaults.h,v 1.8 2001/02/18 05:34:37 rahn Exp $
+ * $Id: bgdefaults.h,v 1.10 2001/10/17 20:50:38 lunakl Exp $
  *
  * This file is part of the KDE project, module kdesktop.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -19,6 +19,10 @@
 #define _defLimitCache true
 #define _defCacheSize 2048
 
+#define _defShm false
+// there are usually poor results with bpp<16 when tiling
+#define _defMinOptimizationDepth 1
+
 // Per desktop defaults
 // Before you change this get in touch with me (torsten@kde.org)
 // Thanks!!
