@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgrender.cc,v 1.30.2.1 2003/01/07 14:37:56 lunakl Exp $
+ * $Id: bgrender.cc,v 1.30.2.2 2003/04/29 22:30:32 waba Exp $
  *
  * This file is part of the KDE project, module kdesktop.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -274,6 +274,7 @@ int KBackgroundRenderer::doWallpaper(bool quit)
 
     QImage wp;
     if (wpmode != NoWallpaper) {
+wp_load:
 	if (currentWallpaper().isEmpty()) {
 	    wpmode = NoWallpaper;
 	    goto wp_out;
@@ -286,6 +287,8 @@ int KBackgroundRenderer::doWallpaper(bool quit)
 
 	wp.load(file);
 	if (wp.isNull()) {
+            if (discardCurrentWallpaper())
+               goto wp_load;
 	    wpmode = NoWallpaper;
 	    goto wp_out;
 	}
