@@ -32,6 +32,7 @@
 
 #include <kdebug.h>
 #include <klocale.h>
+#include <kglobal.h>
 #include <kprocess.h>
 #include <kmessagebox.h>
 
@@ -62,7 +63,7 @@ Dtime::Dtime(QWidget * parent, const char *name)
   l1->addWidget( year, 0, 2 );
   QWhatsThis::add( year, i18n("Here you can change the system date's year.") );
 
-  cal = new KDateTable( this );
+  cal = new KDateTable( dateBox );
   l1->addMultiCellWidget( cal, 1, 1, 0, 2 );
   QWhatsThis::add( cal, i18n("Here you can change the system date's day of the month.") );
 
@@ -86,53 +87,56 @@ Dtime::Dtime(QWidget * parent, const char *name)
 
 //  v3->setColStretch( 0, 1 );
 
+  QSpacerItem *spacer1 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+  v3->addMultiCell(spacer1, 0, 1, 1, 1);
+
   hour = new QLineEdit( timeBox, "LineEdit_1" );
   connect( hour, SIGNAL(textChanged(const QString&)), SLOT(set_time()) );
   hour->setMaxLength( 2 );
   hour->setFrame( TRUE );
   hour->setValidator(new KStrictIntValidator(0, 23, hour));
-  v3->addMultiCellWidget(hour, 0, 1, isRTL ? 5 : 1, isRTL ? 5 : 1 );
+  v3->addMultiCellWidget(hour, 0, 1, isRTL ? 6 : 2, isRTL ? 6 : 2 );
 
   QLabel *dots1 = new QLabel(":", timeBox);
   dots1->setMinimumWidth( 7 );
   dots1->setAlignment( QLabel::AlignCenter );
-  v3->addMultiCellWidget(dots1, 0, 1, 2, 2 );
+  v3->addMultiCellWidget(dots1, 0, 1, 3, 3 );
 
   minute = new QLineEdit( timeBox, "LineEdit_2" );
   connect( minute, SIGNAL(textChanged(const QString&)), SLOT(set_time()) );
   minute->setMaxLength( 2 );
   minute->setFrame( TRUE );
   minute->setValidator(new KStrictIntValidator(0, 59, minute));
-  v3->addMultiCellWidget(minute, 0, 1, 3, 3 );
+  v3->addMultiCellWidget(minute, 0, 1, 4, 4 );
 
   QLabel *dots2 = new QLabel(":", timeBox);
   dots2->setMinimumWidth( 7 );
   dots2->setAlignment( QLabel::AlignCenter );
-  v3->addMultiCellWidget(dots2, 0, 1, 4, 4 );
+  v3->addMultiCellWidget(dots2, 0, 1, 5, 5 );
 
   second = new QLineEdit( timeBox, "LineEdit_3" );
   connect( second, SIGNAL(textChanged(const QString&)), SLOT(set_time()) );
   second->setMaxLength( 2 );
   second->setFrame( TRUE );
   second->setValidator(new KStrictIntValidator(0, 59, second));
-  v3->addMultiCellWidget(second, 0, 1, isRTL? 1 : 5, isRTL ? 1 : 5 );
+  v3->addMultiCellWidget(second, 0, 1, isRTL ? 2 : 6, isRTL ? 2 : 6 );
 
   int w = 2*hour->fontMetrics().width("00");
   hour->setMaximumWidth(w);
   minute->setMaximumWidth(w);
   second->setMaximumWidth(w);
 
-  v3->addColSpacing( 6, 5 );
+  v3->addColSpacing(7, 7);
 
   QPushButton* plusPB = new QPushButton( "+", timeBox, "plusPB" );
   connect( plusPB, SIGNAL(pressed()), this, SLOT(inc_time()) );
   plusPB->setAutoRepeat( TRUE );
-  v3->addWidget(plusPB, 0, 7 );
+  v3->addWidget(plusPB, 0, 8 );
 
   QPushButton* minusPB = new QPushButton( "-", timeBox, "minusPB" );
   connect( minusPB, SIGNAL(pressed()), this, SLOT(dec_time()) );
   minusPB->setAutoRepeat( TRUE );
-  v3->addWidget(minusPB, 1, 7 );
+  v3->addWidget(minusPB, 1, 8 );
 
   QString wtstr = i18n("Here you can change the system time. Click into the"
     " hours, minutes or seconds field to change the relevant value, either"
@@ -143,6 +147,9 @@ Dtime::Dtime(QWidget * parent, const char *name)
   QWhatsThis::add( minute, wtstr );
   QWhatsThis::add( second, wtstr );
 
+  QSpacerItem *spacer3 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+  v3->addMultiCell(spacer3, 0, 1, 9, 9);
+
   plusPB->setFixedSize( 20, hour->height()/2 );
   minusPB->setFixedSize( 20, hour->height()/2 );
 
@@ -158,18 +165,8 @@ Dtime::Dtime(QWidget * parent, const char *name)
   // End Dialog
   // *************************************************************
 
-  month->insertItem( i18n("January") );
-  month->insertItem( i18n("February") );
-  month->insertItem( i18n("March") );
-  month->insertItem( i18n("April") );
-  month->insertItem( i18n("May") );
-  month->insertItem( i18n("June") );
-  month->insertItem( i18n("July") );
-  month->insertItem( i18n("August") );
-  month->insertItem( i18n("September") );
-  month->insertItem( i18n("October") );
-  month->insertItem( i18n("November") );
-  month->insertItem( i18n("December") );
+  for (int i=1; i<13; i++)
+      month->insertItem(KGlobal::locale()->monthName(i, false /*short*/));
 
   connect( cal, SIGNAL(dateChanged(QDate)), SLOT(changeDate(QDate)));
 
@@ -246,19 +243,31 @@ void Dtime::save()
 {
   KProcess c_proc;
 
+// BSD systems reverse year compared to Susv3
+#if defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__NetBSD__)
+  BufS.sprintf("%04d%02d%02d%02d%02d.%02d",
+               date.year(),
+               date.month(), date.day(),
+               hour->text().toInt(), minute->text().toInt(),
+               second->text().toInt());
+#else
   BufS.sprintf("%02d%02d%02d%02d%04d.%02d",
                date.month(), date.day(),
                hour->text().toInt(), minute->text().toInt(),
                date.year(), second->text().toInt());
+#endif
 
   kdDebug() << "Set date " << BufS << endl;
 
   c_proc.setExecutable( "date" );
   c_proc << BufS;
   c_proc.start( KProcess::Block );
-
-  if ( c_proc.exitStatus() != 0 ) 
-	{
+  int result = c_proc.exitStatus();
+  if (result != 0
+#if defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__NetBSD__)
+  	&& result != 2	// can only set local date, which is okay
+#endif
+    ) {
     KMessageBox::error( this, i18n("Can not set date."));
     return;
   }
@@ -351,8 +360,10 @@ void Kclock::paintEvent( QPaintEvent * )
   QPointArray pts;
   QPoint cp = rect().center();
   int d = QMIN(width(),height());
-  paint.setPen( gray );
-  paint.setBrush( gray );
+  QColor hands =  colorGroup().dark();
+  QColor shadow =  colorGroup().text();
+  paint.setPen( shadow );
+  paint.setBrush( shadow );
   paint.setViewport(4,4,width(),height());
 
   for ( int c=0 ; c < 2 ; c++ )
@@ -395,8 +406,8 @@ void Kclock::paintEvent( QPaintEvent * )
           matrix.rotate( 6 );
         }
 
-      paint.setPen( black );
-      paint.setBrush( black );
+      paint.setPen( hands );
+      paint.setBrush( hands );
       paint.setViewport(0,0,width(),height());
     }
   paint.end();
