@@ -23,6 +23,7 @@
 #define tzone_included
 
 class QComboBox;
+class QStringList;
 
 class Tzone : public QWidget
 {
@@ -42,9 +43,10 @@ protected slots:
 
 private:
   void  fillTimeZones();
-  QString getCurrentZone() const;
+  QString currentZone() const;
 
   QComboBox       *tzonelist;
+  QStringList     tzonenames;
 	QLabel					*currentzonetitle;
 	QLabel          *currentzone;
   QString         BufS;
