@@ -289,7 +289,7 @@ void KColorScheme::load()
     readScheme(0);
 
     cs->drawSampleWidgets();
-    slotWidgetColor(0);
+    slotWidgetColor(wcCombo->currentItem());
     sb->blockSignals(true);
     sb->setValue(cs->contrast);
     sb->blockSignals(false);
@@ -402,7 +402,7 @@ void KColorScheme::defaults()
     sList->setCurrentItem(1);
 
     cs->drawSampleWidgets();
-    slotWidgetColor(0);
+    slotWidgetColor(wcCombo->currentItem());
     sb->blockSignals(true);
     sb->setValue(cs->contrast);
     sb->blockSignals(false);
@@ -494,6 +494,11 @@ void KColorScheme::slotRemove()
 
     sList->removeItem(ind);
     mSchemeList->remove(entry);
+
+    ind = sList->currentItem();
+    entry = mSchemeList->at(ind-nSysSchemes);
+    if (!entry) return;
+    removeBt->setEnabled(entry ? entry->local : false);
 }
 
 
@@ -685,8 +690,10 @@ void KColorScheme::slotSelectColor(const QColor &col)
 
 void KColorScheme::slotWidgetColor(int indx)
 {
+    if (indx < 0)
+        indx = 0;
     if (wcCombo->currentItem() != indx)
-    wcCombo->setCurrentItem( indx );
+        wcCombo->setCurrentItem( indx );
 
     QColor col = color(indx);
     colorButton->setColor( col );
@@ -697,7 +704,7 @@ void KColorScheme::slotWidgetColor(int indx)
 void KColorScheme::slotColorForWidget(int indx, const QColor& col)
 {
     if (wcCombo->currentItem() != indx)
-    wcCombo->setCurrentItem( indx );
+        wcCombo->setCurrentItem( indx );
 
     slotSelectColor(col);
 }
@@ -891,7 +898,7 @@ void KColorScheme::slotPreviewScheme(int indx)
     sb->blockSignals(true);
     sb->setValue(cs->contrast);
     sb->blockSignals(false);
-    slotWidgetColor(0);
+    slotWidgetColor(wcCombo->currentItem());
     if (indx < nSysSchemes)
        removeBt->setEnabled(false);
     else
