@@ -849,7 +849,7 @@ void KCryptoConfig::load()
   config->setGroup("Warnings");
   mWarnOnEnter->setChecked(config->readBoolEntry("OnEnter", false));
   mWarnOnLeave->setChecked(config->readBoolEntry("OnLeave", true));
-  mWarnOnUnencrypted->setChecked(config->readBoolEntry("OnUnencrypted", false));
+  mWarnOnUnencrypted->setChecked(config->readBoolEntry("OnUnencrypted", true));
 
 #if 0 // NOT IMPLEMENTED IN KDE 2.0
   mWarnOnMixed->setChecked(config->readBoolEntry("OnMixed", true));
@@ -869,12 +869,12 @@ void KCryptoConfig::load()
     mUseEFile->setChecked(true);
     slotUseEFile();
   }
-  mEGDPath->setURL(config->readEntry("EGDPath", QString::null));
+  mEGDPath->setURL(config->readPathEntry("EGDPath"));
 
 
 #ifdef HAVE_SSL
   config->setGroup("OpenSSL");
-  oPath->setURL(config->readEntry("Path", QString::null));
+  oPath->setURL(config->readPathEntry("Path"));
 #endif
 
   config->setGroup("SSLv2");
@@ -2308,9 +2308,13 @@ SSL_METHOD *meth;
   for (i=0; ; i++) {
     int j, k;
     SSL_CIPHER *sc;
-    QString cname;
     sc = (meth->get_cipher)(i);
-    if (!sc) break;
+    if (!sc)
+      break;
+    // Leak of sc*?
+    if (QString(sc->name).contains("ADH-")) {
+      continue;
+    }
     k = SSL_CIPHER_get_bits(sc, &j);
 
     item = new CipherItem( SSLv2Box, sc->name, k, j, this );
@@ -2331,9 +2335,13 @@ SSL_METHOD *meth;
   for (i=0; ; i++) {
     int j, k;
     SSL_CIPHER *sc;
-    QString cname;
     sc = (meth->get_cipher)(i);
-    if (!sc) break;
+    if (!sc)
+      break;
+    // Leak of sc*?
+    if (QString(sc->name).contains("ADH-")) {
+      continue;
+    }
     k = SSL_CIPHER_get_bits(sc, &j);
 
     item = new CipherItem( SSLv3Box, sc->name, k, j, this );
