@@ -1,4 +1,3 @@
-#include <iostream.h>
 
 
 #include <qlayout.h>
@@ -226,8 +225,8 @@ void CSSConfig::defaults()
 
 QString CSSConfig::quickHelp() const
 {
-  return i18n("This module allows you to apply your own color"
-              " and font settings to konqueror by using"
+  return i18n("<h1>Konqueror Stylesheets</h1> This module allows you to apply your own color"
+              " and font settings to Konqueror by using"
               " stylesheets (CSS). You can either specify"
               " options or apply your own self-written"
               " stylesheet by pointing to its location.<br>"
@@ -387,11 +386,7 @@ void CSSConfig::preview()
 
   // Show the preview
   PreviewDialog *dlg = new PreviewDialog(this, 0, true);
-  QColorGroup clgrp = dlg->preview->colorGroup();
-  clgrp.setColor(QColorGroup::Base, back);
-#if QT_VERSION < 300
-  dlg->preview->setPaperColorGroup(clgrp);
-#endif
+  dlg->preview->setPaper(back);
   dlg->preview->viewport()->setFont(QFont("helvetica", bfs));
 
   dlg->exec();
