@@ -18,13 +18,13 @@
 
 */
 
-/* $Id: kuriikwsfilter.h,v 1.9 2001/04/16 16:33:58 adawit Exp $ */
+/* $Id: kuriikwsfilter.h,v 1.11 2001/10/27 16:32:53 hausmann Exp $ */
 
 #ifndef __KURIIKWSFILTER_H__
 #define __KURIIKWSFILTER_H__
 
 #include <dcopobject.h>
-#include <klibloader.h>
+#include <kgenericfactory.h>
 
 #include <kurifilter.h>
 
@@ -33,8 +33,10 @@ class KInstance;
 class KURIIKWSFilter : public KURIFilterPlugin, public DCOPObject
 {
     K_DCOP
+    Q_OBJECT
 public:
-    KURIIKWSFilter(QObject *parent = 0, const char *name = 0);
+    KURIIKWSFilter(QObject *parent = 0, const char *name = 0,
+	           const QStringList &args = QStringList() );
     ~KURIIKWSFilter();
 
     virtual bool filterURI( KURIFilterData& ) const;
@@ -43,21 +45,5 @@ k_dcop:
     virtual void configure();
 };
 
-class KURIIKWSFilterFactory : public KLibFactory
-{
-    Q_OBJECT
-public:
-    KURIIKWSFilterFactory( QObject *parent = 0, const char *name = 0 );
-    ~KURIIKWSFilterFactory();
-
-    virtual QObject *createObject( QObject *parent = 0, const char *name = 0,
-                                   const char* classname = "QObject",
-                                   const QStringList &args = QStringList() );
-    static KInstance *instance();
-
-private:
-    static KInstance *s_instance;
-};
-
 #endif
 
