@@ -31,18 +31,15 @@
 
 #define searcher KURISearchFilterEngine::self()
 
-KInstance *KURISearchFilterFactory::s_instance = 0L;
-
-KURISearchFilter::KURISearchFilter(QObject *parent, const char *name)
+KURISearchFilter::KURISearchFilter(QObject *parent, const char *name,
+	                           const QStringList & /*args*/)
                  :KURIFilterPlugin(parent, name ? name : "kurisearchfilter", 1.0),
                   DCOPObject("KURISearchFilterIface")
 {
-  KURISearchFilterEngine::incRef();
 }
 
 KURISearchFilter::~KURISearchFilter()
 {
-  KURISearchFilterEngine::decRef();
 }
 
 void KURISearchFilter::configure()
@@ -68,7 +65,7 @@ bool KURISearchFilter::filterURI( KURIFilterData &data ) const
 
 KCModule *KURISearchFilter::configModule(QWidget *parent, const char *name) const
 {
-    return new InternetKeywordsOptions(parent, name);
+    return new InternetKeywordsOptions( KURISeachFilterFactory::instance(), parent, name);
 }
 
 QString KURISearchFilter::configName() const
@@ -76,37 +73,7 @@ QString KURISearchFilter::configName() const
     return i18n("&Keywords");
 }
 
-
-KURISearchFilterFactory::KURISearchFilterFactory(QObject *parent, const char *name) : KLibFactory(parent, name)
-{
-    KURISearchFilterEngine::incRef();
-    s_instance = new KInstance(searcher->name());
-}
-
-KURISearchFilterFactory::~KURISearchFilterFactory()
-{
-    KURISearchFilterEngine::decRef();
-    delete s_instance;
-}
-
-QObject *KURISearchFilterFactory::create( QObject *parent, const char *name, const char*, const QStringList & )
-{
-    QObject *obj = new KURISearchFilter( parent, name );
-    emit objectCreated( obj );
-    return obj;
-}
-
-KInstance *KURISearchFilterFactory::instance()
-{
-    return s_instance;
-}
-
-extern "C"
-{
-  void *init_libkurisearchfilter()
-  {
-    return new KURISearchFilterFactory;
-  }
-}
+K_EXPORT_COMPONENT_FACTORY( libkurisearchfilter, 
+	                    KURISeachFilterFactory( "kuriikwsfilter" ) );
 
 #include "kurisearchfilter.moc"
