@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: email.cpp,v 1.71 2002/02/19 17:27:51 coolo Exp $
+ * $Id: email.cpp,v 1.75.2.1 2002/12/26 13:37:01 pfeiffer Exp $
  *
  * This file is part of the KDE project, module kcontrol.
  * Copyright (C) 1999-2001 by Alex Zepeda and Daniel Molkentin
@@ -38,22 +38,24 @@
 #include <unistd.h>
 
 #include <qcheckbox.h>
+#include <qfile.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
-#include <qtoolbutton.h>
 
 #include <kdebug.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kdialog.h>
 #include <klocale.h>
-#include <kopenwith.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <kemailsettings.h>
 #include <kgenericfactory.h>
 #include <kaboutdata.h>
+#include <kapplication.h>
+#include <kconfig.h>
+#include <dcopclient.h>
 
 #include "email.h"
 
@@ -74,10 +76,7 @@ topKCMEmail::topKCMEmail (QWidget *parent,  const char *name, const QStringList
 	connect(m_email->txtOrganization, SIGNAL(textChanged(const QString&)), SLOT(configChanged()) );
 	connect(m_email->txtEMailAddr, SIGNAL(textChanged(const QString&)), SLOT(configChanged()) );
 	connect(m_email->txtReplyTo, SIGNAL(textChanged(const QString&)), SLOT(configChanged()) );
-	connect(m_email->txtEMailClient, SIGNAL(textChanged(const QString&)), SLOT(configChanged()) );
-	connect(m_email->chkRunTerminal, SIGNAL(clicked()), SLOT(configChanged()) );
-	connect(m_email->btnSelectEmail, SIGNAL(clicked()), SLOT(selectEmailClient()) );
-
+	connect(m_email->txtSMTP, SIGNAL(textChanged(const QString&)), SLOT(configChanged()) );
 
 	pSettings = new KEMailSettings();
 	m_email->lblCurrentProfile->hide();
@@ -114,6 +113,20 @@ topKCMEmail::topKCMEmail (QWidget *parent,  const char *name, const QStringList
 	"LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY\n"
 	"OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF\n"
 	"SUCH DAMAGE.");
+
+	if ( m_email->txtFullName->text().isEmpty() &&
+	     m_email->txtOrganization->text().isEmpty() &&
+	     m_email->txtEMailAddr->text().isEmpty() &&
+	     m_email->txtReplyTo->text().isEmpty() &&
+	     m_email->txtSMTP->text().isEmpty() )
+	{
+		KConfigGroup config( EMailFactory::instance()->config(), 
+				     "General" );
+		if ( config.readBoolEntry( "FirstStart", true ) )
+			defaults();
+	}
+
+	m_email->txtFullName->setFocus();
 }
 
 topKCMEmail::~topKCMEmail()
@@ -157,10 +170,7 @@ void topKCMEmail::load(const QString &s)
 		m_email->txtReplyTo->setText(pSettings->getSetting(KEMailSettings::ReplyToAddress));
 		m_email->txtOrganization->setText(pSettings->getSetting(KEMailSettings::Organization));
 		m_email->txtFullName->setText(pSettings->getSetting(KEMailSettings::RealName));
-
-		m_email->txtEMailClient->setText(pSettings->getSetting(KEMailSettings::ClientProgram));
-		m_email->chkRunTerminal->setChecked((pSettings->getSetting(KEMailSettings::ClientTerminal) == "true"));
-
+		m_email->txtSMTP->setText(pSettings->getSetting(KEMailSettings::OutServer));
 		configChanged(false);
 	}
 
@@ -172,9 +182,7 @@ void topKCMEmail::clearData()
 	m_email->txtReplyTo->setText(QString::null);
 	m_email->txtOrganization->setText(QString::null);
 	m_email->txtFullName->setText(QString::null);
-
-	m_email->txtEMailClient->setText(QString::null);
-	m_email->chkRunTerminal->setChecked(false);
+	m_email->txtSMTP->setText(QString::null);
 
 	configChanged(false);
 }
@@ -248,16 +256,19 @@ void topKCMEmail::save()
 	pSettings->setSetting(KEMailSettings::EmailAddress, m_email->txtEMailAddr->text());
 	pSettings->setSetting(KEMailSettings::Organization, m_email->txtOrganization->text());
 	pSettings->setSetting(KEMailSettings::ReplyToAddress, m_email->txtReplyTo->text());
-
-	pSettings->setSetting(KEMailSettings::ClientProgram, m_email->txtEMailClient->text());
-	pSettings->setSetting(KEMailSettings::ClientTerminal, (m_email->chkRunTerminal->isChecked()) ? "true" : "false");
+	pSettings->setSetting(KEMailSettings::OutServer, m_email->txtSMTP->text());
 
 	// insure proper permissions -- contains sensitive data
 	QString cfgName(KGlobal::dirs()->findResource("config", "emaildefaults"));
 	if (!cfgName.isEmpty())
 		::chmod(QFile::encodeName(cfgName), 0600);
 
+	KConfigGroup config( EMailFactory::instance()->config(), "General" );
+	config.writeEntry( "FirstStart", false );
+
 	configChanged(false);
+
+	kapp->dcopClient()->emitDCOPSignal("KDE_emailSettingsChanged()", QByteArray());
 }
 
 void topKCMEmail::defaults()
@@ -271,21 +282,19 @@ void topKCMEmail::defaults()
 	m_email->txtFullName->setText(QString::fromLocal8Bit(p->pw_gecos));
         m_email->txtOrganization->setText(QString::null);
         m_email->txtReplyTo->setText(QString::null);
+        m_email->txtSMTP->setText(QString::null);
 
 	QString tmp = QString::fromLocal8Bit(p->pw_name);
 	tmp += "@"; tmp += hostname;
 
 	m_email->txtEMailAddr->setText(tmp);
 
-	m_email->txtEMailClient->setText("kmail");
-	m_email->chkRunTerminal->setChecked(false);
-
 	configChanged();
 }
 
 QString topKCMEmail::quickHelp() const
 {
-	return i18n("<h1>email</h1> This module allows you to enter basic email"
+	return i18n("<h1>Email</h1> This module allows you to enter basic email"
 	            " information for the current user. The information here is used,"
 	            " among other things, for sending bug reports to the KDE developers"
 	            " when you use the bug report dialog.<p>"
@@ -293,23 +302,7 @@ QString topKCMEmail::quickHelp() const
 	            " features, but they provide their own configuration facilities.");
 }
 
-void topKCMEmail::selectEmailClient()
-{
-	KURL::List urlList;
-	KOpenWithDlg dlg(urlList, i18n("Preferred Email Client"), QString::null, this);
-	if (dlg.exec() != QDialog::Accepted) return;
-	QString client = dlg.text();
 
-/*	QFileInfo *clientInfo = new QFileInfo(client);
-	if (clientInfo->exists() && clientInfo->isExecutable() && clientInfo->filePath().contains(' ') == 0) */
-	bool b = client.left(11) == "konsole -e ";
-	if (b) client = client.mid(11);
-	if (!client.isEmpty())
-	{
-		m_email->chkRunTerminal->setChecked(b);
-		m_email->txtEMailClient->setText(client);
-	}
-}
 
 void topKCMEmail::profileChanged(const QString &s)
 {
