@@ -21,6 +21,7 @@
 #include "filetypedetails.h"
 #include "filegroupdetails.h"
 #include "filetypesview.h"
+#include <ksycoca.h>
 
 FileTypesView::FileTypesView(QWidget *p, const char *name)
   : KCModule(p, name)
@@ -110,8 +111,9 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
 
   m_widgetStack->raiseWidget( m_emptyWidget );
 
-  qApp->processEvents(); // let's show up
   QTimer::singleShot( 0, this, SLOT( init() ) ); // this takes some time
+
+  connect( KSycoca::self(), SIGNAL( databaseChanged() ), SLOT( slotDatabaseChanged() ) );
 }
 
 FileTypesView::~FileTypesView()
@@ -126,14 +128,15 @@ void FileTypesView::setDirty(bool state)
 
 void FileTypesView::init()
 {
+  show();
   setEnabled( false );
-  setCursor( KCursor::waitCursor() );
 
+  setCursor( KCursor::waitCursor() );
   readFileTypes();
+  unsetCursor();
 
   setDirty(false);
   setEnabled( true );
-  unsetCursor();
 }
 
 // only call this method once on startup, then never again! Otherwise, newly
@@ -164,6 +167,7 @@ void FileTypesView::readFileTypes()
 	TypesListItem *item = new TypesListItem(groupItem, (*it2));
 	m_itemList.append( item );
     }
+	updateDisplay(0L);
 }
 
 void FileTypesView::slotFilter(const QString & patternFilter)
@@ -309,7 +313,7 @@ void FileTypesView::updateDisplay(QListViewItem *item)
     setDirty(false);
 }
 
-bool FileTypesView::sync()
+bool FileTypesView::sync( QValueList<TypesListItem *>& itemsModified )
 {
   bool didIt = false;
   // first, remove those items which we are asked to remove.
@@ -330,14 +334,28 @@ bool FileTypesView::sync()
   }
 
   // now go through all entries and sync those which are dirty.
-  QListViewItemIterator it2(typesLV);
-  for (; it2.current(); ++it2) {
-    TypesListItem *tli = (TypesListItem *) it2.current();
+  // don't use typesLV, it may be filtered
+  QMapIterator<QString,TypesListItem*> it1 = m_majorMap.begin();
+  while ( it1 != m_majorMap.end() ) {
+    TypesListItem *tli = *it1;
     if (tli->isDirty()) {
       kdDebug() << "Entry " << tli->name() << " is dirty. Saving." << endl;
       tli->sync();
+      itemsModified.append( tli );
       didIt = true;
     }
+    ++it1;
+  }
+  QPtrListIterator<TypesListItem> it2( m_itemList );
+  while ( it2.current() ) {
+    TypesListItem *tli = *it2;
+    if (tli->isDirty()) {
+      kdDebug() << "Entry " << tli->name() << " is dirty. Saving." << endl;
+      tli->sync();
+      itemsModified.append( tli );
+      didIt = true;
+    }
+    ++it2;
   }
   setDirty(false);
   return didIt;
@@ -350,12 +368,34 @@ void FileTypesView::load()
 
 void FileTypesView::save()
 {
-  // only send dcop signal if sync() was necessary.
-  if (sync()) {
+  m_itemsModified.clear();
+  if (sync(m_itemsModified)) {
+    // only send dcop signal if sync() was necessary.
     DCOPClient *dcc = kapp->dcopClient();
     if ( !dcc->isAttached() )
 	dcc->attach();
     dcc->send("kded", "kbuildsycoca", "recreate()", QByteArray());
+    // send() returns immediately. This means we don't have to block the UI
+    // while kbuildsycoca runs, unlike KOpenWithDlg.
+    // We'll update the mimetype object when databaseChanged() is emitted.
+  }
+}
+
+void FileTypesView::slotDatabaseChanged()
+{
+  if ( KSycoca::self()->isChanged( "mime" ) )
+  {
+    // ksycoca has new KMimeTypes objects for us, make sure to update
+    // our 'copies' to be in sync with it. Not important for OK, but
+    // important for Apply (how to differenciate those 2?).
+    // See BR 35071.
+    QValueList<TypesListItem *>::Iterator it = m_itemsModified.begin();
+    for( ; it != m_itemsModified.end(); ++it ) {
+        QString name = (*it)->name();
+        if ( removedList.find( name ) == removedList.end() ) // if not deleted meanwhile
+            (*it)->refresh();
+    }
+    m_itemsModified.clear();
   }
 }
 
