@@ -9,6 +9,7 @@
 #include <qtimer.h>
 
 #include <kcmodule.h>
+#include <kaboutdata.h>
 #include <config.h>
 
 #ifdef HAVE_LONG_LONG
@@ -30,6 +31,9 @@ class KMemoryWidget:public KCModule {
     KMemoryWidget(QWidget * parent, const char *name = 0);
     ~KMemoryWidget();
 
+    QString quickHelp() const;
+    const KAboutData* aboutData() const;
+
   private:
     QString Not_Available_Text;
     QTimer *timer;
@@ -49,12 +53,12 @@ class KMemoryWidget:public KCModule {
 
     void update();
 
-    bool KMemoryWidget::Display_Graph(int widgetindex,
-				      int count,
-				      t_memsize total,
-				      t_memsize *used, 
-				      QColor *color,
-				      QString *text);
+    bool Display_Graph(int widgetindex,
+		      int count,
+		      t_memsize total,
+		      t_memsize *used, 
+		      QColor *color,
+		      QString *text);
     public slots:
     void update_Values();
 };
