@@ -25,6 +25,7 @@
 #define kcmioslaveinfo_h_included
 
 #include <kcmodule.h>
+#include <kaboutdata.h>
 
 #include <qstring.h>
 #include <ktextbrowser.h>
@@ -49,17 +50,20 @@ public:
     void defaults();
     int buttons();
     QString quickHelp() const;
+    const KAboutData* aboutData() const;
 
 protected:
     KListBox *m_ioslavesLb;
     KTextBrowser *m_info;
     QCString helpData;
+    KIO::Job *m_tfj;
 
 protected slots:
 
     void showInfo(const QString& protocol);
     void showInfo(QListBoxItem *item);
     void slaveHelp( KIO::Job *, const QByteArray &data);
+    void slotResult( KIO::Job * );
 
 public slots:
     void configChanged();
