@@ -47,6 +47,14 @@ const char * intro_text = I18N_NOOP("Welcome to the \"KDE Control Center\", "
                                 "Select an item from the index on the left "
                                 "to load a configuration module.");
 
+const char * kcc_infotext = I18N_NOOP("KDE Info Center");
+
+const char * title_infotext = I18N_NOOP("");
+
+const char * intro_infotext = I18N_NOOP("Welcome to the \"KDE Info Center\", "
+                                "a central place to find information about your "
+                                "computer system.");
+
 const char * use_text = I18N_NOOP("Click on the \"<b>Help</b>\" tab on the left to view help "
                         "for the active "
                         "control module. Use the \"<b>Search</b>\" tab if you are unsure "
@@ -71,11 +79,12 @@ QPixmap *AboutWidget::_part2 = 0L;
 QPixmap *AboutWidget::_part3 = 0L;
 KPixmap *AboutWidget::_part3Effect = 0L;
 
-AboutWidget::AboutWidget(QWidget *parent , const char *name, QListViewItem* category)
+AboutWidget::AboutWidget(QWidget *parent , const char *name, QListViewItem* category, const QString &caption)
    : QWidget(parent, name),
       _moduleList(false),
       _category(category),
-      _activeLink(0)
+      _activeLink(0),
+      _caption(caption)
 {
     if (_category)
       _moduleList = true;
@@ -106,8 +115,9 @@ AboutWidget::AboutWidget(QWidget *parent , const char *name, QListViewItem* cate
     QWhatsThis::add(this, i18n(intro_text));
 }
 
-void AboutWidget::setCategory( QListViewItem* category )
+void AboutWidget::setCategory( QListViewItem* category, const QString &caption )
 {
+  _caption = caption;
   _category = category;
   _activeLink = 0;
   if ( _category )
@@ -147,7 +157,7 @@ void AboutWidget::freePixmaps()
   _part1 = 0L;
   _part2 = 0L;
   _part3 = 0L;
-  _part3 = 0L;
+  _part3Effect = 0L;
 }
 
 void AboutWidget::paintEvent(QPaintEvent* e)
@@ -198,23 +208,38 @@ void AboutWidget::updatePixmap()
     QFont f2 = f1;
     QFont f3 = QFont(KGlobalSettings::generalFont().family(), 28, QFont::Bold, true);
 
+    QString title, intro, caption;
+    if (KCGlobal::isInfoCenter())
+    {
+       title = i18n(title_infotext);
+       intro = i18n(intro_infotext);
+       caption = i18n(kcc_infotext);
+    }
+    else
+    {
+       title = i18n(title_text);
+       intro = i18n(intro_text);
+       caption = i18n(kcc_text);
+    }
+
     //draw the caption text
     p.setFont(f3);
     p.setPen(gray);
-    p.drawText(220, 60, i18n(kcc_text));
+    p.drawText(220, 60, caption);
     p.setPen(black);
-    p.drawText(217, 57, i18n(kcc_text));
+    p.drawText(217, 57, caption);
     p.setFont(f1);
 
-    int hAlign = QApplication::reverseLayout() ? AlignRight : AlignLeft;
+    const int hAlign = QApplication::reverseLayout() ? AlignRight : AlignLeft;
+    
     
     // draw title text
     p.setPen(white);
-    p.drawText(150, 84, width() - 160, 108 - 84, hAlign | AlignVCenter, i18n(title_text));
+    p.drawText(150, 84, width() - 160, 108 - 84, hAlign | AlignVCenter, title);
 
     // draw intro text
     p.setPen(black);
-    p.drawText(28, 128, width() - 38, 184 - 128, hAlign | AlignVCenter | WordBreak, i18n(intro_text));
+    p.drawText(28, 128, width() - 38, 184 - 128, hAlign | AlignVCenter | WordBreak, intro);
 
     // fill background
     p.fillRect(0, yoffset, width(), height() - yoffset, QBrush(QColor(49,121,172)));
@@ -223,7 +248,7 @@ void AboutWidget::updatePixmap()
     if (height() <= 184) return;
 
     int part3EffectY = height() - _part3->height();
-    int part3EffectX = width()  - _part3->width();
+    int part3EffectX = (hAlign == AlignLeft) ? (width()  - _part3->width()) : 0;
     if ( part3EffectX < 0)
       part3EffectX = 0;
     if ( height() < 184 + _part3->height() )
@@ -234,16 +259,17 @@ void AboutWidget::updatePixmap()
     // draw textbox
     if (height() <= 184 + 50) return;
 
-    int boxX = 25;
-    int boxY = 184 + 50;
     int bheight = height() - 184 - 50 - 40;
-    int bwidth = width() - _part3->width() + 60;
+    int bwidth = width() - 50;
 
     if (bheight < 0) bheight = 0;
     if (bwidth < 0) bheight = 0;
     if (bheight > 400) bheight = 400;
     if (bwidth > 500) bwidth = 500;
 
+    int boxX = (hAlign == AlignLeft) ? 25 : width()-bwidth-25;
+    int boxY = 184 + 50;
+
     p.setClipRect(boxX, boxY, bwidth, bheight);
     p.fillRect( boxX, boxY, bwidth, bheight,
                 QBrush( QColor( 204, 222, 234 ) ) );
@@ -257,158 +283,175 @@ void AboutWidget::updatePixmap()
     yoffset = 30;
 
     int fheight = fontMetrics().height();
-    int xadd = 120;
 
     f2.setBold(true);
 
 
     if (!_moduleList)
     {
-	int xoffset = (hAlign == AlignLeft) ? 10 : bwidth-10-120;
+        int xoffset = (hAlign == AlignLeft) ? 10 : bwidth-10-120;
 	int xadd = (hAlign == AlignLeft) ? 120 : -xoffset+10;
       
 	// kde version
-      p.setFont(f1);
-      p.drawText(xoffset, yoffset, i18n(version_text));
-      p.setFont(f2);
-      p.drawText(xoffset + xadd, yoffset, KCGlobal::kdeVersion());
-      yoffset += fheight + 5;
-      if(yoffset > bheight) return;
+        p.setFont(f1);
+        p.drawText(xoffset, yoffset, 120, fheight, hAlign, i18n(version_text));
+        p.setFont(f2);
+        p.drawText(xoffset + xadd, yoffset, bwidth-130, fheight, hAlign, KCGlobal::kdeVersion());
+        yoffset += fheight + 5;
+        if(yoffset > bheight) return;
 
-      // user name
-      p.setFont(f1);
-      p.drawText(xoffset, yoffset, i18n(user_text));
-      p.setFont(f2);
-      p.drawText(xoffset + xadd, yoffset, KCGlobal::userName());
-      yoffset += fheight + 5;
-      if(yoffset > bheight) return;
+        // user name
+        p.setFont(f1);
+        p.drawText(xoffset, yoffset, 120, fheight, hAlign, i18n(user_text));
+        p.setFont(f2);
+        p.drawText(xoffset + xadd, yoffset, bwidth-130, fheight, hAlign, KCGlobal::userName());
+        yoffset += fheight + 5;
+        if(yoffset > bheight) return;
 
-      // host name
-      p.setFont(f1);
-      p.drawText(xoffset, yoffset, i18n(host_text));
-      p.setFont(f2);
-      p.drawText(xoffset + xadd, yoffset, KCGlobal::hostName());
-      yoffset += fheight + 5;
-      if(yoffset > bheight) return;
+        // host name
+        p.setFont(f1);
+        p.drawText(xoffset, yoffset, 120, fheight, hAlign, i18n(host_text));
+        p.setFont(f2);
+        p.drawText(xoffset + xadd, yoffset, bwidth-130, fheight, hAlign, KCGlobal::hostName());
+        yoffset += fheight + 5;
+        if(yoffset > bheight) return;
 
-      // system
-      p.setFont(f1);
-      p.drawText(xoffset, yoffset, i18n(system_text));
-      p.setFont(f2);
-      p.drawText(xoffset + xadd, yoffset, KCGlobal::systemName());
-      yoffset += fheight + 5;
-      if(yoffset > bheight) return;
+        // system
+        p.setFont(f1);
+        p.drawText(xoffset, yoffset, 120, fheight, hAlign, i18n(system_text));
+        p.setFont(f2);
+        p.drawText(xoffset + xadd, yoffset, bwidth-130, fheight, hAlign, KCGlobal::systemName());
+        yoffset += fheight + 5;
+        if(yoffset > bheight) return;
 
-      // release
-      p.setFont(f1);
-      p.drawText(xoffset, yoffset, i18n(release_text));
-      p.setFont(f2);
-      p.drawText(xoffset + xadd, yoffset, KCGlobal::systemRelease());
-      yoffset += fheight + 5;
-      if(yoffset > bheight) return;
+        // release
+        p.setFont(f1);
+        p.drawText(xoffset, yoffset, 120, fheight, hAlign, i18n(release_text));
+        p.setFont(f2);
+        p.drawText(xoffset + xadd, yoffset, bwidth-130, fheight, hAlign, KCGlobal::systemRelease());
+        yoffset += fheight + 5;
+        if(yoffset > bheight) return;
 
-      // machine
-      p.setFont(f1);
-      p.drawText(xoffset, yoffset, i18n(machine_text));
-      p.setFont(f2);
-      p.drawText(xoffset + xadd, yoffset, KCGlobal::systemMachine());
-      if(yoffset > bheight) return;
+        // machine
+        p.setFont(f1);
+        p.drawText(xoffset, yoffset, 120, fheight, hAlign, i18n(machine_text));
+        p.setFont(f2);
+        p.drawText(xoffset + xadd, yoffset, bwidth-130, fheight, hAlign, KCGlobal::systemMachine());
+        if(yoffset > bheight) return;
 
-      yoffset += 10;
+        yoffset += 10;
 
-      if(width() < 450 || height() < 450) return;
+        if(width() < 450 || height() < 450) return;
 
-      // draw use text
-      xoffset = 10;
-      bheight = bheight - yoffset - 10;
-      bwidth = bwidth - xoffset - 10;
+        // draw use text
+        xoffset = 10;
+        bheight = bheight - yoffset;
+        bwidth = bwidth - (xoffset *2); // both left and right margin
 
-      p.setFont(f1);
+        p.setFont(f1);
 
-      QString ut = i18n(use_text);
-      // do not break message freeze
-      ut.replace(QRegExp("<b>"), "");
-      ut.replace(QRegExp("</b>"), "");
+        QString ut = i18n(use_text);
+        // do not break message freeze
+        ut.replace(QRegExp("<b>"), "");
+        ut.replace(QRegExp("</b>"), "");
 
-      p.drawText(xoffset, yoffset, bwidth, bheight, hAlign | AlignVCenter | WordBreak, ut);
+        QRect r = p.boundingRect(0, 0, bwidth, bheight, hAlign | AlignVCenter | WordBreak, ut);
+        if (bheight - r.height() < 10)
+           return;
+
+        p.drawText(xoffset, yoffset, bwidth, bheight, hAlign | AlignVCenter | WordBreak, ut);
     }
     else
     {
-      // Need to set this here, not in the ctor. Otherwise Qt resets
-      // it to false when this is reparented (malte)
-      setMouseTracking(true);
-      QFont headingFont = f2;
-      headingFont.setPointSize(headingFont.pointSize()+5);
-      QFont lf = f2;
-      lf.setUnderline(true);
+        // Need to set this here, not in the ctor. Otherwise Qt resets
+        // it to false when this is reparented (malte)
+        setMouseTracking(true);
+        QFont headingFont = f2;
+        headingFont.setPointSize(headingFont.pointSize()+5);
+        QFont lf = f2;
+        lf.setUnderline(true);
 
-      p.setFont(headingFont);
-      p.drawText(xoffset, yoffset, static_cast<ModuleTreeItem*>(_category)->caption());
-      yoffset += fheight + 10;
-      xadd = 200;
-
-      // traverse the list
-      _moduleLinks.clear();
-      _linkBuffer.resize(xadd - 10, bheight);
-      _linkArea = p.viewport();
-      _linkArea.setWidth(xadd);
-      QPainter lp(&_linkBuffer);
-      lp.fillRect( 0, 0, xadd - 10, bheight,
-                  QBrush( QColor( 204, 222, 234 ) ) );
-      lp.drawPixmap( part3EffectX - boxX, part3EffectY - boxY, *_part3Effect );
-      lp.setPen(QColor(0x19, 0x19, 0x70)); // same as about:konqueror
-      lp.setFont(lf);
-      QListViewItem* pEntry = _category->firstChild();
-      while (pEntry != NULL)
+        const int alxadd = 200; // name-field width
+	
+	const int nameoffset = (hAlign == AlignLeft) ? 10 : bwidth-alxadd;
+	const int namewidth = alxadd -10;
+	const int commentoffset = (hAlign == AlignLeft) ? alxadd : 0;
+	const int commentwidth = bwidth-alxadd;
+	
+	int yoffset = 15;        
+	
+        p.setFont(headingFont);
+        if (!_caption.isEmpty())
         {
-          QString szName;
-          QString szComment;
-          ModuleInfo *module = static_cast<ModuleTreeItem*>(pEntry)->module();
-          if (module)
+           p.drawText(10, yoffset, bwidth-20, bheight - yoffset, hAlign | AlignTop, _caption );
+           yoffset += fheight + 15;
+        }
+
+        // traverse the list
+        _moduleLinks.clear();
+        _linkBuffer.resize(namewidth, bheight);
+	_linkArea = QRect(p.viewport().left()+nameoffset, p.viewport().top(), 
+	                  namewidth, p.viewport().height());
+        QPainter lp(&_linkBuffer);
+        lp.fillRect( 0, 0, namewidth, bheight,
+                    QBrush( QColor( 204, 222, 234 ) ) );
+        lp.drawPixmap( part3EffectX - boxX-nameoffset, part3EffectY - boxY, *_part3Effect );
+        lp.setPen(QColor(0x19, 0x19, 0x70)); // same as about:konqueror
+        lp.setFont(lf);
+        QListViewItem* pEntry = _category;
+        while (pEntry != NULL)
+        {
+            QString szName;
+            QString szComment;
+            ModuleInfo *module = static_cast<ModuleTreeItem*>(pEntry)->module();
+            if (module)
             {
-              szName = module->name();
-              szComment = module->comment();
-              p.setFont(f2);
-              QRect bounds;
-              p.drawText(xoffset, yoffset,
-                xadd - xoffset, bheight - yoffset,
-                AlignLeft | AlignTop | WordBreak, szName, -1, &bounds);
-              lp.drawText(xoffset, yoffset,
-                xadd - xoffset, bheight - yoffset,
-                AlignLeft | AlignTop | WordBreak, szName);
-              int height = bounds.height();
-              p.setFont(f1);
-              p.drawText(xoffset + xadd, yoffset,
-                bwidth - xadd - xoffset, bheight - yoffset,
-                AlignLeft | AlignTop | WordBreak, szComment, -1, &bounds);
-              height = QMAX(height, bounds.height());
-              ModuleLink *linkInfo = new ModuleLink;
-              linkInfo->module = module;
-              linkInfo->linkArea = QRect(xoffset + p.viewport().left(),
-                                         yoffset + p.viewport().top(),
-                                         xadd, height);
-              _moduleLinks.append(linkInfo);
-              yoffset += height + 5;
+                szName = module->name();
+                szComment = module->comment();
+                p.setFont(f2);
+                QRect bounds;
+	        int height;
+	        p.drawText(nameoffset, yoffset,
+                           namewidth, bheight - yoffset,
+                           hAlign | AlignTop | WordBreak, szName, -1, &bounds);
+                lp.drawText(0, yoffset,
+                            namewidth, bheight - yoffset,
+                            hAlign | AlignTop | WordBreak, szName);
+                height = bounds.height();
+                p.setFont(f1);
+                p.drawText(commentoffset, yoffset,
+                           commentwidth, bheight - yoffset,
+                           hAlign | AlignTop | WordBreak, szComment, -1, &bounds);
+	      
+	        height = QMAX(height, bounds.height());
+
+                ModuleLink *linkInfo = new ModuleLink;
+                linkInfo->module = module;
+                linkInfo->linkArea = QRect(nameoffset + p.viewport().left(),
+                                           yoffset + p.viewport().top(),
+                                           namewidth, height);
+                _moduleLinks.append(linkInfo);
+                yoffset += height + 5;
             }
-          else
+            else
             {
-              szName = static_cast<ModuleTreeItem*>(pEntry)->caption();
-              p.setFont(f2);
-              QRect bounds;
-              p.drawText(xoffset, yoffset, xadd - xoffset, bheight - yoffset,
-                AlignLeft | AlignTop | WordBreak, szName, -1, &bounds);
-              lp.drawText(xoffset, yoffset,
-                xadd - xoffset, bheight - yoffset,
-                AlignLeft | AlignTop | WordBreak, szName);
-              yoffset += bounds.height() + 5;
+                szName = static_cast<ModuleTreeItem*>(pEntry)->caption();
+                p.setFont(f2);
+                QRect bounds;
+                p.drawText(nameoffset, yoffset, namewidth, bheight - yoffset,
+                           hAlign | AlignTop | WordBreak, szName, -1, &bounds);
+                lp.drawText(nameoffset, yoffset,
+                            namewidth, bheight - yoffset,
+                            hAlign | AlignTop | WordBreak, szName);
+                yoffset += bounds.height() + 5;
             }
 
 //          yoffset += fheight + 5;
-          if(yoffset > bheight) return;
+            if(yoffset > bheight) return;
 
-          pEntry = pEntry->nextSibling();
+            pEntry = pEntry->nextSibling();
         }
-      }
+    }
 }
 
 void AboutWidget::mouseMoveEvent(QMouseEvent *e)
