@@ -34,6 +34,7 @@
 #include "global.h"
 
 bool KCGlobal::_root = false;
+bool KCGlobal::_infocenter = false;
 QStringList KCGlobal::_types;
 QString KCGlobal::_uname = "";
 QString KCGlobal::_hname = "";
@@ -48,22 +49,21 @@ QString KCGlobal::_baseGroup = "";
 
 void KCGlobal::init()
 {
-  QString hostname, username;
   char buf[128];
-  char *user = getlogin();
-  struct utsname info;
-
   gethostname(buf, 128);
-  if (strlen(buf)) hostname = QString("%1").arg(buf); else hostname = "";
-  if (!user) user = getenv("LOGNAME");
-  if (!user) username = ""; else username = QString("%1").arg(user);
+  QString hostname(buf);
+  
+  char *user = getlogin();
+  if (user == 0) user = getenv("LOGNAME");
+  QString username(user);
 
   setHostName(hostname);
   setUserName(username);
   setRoot(getuid() == 0);
 
-  setKDEVersion(KDE_VERSION_STRING);
+  setKDEVersion(KDE::versionString());
 
+  struct utsname info;
   uname(&info);
 
   setSystemName(info.sysname);
@@ -82,7 +82,7 @@ QString KCGlobal::baseGroup()
 {
   if ( _baseGroup.isEmpty() )
   {
-    KServiceGroup::Ptr group = KServiceGroup::baseGroup( "settings" );
+    KServiceGroup::Ptr group = KServiceGroup::baseGroup( _infocenter ? "info" : "settings" );
     if (group)
     {
       _baseGroup = group->relPath();
@@ -92,8 +92,16 @@ QString KCGlobal::baseGroup()
     // Compatibility with old behaviour, in case of missing .directory files.
     if (_baseGroup.isEmpty())
     {
-      kdWarning() << "No K menu group with X-KDE-BaseGroup=settings found ! Defaulting to Settings/" << endl;
-      _baseGroup = QString::fromLatin1("Settings");
+      if (_infocenter)
+      {
+        kdWarning() << "No K menu group with X-KDE-BaseGroup=info found ! Defaulting to Settings/Information/" << endl;
+        _baseGroup = QString::fromLatin1("Settings/Information/");
+      }
+      else
+      {
+        kdWarning() << "No K menu group with X-KDE-BaseGroup=settings found ! Defaulting to Settings/" << endl;
+        _baseGroup = QString::fromLatin1("Settings/");
+      }
     }
   }
   return _baseGroup;
