@@ -22,11 +22,13 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kurl.h>
 #include <kprocess.h>
 #include <kapplication.h>
-
+#include <krun.h>
 #include <qpushbutton.h>
 
+#include "global.h"
 #include "quickhelp.h"
 #include "helpwidget.h"
 #include "helpwidget.moc"
@@ -61,18 +63,30 @@ void HelpWidget::setText( const QString& docPath, const QString& text)
 
 void HelpWidget::setBaseText()
 {
-  _browser->setText(i18n("<h1>KDE Control Center</h1>"
-			 "Sorry, there is no quick help available for the active control module."
+  if (KCGlobal::isInfoCenter())
+     _browser->setText(i18n("<h1>KDE Info Center</h1>"
+			 "There is no quick help available for the active info module."
 			 "<br><br>"
-			 "Click <a href = \"kcontrol/index.html\">here</a> to read the general control center manual.") );
+			 "Click <a href = \"kinfocenter/index.html\">here</a> to read the general Info Center manual.") );
+  else 
+     _browser->setText(i18n("<h1>KDE Control Center</h1>"
+			 "There is no quick help available for the active control module."
+			 "<br><br>"
+			 "Click <a href = \"kcontrol/index.html\">here</a> to read the general Control Center manual.") );
 }
 
-void HelpWidget::urlClicked(const QString & url)
+void HelpWidget::urlClicked(const QString & _url)
 {
-  KProcess process;
-  process << "khelpcenter"
-          << "help:/" + url;
-  process.start(KProcess::DontCare);
+    KProcess process;
+    KURL url(KURL("help:/"), _url);
+
+    if (url.protocol() == "help" || url.protocol() == "man" || url.protocol() == "info") {
+        process << "khelpcenter"
+                << url.url();
+        process.start(KProcess::DontCare);
+    } else {
+        new KRun(url);
+    }
 }
 
 void HelpWidget::mailClicked(const QString &,const QString & addr)
