@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: background.h,v 1.1.2.3 2003/01/10 17:11:52 mlaurent Exp $
+ * $Id: background.h,v 1.1.2.4 2003/01/17 02:33:38 ossi Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -38,8 +38,6 @@ signals:
 
 private slots:
     void slotEnableChanged();
-    void moduleChanged(bool);
-    void slotEmitChange();
 private:
     void init();
     void apply();
