@@ -45,7 +45,7 @@ static inline void checkInsertPos( QPopupMenu *popup, const QString & str,
     int w = ( a + b ) / 2;
 
     int id = popup->idAt( w );
-    int j = str.compare( popup->text( id ) );
+    int j = str.localeAwareCompare( popup->text( id ) );
 
     if ( j > 0 )
       a = w + 1;
@@ -134,14 +134,13 @@ void KLanguageButton::insertLanguage( const QString& path, const QString& name,
   QString output = name + QString::fromLatin1( " (" ) + path +
                    QString::fromLatin1( ")" );
 #if 0
-  // dropping flags
+  // Nooooo ! Country != language
   QPixmap flag( locate( "locale", sub + path +
                 QString::fromLatin1( "/flag.png" ) ) );
 #endif
   insertItem( output, path, submenu, index );
 }
 
-
 void KLanguageButton::slotActivated( int index )
 {
   // Update caption and iconset:
