@@ -48,7 +48,7 @@
 #include <unistd.h>
 
 typedef KGenericFactory<KDModule, QWidget> KDMFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_kdm, KDMFactory("kdmconfig") );
+K_EXPORT_COMPONENT_FACTORY( kcm_kdm, KDMFactory("kdmconfig") )
 
 KURL *decodeImgDrop(QDropEvent *e, QWidget *wdg)
 {
