@@ -4,7 +4,7 @@
 // Author        : Craig Drummond
 // Project       : K Font Installer (kfontinst)
 // Creation Date : 02/05/2001
-// Version       : $Revision: 1.7 $ $Date: 2002/08/24 00:54:22 $
+// Version       : $Revision: 1.7.2.1 $ $Date: 2003/04/02 01:32:36 $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -105,7 +105,7 @@ CTtf::EStatus CTtf::fixPsNames(const QString &nameAndPath)
 
                     if(madeChange)
                     {
-                         if((status=checksum())==SUCCESS);
+                         if((status=checksum())==SUCCESS)
                              status=writeFile(nameAndPath);
                     }
                     else
