@@ -119,7 +119,7 @@ void KCookiePolicyDlg::setEnableHostEdit( bool state, const QString& host )
 
 void KCookiePolicyDlg::setPolicy (int policy)
 {
-  if ( policy > -1 && policy < static_cast<int>(m_cbPolicy->count()) )
+  if ( policy > -1 && policy <= static_cast<int>(m_cbPolicy->count()) )
     m_cbPolicy->setCurrentItem(policy-1);
 
   if ( !m_leDomain->isEnabled() )
