@@ -19,7 +19,7 @@
 */
 
 #ifndef __SMBRODLG_H
-#define __SMBRODLG_H 
+#define __SMBRODLG_H
 
 #include <qwidget.h>
 #include <qlineedit.h>
@@ -27,12 +27,13 @@
 
 #include <kcmodule.h>
 
+class KComboBox;
 
 class SMBRoOptions : public KCModule
 {
    Q_OBJECT
    public:
-      SMBRoOptions(QWidget *parent = 0L, const char *name = 0L);
+      SMBRoOptions(QWidget *parent = 0);
       ~SMBRoOptions();
 
       virtual void load();
@@ -48,6 +49,7 @@ class SMBRoOptions : public KCModule
       QLineEdit *m_passwordLe;
       QLineEdit *m_workgroupLe;
       QCheckBox *m_showHiddenShares;
+      KComboBox *m_encodingList;
 };
 
 #endif
