@@ -310,7 +310,7 @@ void UserAgentOptions::load()
       QString domain = *it;
       m_config->setGroup(*it);
       QString userAgent = m_config->readEntry("UserAgent");
-      if (!userAgent.isEmpty());
+      if (!userAgent.isEmpty())
       {
          QString comment = m_provider->aliasFor(userAgent);
          (void) new QListViewItem( lv_siteUABindings, domain.lower(), userAgent, comment );
