@@ -1,5 +1,5 @@
 /*
-    $Id: knotify.cpp,v 1.61 2002/10/24 18:00:27 pfeiffer Exp $
+    $Id: knotify.cpp,v 1.61.2.2 2003/06/29 21:53:08 deller Exp $
 
     Copyright (C) 2000,2002 Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -77,7 +77,7 @@ KCMKNotify::KCMKNotify(QWidget *parent, const char *name, const QStringList & )
 
     load();
 
-};
+}
 
 KCMKNotify::~KCMKNotify()
 {
@@ -244,7 +244,7 @@ void PlayerSettingsDialog::load()
     config.setGroup( "Misc" );
     cbExternal->setChecked( config.readBoolEntry( "Use external player",
                                                   false ));
-    reqExternal->setURL( config.readEntry( "External player" ));
+    reqExternal->setURL( config.readPathEntry( "External player" ));
     reqExternal->setEnabled( cbExternal->isChecked() );
     volumeSlider->setValue( config.readNumEntry( "Volume", 100 ) );
     volumeSlider->parentWidget()->setEnabled( !cbExternal->isChecked() );
