@@ -23,7 +23,7 @@
 
 class QCheckBox;
 class QLabel;
-class QLineEdit;
+class KURLRequester;
 class KConfig;
 class QVButtonGroup;
 class QRadioButton;
@@ -37,16 +37,17 @@ class KBehaviourOptions : public KCModule
   Q_OBJECT
 public:
   KBehaviourOptions(KConfig *config, QString group, QWidget *parent=0, const char *name=0);
-
+    ~KBehaviourOptions();
   virtual void load();
   virtual void save();
   virtual void defaults();
+  virtual QString quickHelp() const;
 
 protected slots:
 
   void changed();
   void updateWinPixmap(bool);
-
+  void slotShowTips(bool);
 private:
 
   KConfig *g_pConfig;
@@ -58,7 +59,7 @@ private:
 
   QLabel *winPixmap;
 
-  QLineEdit *homeURL;
+  KURLRequester *homeURL;
 
   QVButtonGroup *bgOneProcess;
   QRadioButton  *rbOPNever,
@@ -66,8 +67,14 @@ private:
                 *rbOPWeb,
                 *rbOPAlways;
 
-  QSpinBox  *sbToolTip;
+  //QLabel *fileTips;
+  //QSpinBox  *sbToolTip;
   QCheckBox *cbShowTips;
+  QCheckBox *cbShowPreviewsInTips;
+
+  QCheckBox *cbMoveToTrash;
+  QCheckBox *cbDelete;
+  QCheckBox *cbShred;
 };
 
 #endif		// __BEHAVIOUR_H__
