@@ -24,6 +24,7 @@
 #include <qslider.h>
 
 #include <kapplication.h>
+#include <kconfig.h>
 #include <dcopclient.h>
 #include <kglobal.h>
 #include <klocale.h>
@@ -41,7 +42,7 @@ extern "C"
   KCModule *create_virtualdesktops(QWidget *parent, const char */*name*/)
   {
     return new KDesktopConfig(parent, "kcmkonq");
-  };
+  }
 }
 
 // I'm using 16 line inputs by intention as it makes sence to be able
@@ -102,6 +103,32 @@ KDesktopConfig::KDesktopConfig(QWidget *parent, const char */*name*/)
   layout->addWidget(name_group);
   layout->addStretch(1);
 
+  // Begin check for immutable
+  int kwin_screen_number = DefaultScreen(qt_xdisplay());
+
+  KConfig *config = KGlobal::config();
+
+  QCString groupname;
+  if (kwin_screen_number == 0)
+     groupname = "Desktops";
+  else
+     groupname.sprintf("Desktops-screen-%d", kwin_screen_number);
+
+  if (config->groupIsImmutable(QString::fromUtf8(groupname)))
+  {
+     name_group->setEnabled(false);
+     number_group->setEnabled(false);
+  }
+  else
+  {
+     KConfigGroupSaver cfgSaver(config, groupname);
+     if (config->entryIsImmutable("Number"))
+     {
+        number_group->setEnabled(false);
+     }
+  }
+  // End check for immutable
+
   load();
 }
 
