@@ -29,6 +29,7 @@ class QComboBox;
 class QLineEdit;
 class QListViewItem;
 class QRadioButton;
+class QPushButton;
 
 class KJavaOptions : public KCModule
 {
@@ -49,6 +50,7 @@ private slots:
     void changePressed();
     void deletePressed();
     void toggleJavaControls();
+    void updateButton();
 
 private:
     void updateDomainList(const QStringList &domainConfig);
@@ -65,7 +67,8 @@ private:
     QLineEdit*     addArgED;
     KURLRequester* pathED;
 
-
+    QPushButton* changeDomainPB;
+    QPushButton* deleteDomainPB;
     QMap<QListViewItem*, int> javaDomainPolicy;
 };
 
