@@ -91,7 +91,7 @@ KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget
   QWhatsThis::add( domainSpecificGB, wtstr );
   connect(domainSpecificLV,SIGNAL(doubleClicked ( QListViewItem * )), this, SLOT( changePressed() ) );
   connect(domainSpecificLV,SIGNAL(returnPressed ( QListViewItem * )), this, SLOT( changePressed() ) );
-
+  connect(domainSpecificLV, SIGNAL( executed( QListViewItem *)), SLOT( updateButton()));
 
   domainSpecificGBLayout->addMultiCellWidget( domainSpecificLV, 0, 5, 0, 0 );
   QPushButton* addDomainPB = new QPushButton( i18n("&New..."), domainSpecificGB );
@@ -100,13 +100,13 @@ KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget
                                      "specific policy.") );
   connect( addDomainPB, SIGNAL(clicked()), SLOT( addPressed() ) );
 
-  QPushButton* changeDomainPB = new QPushButton( i18n("Chan&ge..."), domainSpecificGB );
+  changeDomainPB = new QPushButton( i18n("Chan&ge..."), domainSpecificGB );
   domainSpecificGBLayout->addWidget( changeDomainPB, 1, 1 );
   QWhatsThis::add( changeDomainPB, i18n("Click on this button to change the policy for the "
                                         "host or domain selected in the list box.") );
   connect( changeDomainPB, SIGNAL( clicked() ), this, SLOT( changePressed() ) );
 
-  QPushButton* deleteDomainPB = new QPushButton( i18n("De&lete"), domainSpecificGB );
+  deleteDomainPB = new QPushButton( i18n("De&lete"), domainSpecificGB );
   domainSpecificGBLayout->addWidget( deleteDomainPB, 2, 1 );
   QWhatsThis::add( deleteDomainPB, i18n("Click on this button to change the policy for the "
                                         "host or domain selected in the list box.") );
@@ -147,21 +147,21 @@ KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget
 
   js_popup = new QButtonGroup(4, Horizontal, i18n( "JavaScript Web Popups Policy" ), this);
   js_popup->setExclusive(TRUE);
-  
+
   QRadioButton* popupMode = new QRadioButton(i18n( "Allow" ), js_popup);
   QWhatsThis::add( popupMode,i18n("Accept all popup window requests.") );
-  
+
   popupMode = new QRadioButton(i18n( "Ask" ), js_popup);
   QWhatsThis::add( popupMode,i18n("Prompt every time a popup window is requested.") );
-  
+
   popupMode = new QRadioButton(i18n( "Deny" ), js_popup);
   QWhatsThis::add( popupMode,i18n("Reject all popup window requests.") );
-  
-  popupMode = new QRadioButton(i18n( "Smart" ), js_popup);  
+
+  popupMode = new QRadioButton(i18n( "Smart" ), js_popup);
   QWhatsThis::add( popupMode, i18n("Accept popup window requests only when "
                                    "links are activated through an explicit "
                                    "mouse click or keyboard operation.") );
-  toplevel->addWidget(js_popup);  
+  toplevel->addWidget(js_popup);
   QWhatsThis::add( js_popup, i18n("If you disable this, Konqueror will stop "
                                   "interpreting the <i>window.open()</i> "
                                   "JavaScript command. This is useful if you "
@@ -186,6 +186,16 @@ KJavaScriptOptions::KJavaScriptOptions( KConfig* config, QString group, QWidget
 
   // Finally do the loading
   load();
+  updateButton();
+}
+
+void KJavaScriptOptions::updateButton()
+{
+    QListViewItem *index = domainSpecificLV->currentItem();
+    bool enable = ( index != 0 );
+    changeDomainPB->setEnabled( enable );
+    deleteDomainPB->setEnabled( enable );
+
 }
 
 
@@ -264,6 +274,7 @@ void KJavaScriptOptions::addPressed()
         javaScriptDomainPolicy.insert( index, (KHTMLSettings::KJavaScriptAdvice)pDlg.javaScriptPolicyAdvice());
         domainSpecificLV->setCurrentItem( index );
         slotChanged();
+        updateButton();
     }
 }
 
@@ -303,6 +314,7 @@ void KJavaScriptOptions::deletePressed()
     javaScriptDomainPolicy.remove(index);
     delete index;
     slotChanged();
+    updateButton();
 }
 
 void KJavaScriptOptions::importPressed()
