@@ -24,6 +24,7 @@ class QListViewItem;
 class QRadioButton;
 class QSpinBox;
 class QButtonGroup;
+class QPushButton;
 
 class KJavaScriptOptions : public KCModule
 {
@@ -42,7 +43,7 @@ private slots:
   void addPressed();
   void changePressed();
   void deletePressed();
-
+    void updateButton();
 private:
   void changeJavaScriptEnabled();
   void updateDomainList(const QStringList &domainConfig);
@@ -52,6 +53,8 @@ private:
   QCheckBox *enableJavaScriptGloballyCB;
   QCheckBox *enableJavaScriptDebugCB;
   QButtonGroup *js_popup;
+    QPushButton* changeDomainPB;
+    QPushButton* deleteDomainPB;
   KListView* domainSpecificLV;
   QMap<QListViewItem*, int> javaScriptDomainPolicy;
 };
