@@ -30,6 +30,8 @@ PolicyDialog::PolicyDialog( bool javascript, bool java, QWidget *parent, const c
   l->setBuddy( le_domain );
   grid->addWidget(le_domain, 0, 1);
 
+  connect( le_domain,SIGNAL(textChanged ( const QString & )),this,SLOT(slotTextChanged( const QString &)));
+
   QWhatsThis::add(le_domain, i18n("Enter the name of a host (like www.kde.org) "
                                   "or a domain, starting with a dot (like .kde.org or .org)") );
 
@@ -64,7 +66,7 @@ PolicyDialog::PolicyDialog( bool javascript, bool java, QWidget *parent, const c
   topl->addWidget(bbox);
 
   bbox->addStretch(1);
-  QPushButton *okButton = bbox->addButton(i18n("&OK"));
+  okButton = bbox->addButton(i18n("&OK"));
   okButton->setDefault(true);
   connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
 
@@ -85,12 +87,17 @@ PolicyDialog::PolicyDialog( bool javascript, bool java, QWidget *parent, const c
   }
 
   le_domain->setFocus();
+  okButton->setEnabled( !le_domain->text().isEmpty());
+}
+
+void PolicyDialog::slotTextChanged( const QString &text)
+{
+    okButton->setEnabled( !text.isEmpty());
 }
 
 void PolicyDialog::setDisableEdit( bool state, const QString& text )
 {
-    if( text.isNull() );
-        le_domain->setText( text );
+    le_domain->setText( text );
 
     le_domain->setEnabled( state );
 
