@@ -10,7 +10,6 @@
 #include <qradiobutton.h>
 #include <qvbuttongroup.h>
 #include <qstring.h>
-#include <qspinbox.h>
 #include <qlabel.h>
 #include <qwhatsthis.h>
 
@@ -21,6 +20,8 @@
 #include <kcmodule.h>
 #include <kpassdlg.h>
 #include <kgenericfactory.h>
+#include <knuminput.h>
+#include <kaboutdata.h>
 
 #include <kdesu/defaults.h>
 #include <kdesu/client.h>
@@ -43,7 +44,7 @@ KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name, const QStrin
     QVBoxLayout *top = new QVBoxLayout(this, 10, 10);
 
     // Echo mode
-    m_EMGroup = new QVButtonGroup(i18n("Echo characters as"), this);
+    m_EMGroup = new QVButtonGroup(i18n("Echo Characters As"), this);
     m_EMGroup->layout()->setSpacing( KDialog::spacingHint() );
     QWhatsThis::add( m_EMGroup,  i18n("You can select the type of visual feedback given"
       " when you enter a password in kdesu. Choose one of the following options:<p>"
@@ -52,9 +53,9 @@ KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name, const QStrin
       " <li><em>no echo:</em> there is no visual feedback at all, so nothing on your screen"
       " shows how many characters are in your password.</li></ul>"));
     top->addWidget(m_EMGroup);
-    new QRadioButton(i18n("1 star"), m_EMGroup);
-    new QRadioButton(i18n("3 stars"), m_EMGroup);
-    new QRadioButton(i18n("no echo"), m_EMGroup);
+    new QRadioButton(i18n("&1 star"), m_EMGroup);
+    new QRadioButton(i18n("&3 stars"), m_EMGroup);
+    new QRadioButton(i18n("&No echo"), m_EMGroup);
     connect(m_EMGroup, SIGNAL(clicked(int)), SLOT(slotEchoMode(int)));
 
     // Keep password
@@ -71,25 +72,19 @@ KPasswordConfig::KPasswordConfig(QWidget *parent, const char *name, const QStrin
     top->addWidget(m_KeepBut);
     QHBoxLayout *hbox = new QHBoxLayout();
     top->addLayout(hbox);
-    QLabel *lbl = new QLabel(i18n("&Timeout"), this);
-    lbl->setFixedSize(lbl->sizeHint());
     hbox->addSpacing(20);
-    hbox->addWidget(lbl);
-    m_TimeoutEdit = new QSpinBox(this);
+    m_TimeoutEdit = new KIntNumInput(this);
     QString wtstr = i18n("You can specify how long kdesu will remember your"
        " passwords. A short timeout is more secure than a long timeout.");
-    QWhatsThis::add( lbl, wtstr );
     QWhatsThis::add( m_TimeoutEdit, wtstr );
-    lbl->setBuddy(m_TimeoutEdit);
+    m_TimeoutEdit->setLabel( i18n( "&Timeout:" ), AlignVCenter );
     m_TimeoutEdit->setRange(5, 1200);
-    m_TimeoutEdit->setSteps(5, 10);
-    m_TimeoutEdit->setSuffix(i18n(" minutes"));
-    m_TimeoutEdit->setFixedSize(m_TimeoutEdit->sizeHint());
+    m_TimeoutEdit->setSteps(5, 20);
+    m_TimeoutEdit->setSuffix(i18n(" min"));
 
     connect(m_TimeoutEdit,SIGNAL(valueChanged ( int )),this,SLOT(configChanged()));
 
     hbox->addWidget(m_TimeoutEdit);
-    hbox->addStretch();
 
     top->addStretch();
 
@@ -119,6 +114,7 @@ void KPasswordConfig::load()
 
     m_bKeep = m_pConfig->readBoolEntry("Keep", defKeep);
     m_Timeout = m_pConfig->readNumEntry("Timeout", defTimeout);
+    slotKeep(m_bKeep);
 
     apply();
     emit changed(false);
@@ -185,7 +181,7 @@ void KPasswordConfig::slotEchoMode(int i)
 void KPasswordConfig::slotKeep(bool keep)
 {
     m_bKeep = keep;
-    m_TimeoutEdit->setEnabled(m_bKeep);
+    m_TimeoutEdit->setEnabled(keep);
     emit changed(true);
 }
 
@@ -210,4 +206,17 @@ QString KPasswordConfig::quickHelp() const
        " configured here.");
 }
 
+const KAboutData* KPasswordConfig::aboutData() const
+{
+   KAboutData *about =
+   new KAboutData(I18N_NOOP("kcmpasswords"), I18N_NOOP("Password Control Module"),
+                  0, 0, KAboutData::License_GPL,
+                  I18N_NOOP("(c) 1999-2000, Geert Jansen"));
+
+   about->addAuthor("Geert Jansen", 0 , "jansen@kde.org");
+
+   return about;
+}
+
+
 #include "passwords.moc"
