@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwords.h,v 1.5 2001/12/28 02:32:22 zecke Exp $
+ * $Id: passwords.h,v 1.9 2002/11/03 12:27:51 mlaurent Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -11,8 +11,10 @@
 
 class QButtonGroup;
 class QCheckBox;
-class QSpinBox;
+
 class KConfig;
+class KIntNumInput;
+class KAboutData;
 
 #include <kcmodule.h>
 
@@ -27,13 +29,12 @@ public:
     virtual void load();
     virtual void save();
     virtual void defaults();
+    const KAboutData* aboutData() const;
 
     void apply();
     int buttons();
     QString quickHelp() const;
 
-signals:
-    void changed(bool);
 
 private slots:
 
@@ -43,7 +44,7 @@ private slots:
 private:
     QButtonGroup *m_EMGroup;
     QCheckBox *m_KeepBut;
-    QSpinBox *m_TimeoutEdit;
+    KIntNumInput *m_TimeoutEdit;
     KConfig *m_pConfig;
 
     int m_Echo, m_Timeout;
