@@ -77,14 +77,14 @@ NetMon::NetMon( QWidget * parent, KConfig *config, const char * name )
     QObject::connect(list,SIGNAL(rightButtonPressed(QListViewItem *,const QPoint &,int)),
 		    SLOT(Killmenu(QListViewItem *,const QPoint &,int)));*/
     update();
-};
+}
 
 void NetMon::processNFSLine(char *bufline, int)
 {
    QCString line(bufline);
    if (line.contains(":/"))
       new QListViewItem(list,"NFS",After(":",line),Before(":/",line));
-};
+}
 
 void NetMon::processSambaLine(char *bufline, int)
 {
@@ -166,7 +166,7 @@ void NetMon::slotReceivedData(KProcess *, char *buffer, int )
 
 void NetMon::update()
 {
-   int pid,n;
+   int pid;
    QListViewItem *row;
    KProcess * process = new KProcess();
 
@@ -237,7 +237,7 @@ void NetMon::killShowmount()
       //cerr<<"succeeded"<<endl;
    };
 
-};
+}
 
 /*void NetMon::Kill()
 {
