@@ -91,19 +91,19 @@ SaverConfig::SaverConfig()
 bool SaverConfig::read(QString file)
 {
     KDesktopFile config(file, true);
-    mExec = config.readEntry("Exec");
+    mExec = config.readPathEntry("Exec");
     mName = config.readEntry("Name");
 
     if (config.hasActionGroup("Setup"))
     {
       config.setActionGroup("Setup");
-      mSetup = config.readEntry("Exec");
+      mSetup = config.readPathEntry("Exec");
     }
 
     if (config.hasActionGroup("InWindow"))
     {
       config.setActionGroup("InWindow");
-      mSaver = config.readEntry("Exec");
+      mSaver = config.readPathEntry("Exec");
     }
 
     int indx = file.findRev('/');
@@ -310,6 +310,13 @@ KScreenSaver::KScreenSaver(QWidget *parent, const char *name, const QStringList&
 
     vLayout->addStretch();
 
+    if (mImmutable)
+    {
+       setButtons(buttons() & ~Default);
+       mSettingsGroup->setEnabled(false);
+       mSaverGroup->setEnabled(false);
+    }
+
     // finding the savers can take some time, so defer loading until
     // we've started up.
     mNumLoaded = 0;
@@ -409,6 +416,9 @@ void KScreenSaver::load()
 void KScreenSaver::readSettings()
 {
     KConfig *config = new KConfig( "kdesktoprc");
+    
+    mImmutable = config->groupIsImmutable("ScreenSaver");
+    
     config->setGroup( "ScreenSaver" );
 
     mEnabled = config->readBoolEntry("Enabled", false);
@@ -446,6 +456,8 @@ void KScreenSaver::updateValues()
 //
 void KScreenSaver::defaults()
 {
+    if (mImmutable) return;
+    
     slotScreenSaver( 0 );
     mEnabledCheckBox->setChecked( false );
     mSaverListBox->setCurrentItem( 0 );
@@ -756,7 +768,7 @@ void KScreenSaver::slotTest()
         }
 
 	mTesting = true;
-        mTestProc->start(KProcess::DontCare);
+        mTestProc->start(KProcess::NotifyOnExit);
     }
 }
 
