@@ -266,15 +266,16 @@ void Installer::slotCreate()
 
   name = dlg.fileName();
   if (!theme->create(name)) return;
-  theme->setName(dlg.themeName().local8Bit());
+  theme->setDescription(dlg.themeName());
   theme->setAuthor(dlg.author());
   theme->setEmail(dlg.email());
   theme->setHomepage(dlg.homepage());
   theme->setVersion("0.1");
   theme->savePreview(dlg.preview());
   theme->extract();
-
-  mThemesList->setCurrentItem(addTheme(name));
+  int cur =addTheme(name);
+  mThemesList->setCurrentItem(cur);
+  slotSetTheme(cur);
 }
 
 
@@ -298,7 +299,7 @@ void Installer::slotRemove()
     KMessageBox::sorry(this, i18n("Failed to remove theme '%1'").arg(themeName));
     return;
   }
-  mThemesList->removeItem(cur);
+  readThemesList();
   if (cur >= (int)mThemesList->count()) cur--;
   mThemesList->setCurrentItem(cur);
 }
@@ -335,9 +336,9 @@ void Installer::slotSetTheme(int id)
       KMessageBox::sorry(this, error);
     }
   }
-
+  isGlobal = QFileInfo(name).isWritable();
   mBtnSaveAs->setEnabled(enabled);
-  mBtnRemove->setEnabled(!isGlobal);
+  mBtnRemove->setEnabled(isGlobal);
 }
 
 
