@@ -24,7 +24,6 @@
 #include <qwidget.h>
 
 class QComboBox;
-class QLineEdit;
 
 class ConfFax : public QWidget
 {
@@ -35,8 +34,7 @@ public:
 	void save();
 
 private:
-	QComboBox	*m_device, *m_resolution, *m_pagesize;
-	QLineEdit	*m_host;
+	QComboBox	*m_resolution, *m_pagesize;
 };
 
 #endif
