@@ -29,6 +29,8 @@
 #include <qpushbutton.h>
 #include <qdragobject.h>
 #include <qtextedit.h>
+#include <qdatetimeedit.h>
+#include <qcombobox.h>
 
 #include <kapplication.h>
 #include <kstdaction.h>
@@ -66,7 +68,7 @@ KdeprintFax::KdeprintFax(QWidget *parent, const char *name)
 	m_number = new QLineEdit(mainw);
 	m_name = new QLineEdit(mainw);
 	m_enterprise = new QLineEdit(mainw);
-	QLabel	*m_numberlabel = new QLabel(i18n("Fax &Number:"), mainw);
+	QLabel	*m_numberlabel = new QLabel(i18n("Fax &number:"), mainw);
         m_numberlabel->setBuddy(m_number);
 	QLabel	*m_namelabel = new QLabel(i18n("N&ame:"), mainw);
         m_namelabel->setBuddy(m_name);
@@ -80,8 +82,18 @@ KdeprintFax::KdeprintFax(QWidget *parent, const char *name)
 	m_comment->setWordWrap(QTextEdit::NoWrap);
 	m_comment->setLineWidth(1);
 	m_commentlabel->setBuddy(m_comment);
+	QLabel	*m_timelabel = new QLabel(i18n("Sched&ule:"), mainw);
+	m_timecombo = new QComboBox(mainw);
+	m_timecombo->insertItem(i18n("Now"));
+	m_timecombo->insertItem(i18n("At Specified Time"));
+	m_timecombo->setCurrentItem(0);
+	m_timelabel->setBuddy(m_timecombo);
+	m_time = new QTimeEdit(mainw);
+	m_time->setTime(QTime::currentTime());
+	m_time->setEnabled(false);
+	connect(m_timecombo, SIGNAL(activated(int)), SLOT(slotTimeComboActivated(int)));
 
-	QGridLayout	*l0 = new QGridLayout(mainw, 7, 2, 10, 5);
+	QGridLayout	*l0 = new QGridLayout(mainw, 8, 2, 10, 5);
 	l0->setColStretch(1,1);
 	l0->addRowSpacing(5, 10);
 	l0->addWidget(m_filelabel, 0, 0, Qt::AlignLeft|Qt::AlignTop);
@@ -96,6 +108,11 @@ KdeprintFax::KdeprintFax(QWidget *parent, const char *name)
 	l0->addWidget(m_enterprise, 4, 1);
 	l0->addWidget(m_commentlabel, 6, 0, Qt::AlignTop|Qt::AlignLeft);
 	l0->addWidget(m_comment, 6, 1);
+	l0->addWidget(m_timelabel, 7, 0);
+	QHBoxLayout	*l1 = new QHBoxLayout(0, 0, 5);
+	l0->addLayout(l1, 7, 1);
+	l1->addWidget(m_timecombo, 1);
+	l1->addWidget(m_time, 0);
 
 	m_msglabel = new KSqueezedTextLabel(statusBar());
 	statusBar()->addWidget(m_msglabel, 1);
@@ -123,8 +140,8 @@ void KdeprintFax::initActions()
 	new KAction(i18n("&Remove File"), "remove", Qt::Key_Delete, this, SLOT(slotRemove()), actionCollection(), "file_remove");
 	new KAction(i18n("&Send Fax"), "connect_established", Qt::Key_Return, this, SLOT(slotFax()), actionCollection(), "fax_send");
 	new KAction(i18n("A&bort"), "stop", Qt::Key_Escape, this, SLOT(slotAbort()), actionCollection(), "fax_stop");
-	new KAction(i18n("A&ddress Book..."), "contents2", Qt::CTRL+Qt::Key_A, this, SLOT(slotKab()), actionCollection(), "fax_ab");
-	new KAction(i18n("V&iew Log..."), "contents", Qt::CTRL+Qt::Key_L, this, SLOT(slotViewLog()), actionCollection(), "fax_log");
+	new KAction(i18n("A&ddress Book"), "contents2", Qt::CTRL+Qt::Key_A, this, SLOT(slotKab()), actionCollection(), "fax_ab");
+	new KAction(i18n("V&iew Log"), "contents", Qt::CTRL+Qt::Key_L, this, SLOT(slotViewLog()), actionCollection(), "fax_log");
 	new KAction(i18n("Vi&ew File"), "filefind", Qt::CTRL+Qt::Key_O, this, SLOT(slotView()), actionCollection(), "file_view");
 
 	KStdAction::quit(this, SLOT(slotQuit()), actionCollection());
@@ -294,13 +311,20 @@ void KdeprintFax::slotConfigure()
 
 void KdeprintFax::updateState()
 {
-	m_comment->setPaper(m_faxctrl->isExtended() ? colorGroup().base() : colorGroup().background());
-	m_comment->setEnabled(m_faxctrl->isExtended());
+	QString	cmd = m_faxctrl->faxCommand();
+	m_comment->setEnabled(cmd.find("%comment") != -1);
+	//m_comment->setPaper(m_comment->isEnabled() ? colorGroup().brush(QColorGroup::Base) : colorGroup().brush(QColorGroup::Background));
 	if (!m_comment->isEnabled())
 		m_comment->setText("");
-	m_enterprise->setEnabled(m_faxctrl->isExtended());
+	m_enterprise->setEnabled(cmd.find("%enterprise") != -1);
 	if (!m_enterprise->isEnabled())
 		m_enterprise->setText("");
+	if (cmd.find("%time") == -1)
+	{
+		m_timecombo->setCurrentItem(0);
+		m_timecombo->setEnabled(false);
+		slotTimeComboActivated(0);
+	}
 	statusBar()->changeItem(m_faxctrl->faxSystem(), 2);
 }
 
@@ -309,4 +333,16 @@ void KdeprintFax::slotQuit()
 	close(true);
 }
 
+void KdeprintFax::slotTimeComboActivated(int ID)
+{
+	m_time->setEnabled(ID == 1);
+}
+
+QString KdeprintFax::time()
+{
+	if (!m_time->isEnabled())
+		return QString::null;
+	return m_time->time().toString("hh:mm");
+}
+
 #include "kdeprintfax.moc"
