@@ -38,9 +38,8 @@ class JobTray : public KSystemTray
 {
 public:
 	JobTray(KJobViewerApp *parent, const char *name = 0)
-		: KSystemTray(0, name), m_app(parent) {}
+		: KSystemTray(0, name), m_app(parent) { connect( this, SIGNAL( quitSelected() ), kapp, SLOT( quit() ) ); }
 protected:
-	void contextMenuAboutToShow(KPopupMenu*);
 	void mousePressEvent(QMouseEvent*);
 private:
 	KJobViewerApp	*m_app;
@@ -87,21 +86,6 @@ void JobTray::mousePressEvent(QMouseEvent *e)
 	}
 }
 
-void JobTray::contextMenuAboutToShow(KPopupMenu *menu)
-{
-	unsigned int n(0);
-	for (; n<menu->count(); n++)
-	{
-		if (menu->text(menu->idAt(n)) ==i18n("&Quit"))
-		{
-			menu->removeItemAt(n);
-			break;
-		}
-	}
-
-	menu->insertItem(SmallIcon("exit"), i18n("&Quit" ), kapp, SLOT(quit()), 0, -1, n);
-}
-
 //-------------------------------------------------------------
 
 KJobViewerApp::KJobViewerApp() : KUniqueApplication()
@@ -145,6 +129,7 @@ void KJobViewerApp::initialize()
             else {
                 KMessageBox::error(0, i18n("There is no default printer. Start with --all to see all printers."), i18n("Print Error"));
                 exit(1);
+                return;
             }
         }
 
