@@ -27,7 +27,7 @@
 
 static KCmdLineOptions options[] = {
 	{ "d <printer-name>", I18N_NOOP("The printer for which jobs are requested"), 0 },
-	{ "show", I18N_NOOP("Show job viewer at startup"), 0},
+	{ "noshow", I18N_NOOP("Show job viewer at startup"), 0},
 	{ "all", I18N_NOOP("Show jobs for all printers"), 0},
 	{ 0, 0, 0}
 };
