@@ -23,6 +23,8 @@
 #include <qwidget.h>
 
 class KPrinter;
+class KPrintDialog;
+class QSocketNotifier;
 
 class PrintWrapper : public QWidget
 {
@@ -33,9 +35,15 @@ public:
 public slots:
 	void slotPrint();
 	void slotPrintRequested(KPrinter*);
-	
+
+private slots:
+	void slotGotStdin();
+		
 private:
-	bool	stdin_set;
+	bool force_stdin;
+	bool check_stdin;
+	KPrintDialog* dlg;
+	QSocketNotifier* notif;
 };
 
 #endif
