@@ -30,6 +30,9 @@ public:
 	KCMPrintMgr(QWidget *parent = 0, const char *name = 0);
 	~KCMPrintMgr();
 
+	QString quickHelp() const;
+	const KAboutData* aboutData() const;
+
 private:
 	KMMainView	*m_mainview;
 };
