@@ -41,6 +41,8 @@ private:
 	void showSpecialInfo(KMPrinter*);
 	void showData(const QString&);
 	QString locateData(const QString&);
+	void showJobs(KMPrinter *p = 0, bool completed = false);
+	void showDriver(KMPrinter*);
 
 	bool loadTemplate(const QString& filename, QString& buffer);
 };
