@@ -4,8 +4,11 @@
 //
 // Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
 //
+#include <config.h>
+
 #include <ctype.h>
 #include <unistd.h>
+#include <stdlib.h>
 #include <pwd.h>
 #include <sys/types.h>
 #include <qlayout.h>
