@@ -57,8 +57,6 @@ int kdesktop_screen_number = 0;
 
 static void crashHandler(int sigId)
 {
-    KCrash::setCrashHandler(0); // exit on next crash
-
     DCOPClient::emergencyClose(); // unregister DCOP
     sleep( 1 );
     system("kdesktop --noautostart &"); // try to restart
@@ -69,8 +67,8 @@ static void crashHandler(int sigId)
 static void signalHandler(int sigId)
 {
     fprintf(stderr, "*** kdesktop got signal %d (Exiting)\n", sigId);
+    KCrash::setEmergencySaveFunction(0); // No restarts any more
     // try to cleanup all windows
-    KCrash::setCrashHandler(0); // we're quitting now anyway
     signal(SIGTERM, SIG_DFL); // next one kills
     signal(SIGHUP,  SIG_DFL); // next one kills
     if (kapp)
@@ -151,7 +149,7 @@ int main( int argc, char **argv )
     app.disableSessionManagement(); // Do SM, but don't restart.
 
     if (getenv("KDE_DEBUG") == NULL)
-        KCrash::setCrashHandler(crashHandler); // Try to restart on crash
+        KCrash::setEmergencySaveFunction(crashHandler); // Try to restart on crash
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
