@@ -80,14 +80,12 @@ Minicli::Minicli( QWidget *parent, const char *name)
                                      "of the resource you want to open. This can be a remote URL "
                                      "like \"www.kde.org\" or a local one like \"~/.kderc\""));
     m_runCombo->setDuplicatesEnabled( false );
-    connect( m_runCombo, SIGNAL( textChanged( const QString& ) ),
-             SLOT( slotCmdChanged(const QString&) ) );
+    m_runCombo->setTrapReturnKey( true );
 
     label->setBuddy(m_runCombo);
     m_runCombo->setFixedWidth( m_runCombo->fontMetrics().width('W') * 23 );
 
     m_parseTimer = new QTimer(this);
-    connect(m_parseTimer, SIGNAL(timeout()), SLOT(slotParseTimer()));
 
     m_bAdvanced = false;
     mpAdvanced = 0;
@@ -101,20 +99,19 @@ Minicli::Minicli( QWidget *parent, const char *name)
     if (!kapp->authorize("shell_access"))
        m_btnOptions->hide();
     bbLay->addWidget( m_btnOptions );
-    connect( m_btnOptions, SIGNAL(clicked()), SLOT(slotAdvanced()) );
+
     bbLay->addStretch( 1 );
 
-    btnRun = new KPushButton( KGuiItem( i18n( "&Run" ), "run" ), btnBox );
-    bbLay->addWidget( btnRun );
-    btnRun->setDefault( true );
-    connect( btnRun, SIGNAL(clicked()), this, SLOT(accept()) );
+    m_btnRun = new KPushButton( KGuiItem( i18n( "&Run" ), "run" ), btnBox );
+    bbLay->addWidget( m_btnRun );
+    m_btnRun->setDefault( true );
 
     m_btnCancel = new KPushButton( KStdGuiItem::cancel(), btnBox );
     bbLay->addWidget( m_btnCancel );
-    connect(m_btnCancel, SIGNAL(clicked()), this, SLOT(reject()));
+
     m_vbox->addWidget( btnBox, 3, 0 );
 
-    btnRun->setEnabled(!m_runCombo->currentText().isEmpty());
+    m_btnRun->setEnabled(!m_runCombo->currentText().isEmpty());
     // Very important, to get the size right before showing
     m_vbox->activate();
 
@@ -122,13 +119,18 @@ Minicli::Minicli( QWidget *parent, const char *name)
     m_IconName = QString::null;
     m_FocusWidget = 0;
 
+    connect( m_btnRun, SIGNAL(clicked()), this, SLOT(accept()) );
+    connect( m_btnCancel, SIGNAL(clicked()), this, SLOT(reject()) );
+    connect( m_btnOptions, SIGNAL(clicked()), SLOT(slotAdvanced()) );
+    connect( m_parseTimer, SIGNAL(timeout()), SLOT(slotParseTimer()) );
+
+    connect( m_runCombo, SIGNAL( textChanged( const QString& ) ),
+             SLOT( slotCmdChanged(const QString&) ) );
+    connect( m_runCombo, SIGNAL( activated( const QString& ) ),
+             m_btnRun, SLOT( animateClick() ) );
+
     loadConfig();
     KWin::setState( winId(), NET::StaysOnTop );
-
-    finalFilters = KURIFilter::self()->pluginNames();
-    finalFilters.remove("kuriikwsfilter");
-    middleFilters = finalFilters;
-    middleFilters.remove("localdomainurifilter");
 }
 
 Minicli::~Minicli()
@@ -159,6 +161,12 @@ void Minicli::loadConfig()
         m_runCombo->completionObject()->setItems( compList );
     int mode = config->readNumEntry( "CompletionMode", KGlobalSettings::completionMode() );
     m_runCombo->setCompletionMode( (KGlobalSettings::Completion) mode );
+
+    finalFilters = KURIFilter::self()->pluginNames();
+    finalFilters.remove("kuriikwsfilter");
+
+    middleFilters = finalFilters;
+    middleFilters.remove("localdomainurifilter");
 }
 
 void Minicli::saveConfig()
@@ -174,15 +182,17 @@ void Minicli::saveConfig()
 
 void Minicli::accept()
 {
-    int ret = runCommand();
-
-    if( ret > 0 )
+    hide();
+    if( runCommand() == 1 )
+    {
+        exec();
         return;
+    }
 
-    m_runCombo->addToHistory( m_runCombo->currentText() );
+    m_runCombo->addToHistory( m_runCombo->currentText().stripWhiteSpace() );
     reset();
-    QDialog::accept();
     saveConfig();
+    QDialog::accept();
 }
 
 void Minicli::reject()
@@ -205,6 +215,7 @@ void Minicli::reset()
     m_runCombo->setFocus();
     m_runCombo->reset();
     m_runCombo->blockSignals( block );
+    m_btnRun->setEnabled( false );
 
     m_FocusWidget = 0;
 }
@@ -243,23 +254,34 @@ int Minicli::runCommand()
       return 0;
     }
 
-    bool useTerminal = mpAdvanced && mpAdvanced->terminal();
     QString cmdNoArgs = cmd.stripWhiteSpace();
     {
        int i = cmdNoArgs.find(' ');
        if (i != -1)
           cmdNoArgs.truncate(i);
     }
-    if (!mpAdvanced || mpAdvanced->isHidden()) // Advanced options have not been touched
+
+
+    bool useTerminal = false;
+    if (mpAdvanced)
     {
-       if (terminalAppList.contains(cmdNoArgs))
-          useTerminal = true;
-    }
-    else if (!mpAdvanced->needsKDEsu())
-    {
-       terminalAppList.remove(cmdNoArgs);
-       if (useTerminal)
-          terminalAppList.append(cmdNoArgs);
+        if (mpAdvanced->isHidden()) // Advanced options have not been toucheda
+        {
+            // take the stored setting
+            useTerminal = terminalAppList.contains(cmdNoArgs);
+        }
+        else
+        {
+            terminalAppList.remove(cmdNoArgs);
+
+            if (useTerminal = mpAdvanced->terminal())
+                terminalAppList.append(cmdNoArgs);
+            else
+                useTerminal = terminalAppList.contains(cmdNoArgs);
+
+            /*Now the terminalAppList will contain cmdNoArgs iff the checkbox is marked
+              (provided it is seen by the user)*/
+        }
     }
 
     if (!kapp->authorize("shell_access"))
@@ -278,7 +300,6 @@ int Minicli::runCommand()
                                  "does not exist on this system.</qt>").arg(mpAdvanced->username())); )
                 return 1;
             }
-            user = mpAdvanced->username().local8Bit();
         }
         else
         {
@@ -288,7 +309,29 @@ int Minicli::runCommand()
                 MSGBOX_WRAPPER( KMessageBox::error( this, i18n("You don't exist!\n")); )
                 return 1;
             }
-            user = pw->pw_name;
+        }
+
+        user = pw->pw_name;
+
+        {   // scoped. we want this object to go away before the fork
+            // (maybe not necessary, but can't hurt)
+            // according to the cvs log, creating the SuProcess object in the parent
+            // and using it in the child creates crashes, but we need to check password
+            // before the fork in order to not get in trouble with X for the messagebox
+            SuProcess proc_checkpwd;
+            proc_checkpwd.setUser( user );
+
+            if (mpAdvanced->changeScheduler())
+            {
+                proc_checkpwd.setPriority(mpAdvanced->priority());
+                proc_checkpwd.setScheduler(mpAdvanced->scheduler());
+            }
+
+            if (proc_checkpwd.checkInstall(mpAdvanced->password()) != 0)
+            {
+                MSGBOX_WRAPPER( KMessageBox::sorry(this, i18n("Incorrect password! Please try again.")); )
+                return 1;
+            }
         }
 
         QApplication::flushX();
@@ -303,6 +346,8 @@ int Minicli::runCommand()
             return 0;
         }
 
+        // from here on, this is child...
+
         SuProcess proc;
         proc.setUser(user);
 
@@ -319,18 +364,13 @@ int Minicli::runCommand()
         if (useTerminal)
         {
             KConfigGroupSaver gs(KGlobal::config(), "General");
-            QString terminal=KGlobal::config()->readEntry("TerminalApplication", "konsole").stripWhiteSpace();
+            QString terminal=KGlobal::config()->readPathEntry("TerminalApplication", "konsole").stripWhiteSpace();
             if (terminal.endsWith("konsole"))
                terminal += " --noclose";
             command = terminal.local8Bit() + QCString(" -e /bin/sh -c \"") + command + "\"";
         }
 
         proc.setCommand(command);
-        if (proc.checkInstall(mpAdvanced->password()) < 0)
-        {
-            MSGBOX_WRAPPER( KMessageBox::sorry(this, i18n("Incorrect password! Please try again.")); )
-            return 1;
-        }
 
         // Block SIGCHLD because SuProcess::exec() uses waitpid()
         sigset_t sset;
@@ -344,11 +384,20 @@ int Minicli::runCommand()
     }
     else
     {
+        // yes, this is a hack, but there is no way of doing it
+        // through SuProcess without providing the user password
+        if (mpAdvanced && mpAdvanced->priority() < 50)
+        {
+            int val = 20 - (int) (((double) mpAdvanced->priority()) * 40 / 100 + 0.5); // from kdesu_stub.c
+            cmd = "nice -n " + QString::number( val ) + " " + cmd;
+        }
+
         QString exec;
+
         if (useTerminal)
         {
             KConfigGroupSaver gs(KGlobal::config(), "General");
-            QString terminal=KGlobal::config()->readEntry("TerminalApplication", "konsole").stripWhiteSpace();
+            QString terminal=KGlobal::config()->readPathEntry("TerminalApplication", "konsole").stripWhiteSpace();
             exec = terminal;
             if (terminal.endsWith("konsole"))
                terminal += " --noclose";
@@ -420,6 +469,7 @@ int Minicli::runCommand()
                     return 1;
             }
         }
+
         if ( KRun::runCommand( cmd, exec, m_IconName ) )
         {
             return 0;
@@ -439,7 +489,7 @@ int Minicli::runCommand()
 void Minicli::slotCmdChanged(const QString& text)
 {
     bool state = text.isEmpty();
-    btnRun->setEnabled( !state );
+    m_btnRun->setEnabled( !state );
     if ( state )
     {
         // Reset values to default
@@ -452,6 +502,19 @@ void Minicli::slotCmdChanged(const QString& text)
             m_runIcon->setPixmap(pixmap);
         return;
     }
+    else
+    {
+      QString cmdNoArgs = text.stripWhiteSpace();
+      {
+        int i = cmdNoArgs.find(' ');
+        if (i != -1)
+            cmdNoArgs.truncate(i);
+      }
+
+      // Look if the new app is a TerminalApp
+      if (mpAdvanced)
+        mpAdvanced->slotTerminal(terminalAppList.contains(cmdNoArgs));
+    }
 
     m_parseTimer->start(250, true);
 }
@@ -477,8 +540,7 @@ void Minicli::slotAdvanced()
            int i = cmdNoArgs.find(' ');
            if (i != -1)
                cmdNoArgs.truncate(i);
-           if (terminalAppList.contains(cmdNoArgs))
-              mpAdvanced->slotTerminal(true);
+           mpAdvanced->slotTerminal(terminalAppList.contains(cmdNoArgs));
         }
 
         mpAdvanced->show();
@@ -492,7 +554,6 @@ void Minicli::slotAdvanced()
         m_FocusWidget = focusWidget();
         if( m_FocusWidget )
             m_FocusWidget->setFocus();
-        mpAdvanced->adjustSize();
     }
     else
     {
@@ -502,7 +563,6 @@ void Minicli::slotAdvanced()
             m_FocusWidget->setFocus();
         mpAdvanced->setMaximumSize(0, 0);
         mpAdvanced->setEnabled( false );
-        mpAdvanced->adjustSize();
     }
 }
 
@@ -515,13 +575,14 @@ void Minicli::parseLine( bool final )
 {
     QString cmd = m_runCombo->currentText().stripWhiteSpace();
 
+    m_filterData->setData( cmd );
+
     // Update checkbox if Advanced is visible
     if (m_bAdvanced)
     {
         if ( !m_runCombo->currentText().isEmpty())
         {
            QString cmdNoArgs;
-           m_filterData->setData( cmd );
            if ( m_filterData->uri().isLocalFile() )
               cmdNoArgs = m_filterData->uri().path();
            else
@@ -529,8 +590,6 @@ void Minicli::parseLine( bool final )
            int i = cmdNoArgs.find(' ');
            if (i != -1)
                cmdNoArgs.truncate(i);
-           if (terminalAppList.contains(cmdNoArgs))
-              mpAdvanced->slotTerminal(true);
          }
     }
 
@@ -541,7 +600,6 @@ void Minicli::parseLine( bool final )
     }
     else
     {
-        m_filterData->setData( cmd );
         if( final )
             KURIFilter::self()->filterURI( *(m_filterData), finalFilters );
         else
@@ -634,7 +692,7 @@ MinicliAdvanced::MinicliAdvanced(QWidget *parent, const char *name)
                                    "center position is the default value. For "
                                    "priorities higher than the default, you "
                                    "will need root's password."));
-    mpSlider->setLineStep(5);
+    mpSlider->setLineStep(10);
     connect(mpSlider, SIGNAL(valueChanged(int)), SLOT(slotPriority(int)));
     hbox->addWidget(mpSlider);
     priorityHighLbl = new QLabel(i18n("High"), this);
@@ -775,7 +833,7 @@ void MinicliAdvanced::slotChangeScheduler(bool ena)
 
 bool MinicliAdvanced::needsKDEsu()
 {
-    return ((mbChangeScheduler && ((mPriority != 50) || (mScheduler != StubProcess::SchedNormal)))
+    return ((mbChangeScheduler && ((mPriority > 50) || (mScheduler != StubProcess::SchedNormal)))
             || (mbChangeUid && !mUsername.isEmpty()));
 }
 
