@@ -76,7 +76,7 @@ private:
     KHistoryCombo* m_runCombo;
     KURIFilterData* m_filterData;
     QWidget* m_FocusWidget;
-    QPushButton* btnRun;
+    QPushButton* m_btnRun;
     QGridLayout *m_vbox;
     QStringList terminalAppList;
 
