@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: handler.cpp,v 1.18 2002/04/24 22:57:10 waba Exp $
+ * $Id: handler.cpp,v 1.18.2.1 2003/06/23 12:01:48 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -170,6 +170,8 @@ int ConnectionHandler::doCommand(QCString buf)
 	m_Timeout = l->lval().toInt();
 	if (l->lex() != '\n')
 	    goto parse_error;
+	if (m_Pass.isNull())
+	   m_Pass = "";
 	kdDebug(1205) << "Password set!\n";
 	respond(Res_OK);
 	break;
@@ -249,7 +251,7 @@ int ConnectionHandler::doCommand(QCString buf)
            key = makeKey(0, m_Host, auth_user, command);
            pass = repo->find(key);
         }
-	if (pass.isNull())
+	if (pass.isNull()) // isNull() means no password, isEmpty() can mean empty password
 	{
 	    if (m_Pass.isNull())
 	    {
