@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdesud.cpp,v 1.21 2001/02/09 18:08:07 waba Exp $
+ * $Id: kdesud.cpp,v 1.25 2002/03/09 02:52:23 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -58,14 +58,15 @@
 #include <sys/select.h>		// Needed on some systems.
 #endif
 
-#include <qvector.h>
+#include <qptrvector.h>
 #include <qfile.h>
+#include <qregexp.h>
 
 #include <kinstance.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kaboutdata.h>
 #include <kdesu/client.h>
 #include <kdesu/defaults.h>
@@ -176,7 +177,7 @@ int create_socket()
 
     sock = QFile::encodeName(locateLocal("socket", QString("kdesud_%1").arg(display)));
     int stat_err=lstat(sock, &s);
-    if(!stat_err && S_ISLNK(s.st_ino)) {
+    if(!stat_err && S_ISLNK(s.st_mode)) {
 	kdWarning(1205) << "Someone is running a symlink attack on you\n";
 	if(unlink(sock)) {
 	    kdWarning(1205) << "Could not delete symlink\n";
@@ -301,7 +302,7 @@ int main(int argc, char *argv[])
     maxfd = QMAX(maxfd, x11Fd);
 
     repo = new Repository;
-    QVector<ConnectionHandler> handler;
+    QPtrVector<ConnectionHandler> handler;
     handler.setAutoDelete(true);
 
     // Signal handlers 
