@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: lexer.cpp,v 1.7 2000/05/20 12:47:18 jansen Exp $
+ * $Id: lexer.cpp,v 1.8 2000/11/19 11:59:42 adawit Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -120,6 +120,12 @@ int Lexer::lex()
 		return Tok_delVar;
 	    if (m_Output == "DELG")
 		return Tok_delGroup;
+	    if (m_Output == "DELS")
+		return Tok_delSpecialKey;
+        if (m_Output == "GETK")
+        return Tok_getKeys;
+        if (m_Output == "CHKG")
+        return Tok_chkGroup;
 	}
 
 	return Tok_str;
