@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: secure.h,v 1.2 2000/03/09 20:19:10 jansen Exp $
+ * $Id: secure.h,v 1.3 2000/05/20 16:12:58 kulow Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -19,9 +19,9 @@
 // `struct ucred' is not defined in glibc 2.0.
 
 struct ucred {
-    int32_t   pid;
-    int32_t   uid;
-    int32_t   gid;
+    pid_t     pid;
+    uid_t     uid;
+    gid_t     gid;
 };
 
 #endif // HAVE_STRUCT_UCRED
