@@ -23,12 +23,12 @@
 #include <stdlib.h>
 #include <iostream.h>
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qfile.h>
-#include <qdstream.h>
+#include <qdatastream.h>
 #include <qregexp.h>
 #include <kmessagebox.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 //#include <ktopwidget.h>
 #include <kmainwindow.h>
@@ -83,10 +83,9 @@ int directCommand(KCmdLineArgs *args)
     bool separateOutput = FALSE;
 
     // --title text
-    if (args->isSet("title"))
-    {
-      title = QString::fromLocal8Bit(args->getOption("title"));
-      cout << title.local8Bit().data() << endl;
+    KCmdLineArgs *qtargs = KCmdLineArgs::parsedArgs("qt"); // --title is a qt option
+    if(qtargs->isSet("title")) {
+      title = QFile::decodeName(qtargs->getOption("title"));
     }
 
     // --separate-output
