@@ -1,5 +1,5 @@
 /* $TOG: verify.c /main/37 1998/02/11 10:00:45 kaleb $ */
-/* $Id: client.c,v 2.25 2002/09/20 00:41:24 ossi Exp $ */
+/* $Id: client.c,v 2.25.2.4 2003/06/18 20:05:15 ossi Exp $ */
 /*
 
 Copyright 1988, 1998  The Open Group
@@ -792,7 +792,7 @@ userEnv (struct display *d, int isRoot,
 			  d->defSdMode == SHUT_TRYNOW ? ",tn" : ",sched", 
 		    (char *)0);
 	}
-	if (AnyReserveDisplays ())
+	if ((d->displayType & d_location) == dLocal && AnyReserveDisplays ())
 	    StrApp (&xma, ",rsvd", (char *)0);
     if (xma)
     {
@@ -1248,9 +1248,10 @@ void
 SessionExit (struct display *d, int status)
 {
     /* make sure the server gets reset after the session is over */
-    if (d->serverPid >= 2 && d->resetSignal)
-	TerminateProcess (d->serverPid, d->resetSignal);
-    else
+    if (d->serverPid >= 2) {
+	if (!d->terminateServer && d->resetSignal)
+	    TerminateProcess (d->serverPid, d->resetSignal);
+    } else
 	ResetServer (d);
     if (sourceReset) {
 	/*
