@@ -1,5 +1,5 @@
 /* $TOG: dm.c /main/73 1998/04/09 15:12:03 barstow $ */
-/* $Id: dm.c,v 1.40.2.2 2002/12/12 18:26:23 ossi Exp $ */
+/* $Id: dm.c,v 1.40.2.3 2003/04/02 12:14:50 ossi Exp $ */
 /*
 
 Copyright 1988, 1998  The Open Group
@@ -721,7 +721,7 @@ parseSd (char **ar, int *how, int *when, int wdef)
 	return 0;
     *how = 0;
     if (!ar[1] || (!ar[2] && wdef < 0)) {
-	LogInfo ("Missing argument(s) to fifo command shutdown\n");
+	LogInfo ("Missing argument(s) to fifo command 'shutdown'\n");
 	return 1;
     }
     if (ar[2]) {
@@ -732,7 +732,7 @@ parseSd (char **ar, int *how, int *when, int wdef)
 	else if (!strcmp (ar[2], "schedule"))
 	    *when = SHUT_SCHEDULE;
 	else {
-	    LogInfo ("Invalid mode spec %'s to fifo command shutdown\n", ar[2]);
+	    LogInfo ("Invalid mode spec %'s to fifo command 'shutdown'\n", ar[2]);
 	    return 1;
 	}
     } else
@@ -742,7 +742,7 @@ parseSd (char **ar, int *how, int *when, int wdef)
     else if (!strcmp (ar[1], "halt"))
 	*how = SHUT_HALT;
     else
-	LogInfo ("Invalid type spec %'s to fifo command shutdown\n", ar[1]);
+	LogInfo ("Invalid type spec %'s to fifo command 'shutdown'\n", ar[1]);
     return 1;
 }
 
@@ -762,16 +762,15 @@ processDFifo (const char *buf, int len, void *ptr)
 	if (d->allowShutdown == SHUT_NONE ||
 	    (d->allowShutdown == SHUT_ROOT && d->userSess))
 	{
-	    LogInfo ("Insufficient priviledges for system shutdown "
-		     "via command fifo\n");
+	    LogInfo ("Display %s attempted fifo command 'shutdown'\n", d->name);
 	    return;
 	}
 	if (when == SHUT_FORCENOW &&
 	    (d->allowNuke == SHUT_NONE ||
 	    (d->allowNuke == SHUT_ROOT && d->userSess)))
 	{
-	    LogInfo ("Insufficient priviledges for forced system shutdown "
-		     "via command fifo\n");
+	    LogInfo ("Display %s attempted fifo command 'shutdown forcenow'\n",
+		     d->name);
 	    return;
 	}
 	d->hstent->sd_how = how;
@@ -788,17 +787,20 @@ processDFifo (const char *buf, int len, void *ptr)
 	ReapReserveDisplays ();
 #endif
     } else if (!strcmp (ar[0], "reserve")) {
-	int lt = 0;
-	if (ar[1])
-	    lt = atoi (ar[1]);
-	StartReserveDisplay (lt ? lt : 60); /* XXX maybe make configurable? */
+	if ((d->displayType & d_location) == dLocal) {
+	    int lt = 0;
+	    if (ar[1])
+		lt = atoi (ar[1]);
+	    StartReserveDisplay (lt ? lt : 60); /* XXX maybe make configurable? */
+	} else
+	    LogInfo ("Remote display %s attempted fifo command 'reserve'\n", d->name);
     } else if (!strcmp (ar[0], "suicide")) {
 	if (d->pid != -1) {
 	    TerminateProcess (d->pid, SIGTERM);
 	    d->status = raiser;
 	}
     } else
-	LogInfo ("Invalid fifo command %'s\n", ar[0]);
+	LogInfo ("Invalid fifo command %'s from display %s\n", ar[0], d->name);
     freeStrArr (ar);
 }
 
@@ -831,7 +833,7 @@ processFifo (const char *buf, int len, void *ptr ATTR_UNUSED)
 	    return;
 	}
 	if (!(d = FindDisplayByName (ar[1]))) {
-	    LogInfo ("Display %s in fifo command %s not found\n", ar[1], ar[0]);
+	    LogInfo ("Display %s in fifo command '%s' not found\n", ar[1], ar[0]);
 	    return;
 	}
 	setNLogin (d, 
