@@ -1,5 +1,5 @@
 /* $TOG: dm.h /main/67 1998/02/09 13:55:01 kaleb $ */
-/* $Id: dm.h,v 1.40.2.1 2002/04/19 11:40:08 ossi Exp $ */
+/* $Id: dm.h,v 1.43 2002/09/20 00:37:09 ossi Exp $ */
 /*
 
 Copyright 1988, 1998  The Open Group
@@ -376,6 +376,8 @@ extern struct display
 	*FindDisplayByServerPid (int serverPid),
 	*NewDisplay (const char *name, const char *class2);
 extern int AnyActiveDisplays (void);
+extern int AnyRunningDisplays (void);
+extern int AnyReserveDisplays (void);
 extern int AllLocalDisplaysLocked (struct display *dp);
 extern void StartReserveDisplay (int lt);
 extern void ReapReserveDisplays (void);
@@ -397,7 +399,7 @@ extern void delStr (RcStr *str);
 extern char **defaultEnv (const char *user);
 extern char **inheritEnv (char **env, const char **what);
 extern char **systemEnv (struct display *d, const char *user, const char *home);
-extern int source (char **environ, char *file);
+extern int source (char **env, char *file);
 extern void DeleteXloginResources (struct display *d);
 extern void LoadXloginResources (struct display *d);
 extern void ManageSession (struct display *d);
@@ -407,12 +409,18 @@ extern void StopDisplay (struct display *d);
 extern void WaitForChild (void);
 
 /* process.c */
+#include <stdlib.h>
+
+typedef SIGVAL (*SIGFUNC)(int);
+
+SIGVAL (*Signal(int, SIGFUNC Handler))(int);
+
 extern void RegisterCloseOnFork (int fd);
 extern void CloseNClearCloseOnFork (int fd);
 extern int Fork (void);
 extern int Wait4 (int pid);
-extern void execute (char **argv, char **environ);
-extern int runAndWait (char **args, char **environ);
+extern void execute (char **argv, char **env);
+extern int runAndWait (char **args, char **env);
 extern void TerminateProcess (int pid, int sig);
 extern Jmp_buf GErrJmp;
 extern const char *GOpen (char **argv, const char *what, char **env);
@@ -536,10 +544,7 @@ extern void RunChooser (struct display *d);
 
 #endif /* XDMCP */
 
-#include <stdlib.h>
-
-typedef SIGVAL (*SIGFUNC)(int);
-
-SIGVAL (*Signal(int, SIGFUNC Handler))(int);
+/* automatically fork off reserve display if all displays are locked */
+/*#define AUTO_RESERVE 1*/
 
 #endif /* _DM_H_ */
