@@ -1,5 +1,5 @@
 /* $TOG: session.c /main/79 1998/02/09 13:56:17 kaleb $ */
-/* $Id: session.c,v 1.68 2002/03/23 14:32:55 ossi Exp $ */
+/* $Id: session.c,v 1.70 2002/10/09 00:48:28 ossi Exp $ */
 /*
 
 Copyright 1988, 1998  The Open Group
@@ -490,11 +490,12 @@ DeleteXloginResources (struct display *d)
 	for (i = ScreenCount(d->dpy); --i >= 0; )
 	    XDeleteProperty(d->dpy, RootWindow (d->dpy, i), prop);
     }
+    XSync(d->dpy, 0);
 }
 
 
 int
-source (char **environ, char *file)
+source (char **env, char *file)
 {
     char	**args, *args_safe[2];
     int		ret;
@@ -507,9 +508,9 @@ source (char **environ, char *file)
 	    args = args_safe;
 	    args[0] = file;
 	    args[1] = NULL;
-	    return runAndWait (args, environ);
+	    return runAndWait (args, env);
 	}
-	ret = runAndWait (args, environ);
+	ret = runAndWait (args, env);
 	freeStrArr (args);
 	return ret;
     }
