@@ -1,10 +1,14 @@
 /* $TOG: util.c /main/19 1998/02/09 13:56:40 kaleb $ */
-/* $Id: util.c,v 1.18.2.2 2001/10/03 10:47:11 ossi Exp $ */
+/* $Id: util.c,v 1.26 2002/03/23 14:32:55 ossi Exp $ */
 /*
 
 Copyright 1989, 1998  The Open Group
 
-All Rights Reserved.
+Permission to use, copy, modify, distribute, and sell this software and its
+documentation for any purpose is hereby granted without fee, provided that
+the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation.
 
 The above copyright notice and this permission notice shall be included
 in all copies or substantial portions of the Software.
@@ -43,11 +47,6 @@ from The Open Group.
 # include <unistd.h>
 #endif
 
-#include <errno.h>
-#ifdef X_NOT_STDC_ENV
-extern int errno;
-#endif
-
 #ifdef USG
 # define NEED_UTSNAME
 #endif
@@ -68,7 +67,7 @@ WipeStr (char *str)
 
 /* duplicate src; wipe & free old dst string */
 int
-ReStrN (char **dst, char *src, int len)
+ReStrN (char **dst, const char *src, int len)
 {
     char *ndst = 0;
 
@@ -88,14 +87,14 @@ ReStrN (char **dst, char *src, int len)
 }
 
 int
-ReStr (char **dst, char *src)
+ReStr (char **dst, const char *src)
 {
     return ReStrN (dst, src, -1);
 }
 
 /* duplicate src */
 int
-StrNDup (char **dst, char *src, int len)
+StrNDup (char **dst, const char *src, int len)
 {
     if (src) {
 	if (len < 0)
@@ -110,7 +109,7 @@ StrNDup (char **dst, char *src, int len)
 }
 
 int
-StrDup (char **dst, char *src)
+StrDup (char **dst, const char *src)
 {
     return StrNDup (dst, src, -1);
 }
@@ -168,7 +167,7 @@ initStrArr (char **arr)
     return arr;
 }
 
-static int
+int
 arrLen (char **arr)
 {
     int nu = 0;
@@ -193,7 +192,7 @@ extStrArr (char ***arr)
 }
 
 char **
-addStrArr (char **arr, char *str, int len)
+addStrArr (char **arr, const char *str, int len)
 {
     char **dst;
 
@@ -206,13 +205,11 @@ char **
 xCopyStrArr (int rn, char **arr)
 {
     char **rarr;
-    int nnu, nu, i;
+    int nu;
 
     nu = arrLen (arr);
-    nnu = nu + rn;
-    if ((rarr = calloc (sizeof (char *), nnu + 1)))
-	for (i = 0; i < nu; i++)
-	    rarr[rn + i] = arr[i];
+    if ((rarr = calloc (sizeof(char *), nu + rn + 1)))
+	memcpy (rarr + rn, arr, sizeof(char *) * nu);
     return rarr;
 }
 
@@ -220,12 +217,11 @@ void
 mergeStrArrs (char ***darr, char **arr)
 {
     char **rarr;
-    int nu, i;
+    int nu;
 
     nu = arrLen (*darr);
     if ((rarr = xCopyStrArr (nu, arr))) {
-	for (i = 0; i < nu; i++)
-	    rarr[i] = (*darr)[i];
+	memcpy (rarr, *darr, sizeof(char *) * nu);
 	free (*darr);
 	*darr = rarr;
     }
@@ -245,17 +241,18 @@ freeStrArr (char **arr)
 
 
 char **
-parseArgs (char **argv, char *string)
+parseArgs (char **argv, const char *string)
 {
-    char *word, ch;
+    const char *word;
+    char ch;
 
     argv = initStrArr (argv);
     for (word = string; ; ++string) {
 	ch = *string;
-	if (!ch || ch == '\n' || ch == '#' || ch == ' ' || ch == '\t') {
+	if (!ch || ch == ' ' || ch == '\t') {
 	    if (word != string)
 		argv = addStrArr (argv, word, string - word);
-	    if (!ch || ch == '\n' || ch == '#')
+	    if (!ch)
 		return argv;
 	    word = string + 1;
 	}
@@ -263,78 +260,60 @@ parseArgs (char **argv, char *string)
 }
 
 
-static char *
-makeEnv (char *name, char *value)
+const char *
+getEnv (char **e, const char *name)
 {
-    char *result;
-
-    result = malloc ((unsigned) (strlen (name) + strlen (value) + 2));
-    if (!result) {
-	LogOutOfMem ("makeEnv");
-	return 0;
-    }
-#ifdef AIXV3
-    /* setpenv() depends on "SYSENVIRON:", not "SYSENVIRON:=" */
-    if (!(value && *value))
-	sprintf (result, "%s", name);
-    else
-#endif
-	sprintf (result, "%s=%s", name, value);
-    return result;
-}
-
-char *
-getEnv (char **e, char *name)
-{
-    int l = strlen (name);
-
-    if (!e)
-	return 0;
-
-    while (*e) {
-	if ((int) strlen (*e) > l && !strncmp (*e, name, l) &&
-	    (*e)[l] == '=')
-	    return (*e) + l + 1;
-	++e;
+    if (e) {
+	int l = strlen (name);
+	for (; *e; e++)
+	    if (!memcmp (*e, name, l) && (*e)[l] == '=')
+		return (*e) + l + 1;
     }
     return 0;
 }
 
 char **
-setEnv (char **e, char *name, char *value)
+setEnv (char **e, const char *name, const char *value)
 {
     char **new, **old;
     char *newe;
     int envsize;
     int l;
 
-    l = strlen (name);
-    newe = makeEnv (name, value);
-    if (!newe) {
-	LogOutOfMem ("setEnv");
-	return e;
-    }
-    if (e) {
-	for (old = e; *old; old++)
-	    if ((int) strlen (*old) > l && !strncmp (*old, name, l)
-		&& (*old)[l] == '=')
-		break;
-	if (*old) {
-	    free (*old);
-	    *old = newe;
+#ifdef AIXV3
+    /* setpenv() depends on "SYSENVIRON:", not "SYSENVIRON:=" */
+    if (!value) {
+	if (!StrDup (&newe, name)) {
+	    LogOutOfMem ("setEnv");
+	    return e;
+	}
+    } else
+#endif
+    {
+	newe = 0;
+	if (!StrApp (&newe, name, "=", value, (char *)0)) {
+	    LogOutOfMem ("setEnv");
 	    return e;
 	}
-	envsize = old - e;
-	new = (char **) realloc ((char *) e,
-				 (unsigned) ((envsize + 2) * 
-					     sizeof (char *)));
-    } else {
-	envsize = 0;
-	new = (char **) malloc (2 * sizeof (char *));
     }
-    if (!new) {
-	LogOutOfMem ("setEnv");
+    envsize = 0;
+    if (e) {
+	l = strlen (name);
+	for (old = e; *old; old++)
+	    if (!memcmp (*old, name, l) && ((*old)[l] == '=' || !(*old)[l]))
+	    {
+		free (*old);
+		*old = newe;
+		return e;
+	    }
+	envsize = old - e;
+    }
+    if (!(new = (char **) 
+	    realloc ((char *) e,
+		     (unsigned) ((envsize + 2) * sizeof (char *)))))
+    {
 	free (newe);
+	LogOutOfMem ("setEnv");
 	return e;
     }
     new[envsize] = newe;
@@ -343,26 +322,18 @@ setEnv (char **e, char *name, char *value)
 }
 
 char **
-putEnv(char *string, char **env)
+putEnv(const char *string, char **env)
 {
-    char *v, *b, *n;
-    int nl;
-  
-    if ((b = strchr(string, '=')) == NULL)
+    char *b, *n;
+
+    if (!(b = strchr(string, '=')))
 	return NULL;
-    v = b + 1;
-  
-    nl = b - string;
-    if ((n = malloc(nl + 1)) == NULL)
+    if (!StrNDup (&n, string, b - string))
     {
 	LogOutOfMem ("putEnv");
 	return NULL;
     }
-  
-    memcpy(n, string, nl);
-    n[nl] = 0;
-  
-    env = setEnv(env, n, v);
+    env = setEnv(env, n, b + 1);
     free(n);
     return env;
 }
@@ -395,7 +366,7 @@ GetHostname(char *buf, int maxlen)
 static char localHostbuf[256];
 static int  gotLocalHostname;
 
-char *
+const char *
 localHostname (void)
 {
     if (!gotLocalHostname)
@@ -429,7 +400,7 @@ Reader (int fd, void *buf, int count)
 }
 
 void
-FdGetsCall (int fd, void (*func)(char *, int, void *), void *ptr)
+FdGetsCall (int fd, void (*func)(const char *, int, void *), void *ptr)
 {
     char	*p;
     int		bpos, bend, llen, ll, rt, ign;
