@@ -3,7 +3,7 @@
     Create a suitable configuration for kdm taking old xdm/kdm 
     installations into account
 
-    $Id: genkdmconf.c,v 1.43.2.2 2002/11/28 17:49:41 ossi Exp $
+    $Id: genkdmconf.c,v 1.43.2.7 2003/05/19 22:17:36 ossi Exp $
 
     Copyright (C) 2001-2002 Oswald Buddenhagen <ossi@kde.org>
 
@@ -466,7 +466,7 @@ wrconf (FILE *f)
 #endif
 
 #ifndef DEF_AUTH_NAME
-# ifdef HASXDMAUTH
+# if 0 /*def HASXDMAUTH*/
 #  define DEF_AUTH_NAME	"XDM-AUTHORIZATION-1,MIT-MAGIC-COOKIE-1"
 # else
 #  define DEF_AUTH_NAME	"MIT-MAGIC-COOKIE-1"
@@ -1347,7 +1347,7 @@ mk_willing(Entry *ce, Section *cs ATTR_UNUSED)
 }
 
 static int
-edit_resources(File *file, char **nbuf ATTR_UNUSED, int *nlen ATTR_UNUSED)
+edit_resources(File *file ATTR_UNUSED, char **nbuf ATTR_UNUSED, int *nlen ATTR_UNUSED)
 {
     /* XXX remove any login*, chooser*, ... resources */
     return 0;
@@ -1626,14 +1626,14 @@ upd_hiddenusers(Entry *ce, Section *cs ATTR_UNUSED)
 	return;
 
     msu = getfqval (cs->name, "MinShowUID", "0");
-    sscanf (msu, "%d", &minuid);
+    sscanf (msu, "%u", &minuid);
     msu = getfqval (cs->name, "MaxShowUID", "65535");
-    sscanf (msu, "%d", &maxuid);
+    sscanf (msu, "%u", &maxuid);
 
     nv = 0;
     pt = ce->value;
     for (;;) {
-	et = strchr (pt, ',');
+	et = strpbrk (pt, ";,");
 	if (et) {
 	    memcpy (nbuf, pt, et - pt);
 	    nbuf[et - pt] = 0;
@@ -1892,12 +1892,11 @@ static Ent entsGreeter[] = {
 "# \"failsafe\" listed herein, which is also the default.\n"
 "# Note, that the meaning of this value is entirely up to your Session program.\n" },
 { "GUIStyle",		0, upd_guistyle, 
-"# Widget Style of the greeter:\n"
-"# Default, Windows, Platinum, Motif, MotifPlus, CDE, SGI, and any styles you\n"
-"# may have installed, e.g., HighColor; Default is \"Default\"\n" },
+"# Widget style of the greeter. \"\" means the built-in default which currently\n"
+"# is \"Keramik\". Default is \"\"\n" },
 { "ColorScheme",		0, 0, 
-"# Widget Colors of the greeter:\n"
-"# Default, and any color schemes you may have installed. Default is \"Default\"\n" },
+"# Widget color scheme of the greeter. \"\" means the built-in default which\n"
+"# currently is quite greyish. Default is \"\"\n" },
 { "LogoArea",		0, upd_logoarea, 
 "# What should be shown righthand of the input lines:\n"
 "# \"Logo\" - the image specified by LogoPixmap (Default)\n"
@@ -2712,8 +2711,6 @@ is22conf (const char *path)
 static int
 mergeKdmRcNewer (const char *path)
 {
-    Section *cs;
-    Entry *ce;
     char *p, *p2;
 
     ASPrintf (&p, "%s/kdm/kdmrc", path);
