@@ -2,7 +2,7 @@
 
     Read options from kdmrc
 
-    $Id: kdm_config.c,v 1.31 2002/09/19 23:44:17 ossi Exp $
+    $Id: kdm_config.c,v 1.31.2.3 2003/05/19 22:17:36 ossi Exp $
 
     Copyright (C) 2001-2002 Oswald Buddenhagen <ossi@kde.org>
 
@@ -530,8 +530,8 @@ Ent entsCore[] = {
 
 Ent entsGreeter[] = {
 { "SessionTypes",	C_SessionTypes,		0,	"default,failsafe" },
-{ "GUIStyle",		C_GUIStyle, 		0,	"KDE" },
-{ "ColorScheme",	C_ColorScheme,		0,	"Default" },
+{ "GUIStyle",		C_GUIStyle, 		0,	"" },
+{ "ColorScheme",	C_ColorScheme,		0,	"" },
 { "LogoArea",		C_LogoArea | C_ENUM, logoarea,	"Logo" },
 { "LogoPixmap",		C_LogoPixmap,		0,	"" },
 { "GreeterPosFixed",	C_GreeterPosFixed | C_BOOL, 0,	"false" },
