@@ -1,7 +1,7 @@
     /*
 
     Configuration for kdm. Class KDMConfig
-    $Id: kdmconfig.h,v 1.21 2002/08/28 18:19:03 ossi Exp $
+    $Id: kdmconfig.h,v 1.21.2.1 2003/05/06 01:06:49 ossi Exp $
 
     Copyright (C) 1997, 1998, 2000 Steffen Hansen <hansen@kde.org>
     Copyright (C) 2000-2002 Oswald Buddenhagen <ossi@kde.org>
@@ -29,15 +29,10 @@
 
 #include <qnamespace.h>
 #include <qstring.h>
-#include <qstrlist.h>
+#include <qstringlist.h>
 #include <qfont.h>
 #include <qpalette.h>
 
-#include <ksimpleconfig.h>	// need it here for "make final"
-
-#include <sys/param.h>	// for BSD
-#include <unistd.h>
-
 QString GetCfgQStr (int id);
 QStringList GetCfgQStrList (int id);
 
