@@ -1,7 +1,7 @@
     /*
 
     Greeter module for xdm
-    $Id: kgreeter.cpp,v 1.83.2.1 2002/12/28 02:01:34 ossi Exp $
+    $Id: kgreeter.cpp,v 1.83.2.8 2003/05/11 22:49:46 ossi Exp $
 
     Copyright (C) 1997, 1998, 2000 Steffen Hansen <hansen@kde.org>
     Copyright (C) 2000-2002 Oswald Buddenhagen <ossi@kde.org>
@@ -25,40 +25,33 @@
 
 #include <config.h>
 
+#include "kgreeter.h"
+#include "kdmshutdown.h"
+#include "kdmconfig.h"
+#include "kdmclock.h"
+#include "kdm_greet.h"
+#include "kdm_config.h"
+
+#include <klocale.h>
+#include <kstandarddirs.h>
+#include <kseparator.h>
+#include <kprocess.h>
+#include <kpassdlg.h>
+#include <klistview.h>
+#include <ksimpleconfig.h>
+
 #include <qfile.h>
-#include <qpixmap.h>
 #include <qimage.h>
-#include <qtextstream.h>
 #include <qpopupmenu.h>
 #include <qtimer.h>
 #include <qcombobox.h>
-#include <qstring.h>
 #include <qaccel.h>
 #include <qcursor.h>
 #include <qheader.h>
-
-#include <klocale.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <kmessagebox.h>
-#include <kseparator.h>
-#include <kapplication.h>
-#include <kprocess.h>
-
-#include "kgreeter.h"
-#include "kdmconfig.h"
-#include "kdmclock.h"
-#include "kfdialog.h"
-#include "kdm_greet.h"
-
-extern "C" {
-#ifdef HAVE_XKB
-// note: some XKBlib.h versions contain a global variable definition
-// called "explicit". This keyword is not allowed on some C++ compilers so ->
-# define explicit __explicit_dummy
-# include <X11/XKBlib.h>
-#endif
-};
+#include <qstyle.h>
+#include <qlayout.h>
+#include <qlabel.h>
+#include <qpushbutton.h>
 
 #include <sys/param.h>
 #include <sys/stat.h>
@@ -68,13 +61,7 @@ extern "C" {
 #include <unistd.h>
 #include <strings.h>
 
-
-class GreeterListViewItem : public KListViewItem {
-public:
-    GreeterListViewItem( KListView* parent, const QString& text )
-	: KListViewItem( parent, text ) {};
-    QString login;
-};
+#include <X11/Xlib.h>
 
 void
 KLoginLineEdit::focusOutEvent( QFocusEvent *e )
@@ -84,6 +71,41 @@ KLoginLineEdit::focusOutEvent( QFocusEvent *e )
 }
 
 
+class UserListView : public KListView {
+public:
+    UserListView( QWidget* parent = 0, const char *name = 0 )
+	: KListView( parent, name )
+	, cachedSizeHint( -1, 0 )
+    {
+	setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Ignored );
+	header()->hide();
+	addColumn( QString::null );
+	setColumnAlignment( 0, AlignVCenter );
+	setResizeMode( QListView::LastColumn );
+    }
+
+    mutable QSize cachedSizeHint;
+
+protected:
+    virtual QSize sizeHint() const
+    {
+	if (!cachedSizeHint.isValid()) {
+	    constPolish();
+	    uint maxw = 0;
+	    for (QListViewItem *itm = firstChild(); itm; itm = itm->nextSibling()) {
+		uint thisw = itm->width( fontMetrics(), this, 0 );
+		if (thisw > maxw)
+		    maxw = thisw;
+	    }
+	    cachedSizeHint.setWidth(
+		style().pixelMetric( QStyle::PM_ScrollBarExtent ) +
+		frameWidth() * 2 + maxw );
+	}
+	return cachedSizeHint;
+    }
+};
+
+
 KGreeter::KGreeter()
   : inherited( 0, 0, true )
   , user_view( 0 )
@@ -92,6 +114,9 @@ KGreeter::KGreeter()
   , capslocked( -1 )
   , loginfailed( false )
 {
+    user_pic_dir = KGlobal::dirs()->resourceDirs( "data" ).last() +
+				      QString::fromLatin1("kdm/pics/users/");	/* XXX standardize */
+
     QGridLayout* main_grid = new QGridLayout( winFrame, 4, 2, 10 );
     QBoxLayout* hbox1 = new QHBoxLayout( 10 );
     QBoxLayout* hbox2 = new QHBoxLayout( 10 );
@@ -105,11 +130,7 @@ KGreeter::KGreeter()
 	main_grid->addWidget( welcomeLabel, 0, 1 );
     }
     if (kdmcfg->_showUsers != SHOW_NONE) {
-	user_view = new KListView( winFrame );
-	user_view->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Ignored ) );
-	user_view->addColumn(QString::null);
-	user_view->setResizeMode(QListView::LastColumn);
-	user_view->header()->hide();
+	user_view = new UserListView( winFrame );
 	insertUsers( user_view );
 	main_grid->addMultiCellWidget(user_view, 0, 3, 0, 0);
 	connect( user_view, SIGNAL(clicked( QListViewItem * )),
@@ -275,14 +296,30 @@ KGreeter::~KGreeter()
     delete stsfile;
 }
 
+class UserListViewItem : public KListViewItem {
+public:
+    UserListViewItem( UserListView *parent, const QString &text,
+			 const QPixmap &pixmap, const QString &username )
+	: KListViewItem( parent )
+	, login( username )
+    {
+	setPixmap( 0, pixmap );
+	setMultiLinesEnabled( true );
+	setText( 0, text );
+	parent->cachedSizeHint.setWidth( -1 );
+    }
+
+    QString login;
+};
+
 void
-KGreeter::insertUser( KListView *listview, const QImage &default_pix,
+KGreeter::insertUser( UserListView *listview, const QImage &default_pix,
 		      const QString &username, struct passwd *ps )
 {
     QImage p;
     if (kdmcfg->_faceSource != FACE_USER_ONLY &&
 	kdmcfg->_faceSource != FACE_PREFER_USER)
-	p = QPixmap( locate( "user_pic", username + ".png" ) );
+	p = QPixmap( user_pic_dir + username + ".png" );
     if (p.isNull() && kdmcfg->_faceSource != FACE_ADMIN_ONLY) {
 	// XXX remove seteuid-voodoo when we run as nobody
 	seteuid( ps->pw_uid );
@@ -290,26 +327,25 @@ KGreeter::insertUser( KListView *listview, const QImage &default_pix,
 	seteuid( 0 );
     }
     if (p.isNull() && kdmcfg->_faceSource != FACE_USER_ONLY)
-	p = QPixmap( locate( "user_pic", username + ".png" ) );
+	p = QPixmap( user_pic_dir + username + ".png" );
     if (p.isNull())
 	p = default_pix;
     else
 	p = p.smoothScale( 48, 48, QImage::ScaleMin );
     QString realname = QFile::decodeName( ps->pw_gecos );
-    realname = realname.left(realname.find(","));
-    QString userlabel = realname.isEmpty() ?
-				username :
-				realname + "\n" + username;
-    GreeterListViewItem *item = new GreeterListViewItem( listview, userlabel );
-    item->setPixmap( 0, QPixmap( p ) );
-    item->login = username;
+    realname.truncate( realname.find( ',' ) );
+    if (realname.isEmpty())
+	new UserListViewItem( listview, username, QPixmap( p ), username );
+    else {
+	realname.append( "\n" ).append( username );
+	new UserListViewItem( listview, realname, QPixmap( p ), username );
+    }
 }
 
 void
-KGreeter::insertUsers( KListView *listview )
+KGreeter::insertUsers( UserListView *listview )
 {
-    QImage default_pix(
-	locate( "user_pic", QString::fromLatin1("default.png") ) );
+    QImage default_pix( user_pic_dir + QString::fromLatin1("default.png") );
     if (default_pix.isNull())
 	LogError("Can't open default pixmap \"default.png\"\n");
     default_pix = default_pix.smoothScale( 48, 48, QImage::ScaleMin );
@@ -372,7 +408,7 @@ KGreeter::sel_user()
 	QString login = loginEdit->text();
 	QListViewItem *item;
 	for (item = user_view->firstChild(); item; item = item->nextSibling())
-	    if (((GreeterListViewItem *)item)->login == login) {
+	    if (((UserListViewItem *)item)->login == login) {
 		user_view->setCurrentItem( item );
 		user_view->ensureItemVisible( item );
 		break;
@@ -385,7 +421,7 @@ void
 KGreeter::slot_user_name( QListViewItem *item )
 {
     if (item) {
-	loginEdit->setText( ((GreeterListViewItem *)item)->login );
+	loginEdit->setText( ((UserListViewItem *)item)->login );
 	passwdEdit->erase();
 	passwdEdit->setFocus();
 	load_wm();
@@ -651,7 +687,7 @@ KGreeter::verifyUser(bool haveto)
 		expire = GRecvInt ();
 		if (!expire)
 		    MsgBox (infobox, i18n("Your account expires today."));
-		if (expire == 1)
+		else if (expire == 1)
 		    MsgBox (infobox, i18n("Your account expires tomorrow."));
 		else
 		    MsgBox (infobox, 
@@ -661,7 +697,7 @@ KGreeter::verifyUser(bool haveto)
 		expire = GRecvInt ();
 		if (!expire)
 		    MsgBox (infobox, i18n("Your password expires today."));
-		if (expire == 1)
+		else if (expire == 1)
 		    MsgBox (infobox, i18n("Your password expires tomorrow."));
 		else
 		    MsgBox (infobox, 
@@ -786,22 +822,6 @@ kg_main( int argc, char **argv )
 
     app.setFont( kdmcfg->_normalFont );
 
-    KGlobal::dirs()->addResourceType( "user_pic",
-				      KStandardDirs::kde_default("data") +
-				      QString::fromLatin1("kdm/pics/users/") );
-
-
-#ifdef HAVE_XKBSETPERCLIENTCONTROLS
-    //
-    //  Activate the correct mapping for modifiers in XKB extension as
-    //  grabbed keyboard has its own mapping by default
-    //
-    int opcode, evbase, errbase, majret, minret;
-    unsigned int value = XkbPCF_GrabsUseXKBStateMask;
-    if (XkbQueryExtension( dpy, &opcode, &evbase,
-                           &errbase, &majret, &minret ))
-        XkbSetPerClientControls( dpy, value, &value );
-#endif
     setup_modifiers( dpy, kdmcfg->_numLockStatus );
     SecureDisplay( dpy );
     if (!dgrabServer) {
@@ -816,6 +836,7 @@ kg_main( int argc, char **argv )
 	GSendInt( G_SetupDpy );
 	GRecvInt();
     }
+
     QDesktopWidget *dsk = kapp->desktop();
     QRect scr = dsk->screenGeometry(
 	kdmcfg->_greeterScreen == -1 ?
@@ -824,10 +845,9 @@ kg_main( int argc, char **argv )
 		dsk->screenNumber( QPoint( dsk->width() - 1, 0 ) ) :
 		kdmcfg->_greeterScreen );
     KGreeter *kgreeter = new KGreeter;
-    kgreeter->setMaximumSize( scr.size() );
-    kgreeter->move( -10000, -10000 );
-    kgreeter->show();
-    QRect grt( QPoint( 0, 0 ), kgreeter->sizeHint() );
+    kgreeter->setMaximumSize( scr.size() * .9 );
+    kgreeter->adjustSize();
+    QRect grt( 0, 0, kgreeter->width(), kgreeter->height() );
     if (kdmcfg->_greeterPosX >= 0) {
 	grt.moveCenter( QPoint( kdmcfg->_greeterPosX, kdmcfg->_greeterPosY ) );
 	moveInto( grt, scr );
@@ -838,7 +858,7 @@ kg_main( int argc, char **argv )
     if (dsk->screenNumber( QCursor::pos() ) !=
 	dsk->screenNumber( grt.center() ))
 	QCursor::setPos( grt.center() );
-    XUndefineCursor( dpy, RootWindow( dpy, DefaultScreen( dpy ) ) );
+    dsk->setCursor( Qt::ArrowCursor );
     Debug ("entering event loop\n");
     kgreeter->exec();
     delete kgreeter;
