@@ -9,6 +9,7 @@
 
 #include <klocale.h>
 #include <kglobal.h>
+#include <kguiitem.h>
 #include <kstatusbar.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
@@ -22,10 +23,12 @@
 #include "kfinddlg.moc"
 
 KfindDlg::KfindDlg(const KURL & url, QWidget *parent, const char *name)
-  : KDialogBase( Plain, QString::null, 
+  : KDialogBase( Plain, QString::null,
 	User1 | User2 | User3 | Apply | Close | Help, User1,
         parent, name, true, true,
-	i18n("&Find"), i18n("Stop"), i18n("Save...") )
+	KGuiItem(i18n("&Find"), "find"),
+	KGuiItem(i18n("Stop"), "stop"),
+	KStdGuiItem::saveAs())
 {
   QWidget::setCaption( i18n("Find Files" ) );
   setButtonBoxOrientation(Vertical);
@@ -37,7 +40,7 @@ KfindDlg::KfindDlg(const KURL & url, QWidget *parent, const char *name)
   setEscapeButton(User2);
 
   setButtonApplyText(i18n("About"));
-  
+
   // remove misleading default help
   setButtonWhatsThis(Apply,QString::null);
   setButtonTip(Apply,QString::null);
@@ -105,14 +108,15 @@ void KfindDlg::setStatusMsg(const QString &msg)
    mStatusBar->changeItem(msg, 0);
 }
 
+
 void KfindDlg::startSearch()
 {
   tabWidget->setQuery(query);
 
   isResultReported = false;
 
-  // Reset count
-  setProgressMsg(i18n("%1 files found").arg(0));
+  // Reset count - use the same i18n as below
+  setProgressMsg(i18n("one file found", "%n files found", 0));
   setStatusMsg(i18n("Searching..."));
 
   emit resultSelected(false);
@@ -183,12 +187,7 @@ void KfindDlg::addFile(const KFileItem* item, const QString& matchingLine)
   }
 
   int count = win->childCount();
-  QString str;
-  if (count == 1)
-    str = i18n("1 file found");
-  else
-    str = i18n("%1 files found")
-      .arg(KGlobal::locale()->formatNumber(count, 0));
+  QString str = i18n("one file found", "%n files found", count);
   setProgressMsg(str);
 }
 
