@@ -48,7 +48,7 @@ public:
   void setURL( const KURL & url );
 
 public slots:
-  void setFocus() { nameBox->setFocus(); }
+  void setFocus();
 
 private slots:
   void getDirectory();
@@ -57,7 +57,7 @@ private slots:
   void slotEditRegExp();
 
 signals:
-  void startSearch();
+    void startSearch();
 
 protected:
 public:
@@ -68,7 +68,12 @@ public:
   // for third page
   QComboBox *typeBox;
   QLineEdit * textEdit;
-  QCheckBox   *caseSensCb;
+  QCheckBox *caseSensCb;
+  QComboBox *m_usernameBox;
+  QComboBox *m_groupBox;
+  //for fourth page
+  QLineEdit *metainfoEdit;
+  QLineEdit *metainfokeyEdit;
 
 private:
   bool isDateValid();
