@@ -27,20 +27,22 @@ class KQuery : public QObject
   void setFileType( int filetype );
   void setMimeType( const QString & mimetype );
   void setContext( const QString & context, bool casesensitive, bool useRegexp );
+  void setUsername( QString username );
+  void setGroupname( QString groupname );
+	void setMetaInfo(const QString &metainfo, const QString &metainfokey);
 
   void start();
   void kill();
 
   const KURL& url()              {return m_url;};
 
-  protected slots:
+ protected slots:
   void slotListEntries(KIO::Job *, const KIO::UDSEntryList &);
   void slotResult(KIO::Job *);
   void slotCanceled(KIO::Job *);
 
  signals:
   void addFile(const KFileItem *filename, const QString& matchingLine);
-  //void addFile(const KFileItem *filename);
   void result(int);
 
  private:
@@ -54,6 +56,11 @@ class KQuery : public QObject
   bool m_recursive;
   QString m_mimetype;
   QString m_context;
+  QString m_username;
+  QString m_groupname;
+  QString m_metainfo;
+  QString m_metainfokey;
+
   bool m_casesensitive;
   bool m_regexpForContent;
   QPtrList<QRegExp> m_regexps;// regexps for file name
