@@ -69,6 +69,7 @@
 #include "glossary.h"
 #include "toc.h"
 #include "view.h"
+#include "mainwindow.h"
 
 using namespace KHC;
 
@@ -620,22 +621,31 @@ void Navigator::insertScrollKeeperDoc(NavigatorItem *parentItem,QDomNode docNode
 
 void Navigator::selectItem( const KURL &url )
 {
+  if ( static_cast<NavigatorItem *>( mContentsTree->currentItem() )->url() == url.url() )
+    return;
+
+  // First, populate the NavigatorAppItems if we don't want the home page
+  if ( url != MainWindow::homeURL() ) {
+    for ( QListViewItem *item = mContentsTree->firstChild(); item != 0; item = item->nextSibling() ) {
+      NavigatorAppItem *appItem = dynamic_cast<NavigatorAppItem *>( item );
+      if ( appItem != 0 )
+        appItem->populate( true /* recursive */ );
+    }
+  }
+
   kdDebug() << "Navigator::selectItem(): " << url.url() << endl;
 
-  if ( url.protocol() == "help" ) {
-    kdDebug() << "TODO: Look up help item." << endl;
-  } else {
     QListViewItemIterator it( mContentsTree );
     while ( it.current() != 0 ) {
       NavigatorItem *item = static_cast<NavigatorItem *>( it.current() );
       if ( item->url() == url.url() ) {
         item->setSelected( true );
         mContentsTree->ensureItemVisible( item );
+        slotItemSelected( item );
         break;
       }
       ++it;
     }
-  }
 }
 
 void Navigator::clearSelection()
