@@ -35,11 +35,13 @@ class NavigatorAppItem : public NavigatorItem
     NavigatorAppItem (QListViewItem* parent, const QString& text, const QString& miniicon, const QString& relpath);
 
     virtual void setOpen(bool);
+    void populate( bool recursive = false );
     
  protected:
     QString documentationURL(KService *s);
 
     QString relpath;
+    bool mPopulated;
 };
 
 }
