@@ -605,26 +605,28 @@ void FuzzyClock::drawContents(QPainter *p)
 
       newTimeStr = normalFuzzy[sector];
       int phStart = newTimeStr.find("%");
-      int phLength = newTimeStr.find(" ", phStart) - phStart;
+      if (phStart >= 0) { // protect yourself from translations
+          int phLength = newTimeStr.find(" ", phStart) - phStart;
 
-      // larrosa: we want the exact length, in case the translation needs it,
-      // in other case, we would cut off the end of the translation.
-      if (phLength < 0) phLength = newTimeStr.length() - phStart;
-      int deltaHour = newTimeStr.mid(phStart + 1, phLength - 1).toInt();
+          // larrosa: we want the exact length, in case the translation needs it,
+          // in other case, we would cut off the end of the translation.
+          if (phLength < 0) phLength = newTimeStr.length() - phStart;
+          int deltaHour = newTimeStr.mid(phStart + 1, phLength - 1).toInt();
 
-      if ((_time.hour() + deltaHour) % 12 > 0)
-          realHour = (_time.hour() + deltaHour) % 12 - 1;
-      else
-          realHour = 12 - ((_time.hour() + deltaHour) % 12 + 1);
-      if (realHour==0) {
-          newTimeStr = normalFuzzyOne[sector];
-          phStart = newTimeStr.find("%");
-         // larrosa: Note that length is the same,
-         // so we only have to update phStart
+          if ((_time.hour() + deltaHour) % 12 > 0)
+              realHour = (_time.hour() + deltaHour) % 12 - 1;
+          else
+              realHour = 12 - ((_time.hour() + deltaHour) % 12 + 1);
+          if (realHour==0) {
+              newTimeStr = normalFuzzyOne[sector];
+              phStart = newTimeStr.find("%");
+              // larrosa: Note that length is the same,
+              // so we only have to update phStart
+          }
+          if (phStart >= 0)
+              newTimeStr.replace(phStart, phLength, hourNames[realHour]);
+          newTimeStr.replace(0, 1, QString(newTimeStr.at(0).upper()));
       }
-      newTimeStr.replace(phStart, phLength, hourNames[realHour]);
-      newTimeStr.replace(0, 1, QString(newTimeStr.at(0).upper()));
-
     } else if (_settings->fuzzyness() == 3) {
         newTimeStr = dayTime[_time.hour() / 3];
     } else {
@@ -840,7 +842,7 @@ void ClockApplet::toggleCalendar()
     }
     if (_calendar || _disableCalendar)
         return;
-    _calendar = new DatePicker(this);
+    _calendar = new DatePicker(this, _lastDate);
     connect( _calendar, SIGNAL( destroyed() ), SLOT( slotCalendarDeleted() ));
 
     // some extra spacing is included if aligned on a desktop edge
@@ -868,6 +870,8 @@ void ClockApplet::toggleCalendar()
 
 void ClockApplet::openContextMenu()
 {
+    bool bImmutable = _settings->isImmutable();
+
     KPopupMenu *menu = new KPopupMenu();
     menu->insertTitle( SmallIcon( "clock" ), i18n( "Clock" ) );
 
@@ -886,30 +890,38 @@ void ClockApplet::openContextMenu()
     copyMenu->insertItem(dt.toString(), 208);
     connect( copyMenu, SIGNAL( activated(int) ), this, SLOT( slotCopyMenuActivated(int) ) );
 
-    KPopupMenu *zoneMenu = new KPopupMenu( menu );
-    int i;
-    for (i=0; i<=_settings->remoteZoneCount(); i++)
- 	zoneMenu->insertItem(i==0 ? i18n("Local Timezone")
+    if (!bImmutable)
+    {
+        KPopupMenu *zoneMenu = new KPopupMenu( menu );
+        int i;
+        for (i=0; i<=_settings->remoteZoneCount(); i++)
+            zoneMenu->insertItem(i==0 ? i18n("Local Timezone")
 			:i18n(_settings->zone(i).utf8()).replace(QRegExp("_"), " "), 500+i);
-    zoneMenu->setItemChecked(500+_settings->zoneIndex(),true);
-    zoneMenu->insertSeparator();
-    zoneMenu->insertItem(SmallIcon("configure"), i18n("&Configure Timezones..."), 110);
+        zoneMenu->setItemChecked(500+_settings->zoneIndex(),true);
+        zoneMenu->insertSeparator();
+        zoneMenu->insertItem(SmallIcon("configure"), i18n("&Configure Timezones..."), 110);
 
-    KPopupMenu *type = new KPopupMenu(menu);
-    type->insertItem(i18n("&Plain"), ClockSettings::Plain, 1);
-    type->insertItem(i18n("&Digital"), ClockSettings::Digital, 2);
-    type->insertItem(i18n("&Analog"), ClockSettings::Analog, 3);
-    type->insertItem(i18n("&Fuzzy"), ClockSettings::Fuzzy, 4);
-    type->setItemChecked((int)_settings->type(),true);
+        KPopupMenu *type = new KPopupMenu(menu);
+        type->insertItem(i18n("&Plain"), ClockSettings::Plain, 1);
+        type->insertItem(i18n("&Digital"), ClockSettings::Digital, 2);
+        type->insertItem(i18n("&Analog"), ClockSettings::Analog, 3);
+        type->insertItem(i18n("&Fuzzy"), ClockSettings::Fuzzy, 4);
+        type->setItemChecked((int)_settings->type(),true);
 
-    menu->insertItem(i18n("&Type"), type, 101, 1);
-    menu->insertItem(i18n("Show Time&zone"), zoneMenu, 110, 2);
-    menu->insertItem(SmallIcon("date"), i18n("&Adjust Date && Time..."), 103, 4);
-    menu->insertItem(SmallIcon("kcontrol"), i18n("Date && Time &Format..."), 104, 5);
+        menu->insertItem(i18n("&Type"), type, 101, 1);
+        menu->insertItem(i18n("Show Time&zone"), zoneMenu, 110, 2);
+        if (kapp->authorize("user/root"))
+        {
+            menu->insertItem(SmallIcon("date"), i18n("&Adjust Date && Time..."), 103, 4);
+        }
+        menu->insertItem(SmallIcon("kcontrol"), i18n("Date && Time &Format..."), 104, 5);
+    }
     menu->insertItem(SmallIcon("editcopy"), i18n("C&opy to Clipboard"), copyMenu, 105, 6);
-    menu->insertSeparator(7);
-    menu->insertItem(SmallIcon("configure"), i18n("&Configure Clock..."), 102, 8);
-
+    if (!bImmutable)
+    {
+        menu->insertSeparator(7);
+        menu->insertItem(SmallIcon("configure"), i18n("&Configure Clock..."), 102, 8);
+    }
     int result = menu->exec( QCursor::pos() );
 
     if ((result >= 0) && (result < 100)) {
@@ -963,7 +975,7 @@ QTime ClockApplet::clockGetTime()
 
 QDate ClockApplet::clockGetDate()
 {
-    return QDate::currentDate().addDays(TZoffset/(24*60*60));
+    return QDateTime::currentDateTime().addSecs(TZoffset).date();
 }
 	
 void ClockApplet::showZone(int z)
@@ -1049,6 +1061,7 @@ void ClockApplet::updateDateLabel()
 	_date->setText(
           zone.mid(zone.find('/') + 1).replace(QRegExp("_"), " ")
 	);
+	slotUpdateToolTip();
     }
     else
     {
