@@ -52,14 +52,14 @@ NaughtyConfigDialog::NaughtyConfigDialog
   kini_updateInterval_  = new KIntNumInput(updateInterval, v);
   kini_threshold_       = new KIntNumInput(kini_updateInterval_, threshold, v);
 
-  kini_updateInterval_  ->setLabel(i18n("&Update interval"));
-  kini_threshold_       ->setLabel(i18n("CPU &load threshold"));
+  kini_updateInterval_  ->setLabel(i18n("&Update interval:"));
+  kini_threshold_       ->setLabel(i18n("CPU &load threshold:"));
 
   kini_updateInterval_  ->setRange(1, 20);
   kini_threshold_       ->setRange(10, 1000);
 
   listBox_ = new KEditListBox
-    (i18n("&Programs to ignore"),
+    (i18n("&Programs to Ignore"),
      v,
      "naughty config dialog ignore listbox",
      false,
