@@ -42,7 +42,7 @@ ExtensionButton::ExtensionButton( const QString& desktopFile, QWidget* parent )
 ExtensionButton::ExtensionButton( const KConfigGroup& config, QWidget* parent )
     : PanelPopupButton( parent, "extensionbuttton" )
 {
-    initialize( config.readEntry("DesktopFile") );
+    initialize( config.readPathEntry("DesktopFile") );
 }
 
 void ExtensionButton::initialize( const QString& desktopFile )
