@@ -72,7 +72,7 @@ URLButton::URLButton( const KConfigGroup& config, QWidget* parent )
   , is_lmb_down(false)
   , pDlg( 0 )
 {
-    initialize( config.readEntry("URL") );
+    initialize( config.readPathEntry("URL") );
 }
 
 URLButton::~URLButton()
@@ -115,8 +115,10 @@ void URLButton::setToolTip()
 
 void URLButton::dragEnterEvent(QDragEnterEvent *ev)
 {
-    if (fileItem->acceptsDrops() && QUriDrag::canDecode(ev))
+    if ((ev->source() != this) && fileItem->acceptsDrops() && QUriDrag::canDecode(ev))
 	ev->accept(rect());
+    else
+        ev->ignore(rect());
     PanelButton::dragEnterEvent(ev);
 }
 
@@ -182,7 +184,7 @@ void URLButton::mouseMoveEvent(QMouseEvent *e)
                                                  KIcon::Panel, sz,
                                                  KIcon::DefaultState, 0L, true);
     dd->setPixmap(pm);
-    dd->dragCopy();
+    dd->drag();
 }
 
 void URLButton::slotExec()
