@@ -25,10 +25,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qpainter.h>
 #include <qstyle.h>
 #include <qpixmapcache.h>
+#include <qtooltip.h>
 
 #include <kpushbutton.h>
 #include <kapplication.h>
 #include <kdebug.h>
+#include <klocale.h>
 
 #include "container_applet.h"
 
@@ -102,15 +104,19 @@ AppletHandle::AppletHandle(AppletContainer* parent, const char* name)
    connect( _menuButton, SIGNAL(clicked()), this, SLOT(menuButtonClicked()) );
    _drag->installEventFilter( this );
 
+   QToolTip::add(this, i18n("%1 applet handle").
+                           arg(parent->info().name()));
+   QToolTip::add(_menuButton, i18n("%1 menu").
+                                  arg(parent->info().name()));
    resetLayout();
 }
 
-int AppletHandle::heightForWidth( int /* w */ )
+int AppletHandle::heightForWidth( int /* w */ ) const
 {
    return style().pixelMetric( QStyle::PM_DockWindowHandleExtent, this );
 }
 
-int AppletHandle::widthForHeight( int /* h */ )
+int AppletHandle::widthForHeight( int /* h */ ) const
 {
    return style().pixelMetric( QStyle::PM_DockWindowHandleExtent, this );
 }
@@ -196,7 +202,7 @@ void AppletHandle::menuButtonClicked()
     emit showAppletMenu();
 }
 
-bool AppletHandle::onMenuButton(const QPoint& point)
+bool AppletHandle::onMenuButton(const QPoint& point) const
 {
   return (childAt(mapFromGlobal(point)) == _menuButton);
 }
