@@ -54,8 +54,7 @@ Panel* Panel::the()
 Panel::Panel()
   : PanelContainer( 0, "Panel" )
   , DCOPObject( "Panel" )
-  , _size( Normal )
-  , _panelsize( 0 )
+  , _opMnu( 0 )
 {
     setAcceptDrops( !Kicker::kicker()->isImmutable() );
 
@@ -74,18 +73,19 @@ Panel::Panel()
     layout->setMargin( _frame->frameWidth() );
 
     // applet area
-    _containerArea = new ContainerArea( KGlobal::config(), _frame );
+    _containerArea = new ContainerArea( KGlobal::config(), _frame, opMenu() );
     layout->addWidget( _containerArea, 1 );
 
     _containerArea->setFrameStyle( QFrame::NoFrame );
     _containerArea->viewport()->installEventFilter( this );
     connect(_containerArea, SIGNAL(sizeHintChanged()), SLOT(updateLayout()));
 
-    connect(this, SIGNAL(positionChange(Position)), SLOT(slotSetPosition(Position)));
+    connect( this, SIGNAL(sizeChange(Size, int)),
+             this, SLOT(slotSizeChange(Size, int)) );
+    connect( this, SIGNAL(positionChange(Position)),
+             this, SLOT(slotPositionChange(Position)) );
     connect( this, SIGNAL(alignmentChange(Alignment)),
              this, SLOT(slotAlignmentChange(Alignment)) );
-
-    _opMnu = new PanelOpMenu( this, this );
 }
 
 Panel::~Panel()
@@ -104,22 +104,9 @@ void Panel::readConfig()
 //    kdDebug() << "Panel::readConfig()" << endl;
 
     KConfig *config = KGlobal::config();
-    _containerArea->configure();
-
     config->setGroup("General");
-
-    _panelsize = config->readNumEntry( "Size", sizeValue( Normal ) );
-
-    // backward compatibility
-    if ( _panelsize == 0 ) _panelsize = sizeValue( Tiny );
-    else if ( _panelsize == 1 ) _panelsize = sizeValue( Small );
-    else if ( _panelsize == 2 ) _panelsize = sizeValue( Normal );
-    else if ( _panelsize == 3 ) _panelsize = sizeValue( Large );
-
-    _panelsize = QMIN( QMAX( _panelsize, MIN_PANEL_SIZE ), MAX_PANEL_SIZE );
-
-    _frame->enableResizeHandle( size() == ::Custom && !Kicker::kicker()->isImmutable() );
-
+    _containerArea->configure();
+    
     PanelContainer::readConfig( config );
 }
 
@@ -130,41 +117,19 @@ void Panel::writeConfig()
     KConfig *config = KGlobal::config();
     config->setGroup("General");
 
-    config->writeEntry( "Size", _panelsize );
-
     KSimpleConfig kdeglobals("kdeglobals", false);
     kdeglobals.setGroup("PanelIcons");
-    if ( _panelsize >= sizeValue( Large ) )
-	kdeglobals.writeEntry("Size", KIcon::SizeLarge );
-    else if ( _panelsize >= sizeValue( Normal ) )
-	kdeglobals.writeEntry("Size", KIcon::SizeMedium );
+    if ( panelSize() >= sizeValue( Large ) )
+	kdeglobals.writeEntry("Size", static_cast<int>(KIcon::SizeLarge) );
+    else if ( panelSize() >= sizeValue( Normal ) )
+	kdeglobals.writeEntry("Size", static_cast<int>(KIcon::SizeMedium) );
     else
-	kdeglobals.writeEntry("Size", KIcon::SizeSmall );
+	kdeglobals.writeEntry("Size", static_cast<int>(KIcon::SizeSmall) );
 
     PanelContainer::writeConfig( config );
-    
     config->sync();
 }
 
-Size Panel::size() const
-{
-    if( _panelsize == sizeValue(::Tiny) ) return ::Tiny;
-    if( _panelsize == sizeValue(::Small) ) return ::Small;
-    if( _panelsize == sizeValue(::Normal) ) return ::Normal;
-    if( _panelsize == sizeValue(::Large) ) return ::Large;
-    return ::Custom;
-}
-
-void Panel::setSize( int s )
-{
-    _panelsize = QMIN( QMAX( s, MIN_PANEL_SIZE ), MAX_PANEL_SIZE );
-
-    _frame->enableResizeHandle( size() == ::Custom && !Kicker::kicker()->isImmutable() );
-
-    updateLayout();
-    writeConfig();
-}
-
 void Panel::slotResizeRequest( int dx, int dy )
 {
     int offset;
@@ -183,10 +148,15 @@ void Panel::slotResizeRequest( int dx, int dy )
 	    offset = -dy;
 	    break;
     }
-    setSize( _panelsize + offset );
+    setSize( size(), panelSize() + offset );
 }
 
-void Panel::slotSetPosition( Position p )
+void Panel::slotSizeChange( Size s, int customSize )
+{
+    _frame->enableResizeHandle( s == Custom && !Kicker::kicker()->isImmutable() );
+}
+
+void Panel::slotPositionChange( Position p )
 {
     switch ( p ) {
 	case Top:
@@ -211,16 +181,18 @@ void Panel::slotAlignmentChange( Alignment a )
     _containerArea->setAlignment( a );
 }
 
-void Panel::showPanelMenu( QPoint globalPos )
+void Panel::showPanelMenu( const QPoint &globalPos )
 {
-    QPopupMenu *menu = BaseContainer::reduceMenu(_opMnu);
+    PanelOpMenu *menu = opMenu();
+    menu->buildMenu();
+    menu = static_cast<PanelOpMenu*>(BaseContainer::reduceMenu(menu));
 
     menu->exec( popupPosition(
-       positionToDirection( position() ), _opMnu,
+       positionToDirection( position() ), opMenu(),
        this, mapFromGlobal( globalPos ) ) );
 }
 
-bool Panel::vetoAutoHide()
+bool Panel::vetoAutoHide() const
 {
     return PanelContainer::vetoAutoHide() || _containerArea->inMoveOperation();
 }
@@ -267,9 +239,9 @@ void Panel::addBrowserButton(const QString &startDir)
     _containerArea->addBrowserButton(startDir);
 }
 
-void Panel::addServiceMenuButton(const QString &name, const QString& relPath)
+void Panel::addServiceMenuButton(const QString &, const QString& relPath)
 {
-    _containerArea->addServiceMenuButton(name, relPath);
+    _containerArea->addServiceMenuButton(relPath);
 }
 
 void Panel::addNonKDEAppButton(const QString &filePath, const QString &icon, const QString &cmdLine, bool inTerm)
@@ -277,23 +249,18 @@ void Panel::addNonKDEAppButton(const QString &filePath, const QString &icon, con
     _containerArea->addNonKDEAppButton(filePath, icon, cmdLine, inTerm);
 }
 
-void Panel::addKonsoleButton()
-{
-    _containerArea->addKonsoleButton();
-}
-
 void Panel::addApplet( const QString &desktopFile )
 {
     _containerArea->addApplet( desktopFile );
 }
 
-QSize Panel::sizeHint( Position p, QSize maxSize )
+QSize Panel::sizeHint( Position p, const QSize &maxSize )
 {
     QSize size = PanelContainer::sizeHint( p, maxSize );
 
     QSize ourSize;
-    int w = _panelsize - size.width() - _frame->lineWidth() * 2;
-    int h = _panelsize - size.height() - _frame->lineWidth() * 2;
+    int w = panelSize() - size.width() - _frame->lineWidth() * 2;
+    int h = panelSize() - size.height() - _frame->lineWidth() * 2;
     if( p == ::Top || p == ::Bottom ) {
 	ourSize = QSize( _containerArea->minimumUsedSpace( Horizontal, w, h ), h ) +
 	          QSize( _frame->lineWidth() * 2,  _frame->lineWidth() * 2 );
@@ -303,3 +270,45 @@ QSize Panel::sizeHint( Position p, QSize maxSize )
     }
     return (size + ourSize).boundedTo( maxSize );
 }
+
+PanelOpMenu* Panel::opMenu()
+{
+    if ( _opMnu == 0 )
+        _opMnu = new PanelOpMenu( this, this );
+
+    return _opMnu;
+}
+
+int Panel::panelSize()
+{
+    if( size() == Custom ) {
+        return customSize();
+    } else {
+        return sizeValue( size() );
+    }
+}
+
+void Panel::setPanelSize(int size)
+{ 
+    if (size == sizeValue(Tiny))
+    {
+        setSize(Tiny);
+    }
+    else if (size == sizeValue(Small))
+    {
+        setSize(Small);
+    }
+    else if (size == sizeValue(Normal))
+    {
+        setSize(Normal);
+    }
+    else if (size == sizeValue(Large))
+    {
+        setSize(Large);
+    }
+    else
+    {
+        setSize(Custom, size); 
+    }
+}
+
