@@ -31,16 +31,26 @@ class DockContainer : public QFrame
     Q_OBJECT
 
 public:
-    DockContainer( QString command, QWidget *parent=0, const char* name=0 );
+    DockContainer( QString command, QWidget *parent, 
+                   QString resname,
+                   QString resclass,
+                   bool undocked_style=false);
 
     void embed(WId);
     void unembed();
+    void kill();
 
     WId embeddedWinId() const;
     QString command() const;
-
+    QString resClass() const;
+    QString resName() const;
+    void askNewCommand(bool bad_command=true);
+    void popupMenu(QPoint p);
+    static int& sz();
+    static int& border();
 signals:
     void embeddedWindowDestroyed(DockContainer*);
+    void settingsChanged(DockContainer*);
 
 protected:
     bool x11Event( XEvent * );
@@ -48,6 +58,7 @@ protected:
 private:
     WId _embeddedWinId;
     QString _command;
+    QString _resName, _resClass;
 };
 
 
@@ -61,6 +72,16 @@ inline QString DockContainer::command() const
     return _command;
 }
 
+inline QString DockContainer::resClass() const
+{
+    return _resClass;
+}
+
+inline QString DockContainer::resName() const
+{
+    return _resName;
+}
+
 
 #endif
 
