@@ -1,7 +1,7 @@
 #include <qlayout.h>
 #include <qtimer.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "kasgroupitem.h"
 #include "kastasker.h"
@@ -14,7 +14,6 @@ const int TITLE_HEIGHT = 13;
 #endif
 
 const int KAS_GROUP_POPUP_KILL_DELAY = 6000;
-
 KasGroupPopup::KasGroupPopup( KasGroupItem *item, const char *name )
     : KasPopup( item, name )
 {
@@ -25,7 +24,7 @@ KasGroupPopup::KasGroupPopup( KasGroupItem *item, const char *name )
     KasTasker *master = static_cast<KasTasker *> (kasbar());
     childBar_ = new KasTasker( ( kasbar()->orientation() == Horizontal ) ? Vertical : Horizontal,
 			       master, this );
-
+    childBar_->setConfig( master->config());
 
     box->addWidget( childBar_ );
     resize( childBar_->size() );
