@@ -57,16 +57,20 @@ class KasTaskItem : public KasItem
     virtual void paint( QPainter *p );
 
     /**
-     * Called when a mouse press event is received over this item.
+     * Reimplemented to activate, show task menus etc.
      */
     virtual void mousePressEvent( QMouseEvent *e );
 
+    /**
+     * Returns the task the item is displaying.
+     */
     Task *task() const { return task_; }
 
+    /**
+     * Returns the parent KasTasker object.
+     */
     KasTasker *kasbar() const;
 
-    void showWindowMenuAt( int x, int y );
-
 public slots:
     /**
      * Create a thumbnail for this task (does nothing if they're disabled).
@@ -78,12 +82,19 @@ public slots:
 
     void iconChanged();
 
+    void showWindowMenuAt( QPoint pos );
+    void showPropertiesDialog();
+
 protected:
     /**
      * Reimplemented to create a KasTaskPopup.
      */
     virtual KasPopup *createPopup();
 
+    QWidget *createTaskProps( QWidget *tabbed );
+    QWidget *createX11Props( QWidget *tabbed );
+    QWidget *createNETProps( QWidget *tabbed );
+
     /**
      * Reimplemented to activate the task.
      */
