@@ -49,6 +49,7 @@ TaskBarExtension::TaskBarExtension(const QString& configFile, Type type,
     QHBoxLayout* layout = new QHBoxLayout( this );
     container = new TaskBarContainer( false, this );
     layout->addWidget( container );
+    setSize(SizeSmall, customSize());
 
     connect( container, SIGNAL( containerCountChanged() ),
              this, SIGNAL( updateLayout() ) );
@@ -88,9 +89,13 @@ void TaskBarExtension::preferences()
 
 QSize TaskBarExtension::sizeHint(Position p, QSize maxSize) const
 {
-    QSize size = container->sizeHint( p, maxSize );
+    if (p == Left || p == Right)
+        maxSize.setWidth(sizeInPixels());
+    else
+        maxSize.setHeight(sizeInPixels());
+
 //    kdDebug(1210) << "TaskBarExtension::sizeHint( Position, QSize )" << endl;
 //    kdDebug(1210) << " width: " << size.width() << endl;
 //    kdDebug(1210) << "height: " << size.height() << endl;
-    return size;
+    return container->sizeHint( p, maxSize );
 }
