@@ -251,9 +251,9 @@ bool FittsLawFrame::x11Event( XEvent* e )
         if (!destWidget || destWidget == this)
             return false;
 
-        if (!rect().contains( QPoint(e->xmotion.x, e->xmotion.y)) ) {
+        // For MotionNotify, don't force the coordinates of the new event to be
+        // inside the destination widget rect. That confuses tooltips.
             dx = 0; dy = 0;
-        }
 
         XEvent ne;
         memset(&ne, 0, sizeof(ne));
