@@ -389,7 +389,10 @@ void TaskBar::reLayout()
 {
     // filter task container list
     TaskContainerList list = filteredContainers();
-    if ( list.count() < 1 ) return;
+    if ( list.count() < 1 ) {
+        resizeContents( contentsRect().width(), contentsRect().height() );
+        return;
+    }
 
     if ( isGrouping != shouldGroup() ) {
         reGroup();
@@ -409,7 +412,7 @@ void TaskBar::reLayout()
 		{
 		    sorted.append( c );
 		    residue.remove( c );
-		}    
+		}
 	    }
 	}
 	list = sorted;
