@@ -55,6 +55,8 @@ PanelBrowserDialog::PanelBrowserDialog( const QString& path, const QString &icon
     hbox1->setSpacing( KDialog::spacingHint() );
     QLabel *label2 = new QLabel( i18n ( "Path:" ), hbox1 );
     pathInput = new KLineEdit( hbox1 );
+    connect( pathInput, SIGNAL( textChanged ( const QString & )), this, SLOT( slotPathChanged( const QString & )));
+
     pathInput->setText( path );
     pathInput->setFocus();
     label2->setBuddy( pathInput );
@@ -75,6 +77,11 @@ PanelBrowserDialog::~PanelBrowserDialog()
 
 }
 
+void PanelBrowserDialog::slotPathChanged( const QString &_text )
+{
+    enableButtonOK( !_text.isEmpty() );
+}
+
 void PanelBrowserDialog::browse()
 {
     QString dir = KFileDialog::getExistingDirectory( pathInput->text(), 0, i18n( "Select Directory" ) );
