@@ -30,7 +30,7 @@ class PanelExtensionOpMenu : public QPopupMenu
 {
 public:
     enum OpButton{Move = 9900, Remove = 9901, Help = 9902, About = 9903, Preferences = 9904, ReportBug = 9905, Shade = 9906 };
-    PanelExtensionOpMenu(int actions = 0, QWidget *parent=0, const char *name=0);
+    PanelExtensionOpMenu(const QString& extension, int actions, QWidget *parent=0, const char *name=0);
 };
 
 #endif
