@@ -244,7 +244,7 @@ fishProtocol::fishProtocol(const QCString &pool_socket, const QCString &app_sock
     sendLen = -1;
     connectionAuth.keepPassword = true;
     connectionAuth.url.setProtocol("fish");
-    epoch.setTime_t(0);
+    epoch.setTime_t(0, Qt::UTC);
     outBufPos = -1;
     outBuf = NULL;
     outBufLen = 0;
@@ -261,7 +261,7 @@ fishProtocol::fishProtocol(const QCString &pool_socket, const QCString &app_sock
 fishProtocol::~fishProtocol()
 {
   myDebug( << "fishProtocol::~fishProtocol()" << endl);
-  closeConnection();
+  shutdownConnection(true);
 }
 
 /* --------------------------------------------------------------------------- */
@@ -271,13 +271,21 @@ Connects to a server and logs us in via SSH. Then starts FISH protocol.
 */
 void fishProtocol::openConnection() {
     if (childPid) return;
-    infoMessage("Connecting...");
+
+    if (connectionHost.isEmpty())
+    {
+       error( KIO::ERR_UNKNOWN_HOST, QString::null );
+       return;
+    }
+
+    infoMessage(i18n("Connecting..."));
 
     myDebug( << "connecting to: " << connectionUser << "@" << connectionHost << ":" << connectionPort << endl);
     sendCommand(FISH_FISH);
+    sendCommand(FISH_VER);
     if (connectionStart()) {
         error(ERR_COULD_NOT_CONNECT,thisFn);
-        closeConnection();
+        shutdownConnection();
         return;
     };
     myDebug( << "subprocess is running" << endl);
@@ -394,7 +402,7 @@ bool fishProtocol::connectionStart() {
 #endif
 
         int pgrp = getpid();
-#ifdef _AIX
+#if defined( _AIX) || defined( __hpux)
         tcsetpgrp(0, pgrp);
 #else
         ioctl(0, TIOCSPGRP, (char *)&pgrp);
@@ -407,7 +415,7 @@ bool fishProtocol::connectionStart() {
 
 #define common_args "-l", connectionUser.latin1(), "-x", "-e", "none", \
     "-q", connectionHost.latin1(), \
-    "echo FISH:;env TZ=UTC LANG=C LC_ALL=C LOCALE=C /bin/sh", NULL
+    "echo FISH:;env TZ=UTC LANG=C LC_ALL=C LOCALE=C /bin/sh", (void *)0
     // disabled: leave compression up to the client.
     // (isOpenSSH?"-C":"+C"),
 
@@ -502,7 +510,7 @@ int fishProtocol::establishConnection(char *buffer, int len) {
         if (str == "\n") continue;
           if (str == "FISH:\n") {
             thisFn = QString::null;
-              infoMessage("Initiating protocol...");
+              infoMessage(i18n("Initiating protocol..."));
             if (!connectionAuth.password.isEmpty()) {
                 connectionAuth.password = connectionAuth.password.left(connectionAuth.password.length()-1);
                   cacheAuthentication(connectionAuth);
@@ -534,8 +542,8 @@ int fishProtocol::establishConnection(char *buffer, int len) {
                 connectionAuth.caption = "SSH Authorization";
                 if (!checkCachedAuthentication(connectionAuth) && !openPassDlg(connectionAuth)) {
                     error(ERR_USER_CANCELED,connectionHost);
-                    closeConnection();
-                    return 0;
+                    shutdownConnection();
+                    return -1;
                 }
                 connectionAuth.password += "\n";
                 if (connectionAuth.username != connectionUser) {
@@ -576,10 +584,7 @@ sets connection information for subsequent commands
 */
 void fishProtocol::setHost(const QString & host, int port, const QString & u, const QString & pass){
     QString user(u);
-    if (host.isEmpty()) {
-        error(ERR_UNKNOWN_HOST,QString::null);
-        return;
-    }
+
     if (port <= 0) port = 0;
     if (user.isEmpty()) user = getenv("LOGNAME");
 
@@ -587,7 +592,7 @@ void fishProtocol::setHost(const QString & host, int port, const QString & u, co
         return;
     myDebug( << "setHost " << u << "@" << host << endl);
 
-    if (childPid) closeConnection();
+    if (childPid) shutdownConnection();
 
     connectionHost = host;
     connectionAuth.url.setHost(host);
@@ -599,17 +604,32 @@ void fishProtocol::setHost(const QString & host, int port, const QString & u, co
     connectionPort = port;
     connectionPassword = pass;
 }
+
+/**
+Forced close of the connection
+
+This function gets called from the application side of the universe,
+it shouldn't send any response.
+ */
+void fishProtocol::closeConnection(){
+    shutdownConnection(true);
+}
+
 /**
 Closes the connection
  */
-void fishProtocol::closeConnection(){
+void fishProtocol::shutdownConnection(bool forced){
     if (childPid) {
         kill(childPid,SIGTERM);
+        wait(NULL);
         childPid = 0;
         close(childFd);
         childFd = -1;
-        dropNetwork();
-        infoMessage("Disconnected.");
+        if (!forced)
+        {
+           dropNetwork();
+           infoMessage(i18n("Disconnected."));
+        }
     }
     outBufPos = -1;
     outBuf = NULL;
@@ -683,7 +703,7 @@ int fishProtocol::makeTimeFromLs(const QString &monthStr, const QString &dayStr,
     int currentMonth = month;
     int day = dayStr.toInt();
 
-    static const char *monthNames[12] = {
+    static const char * const monthNames[12] = {
           "Jan", "Feb", "Mar", "Apr", "May", "Jun",
         "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
     };
@@ -727,7 +747,7 @@ void fishProtocol::manageConnection(const QString &l) {
                 hasAppend = line.contains(" append ");
             } else {
                 error(ERR_UNSUPPORTED_PROTOCOL,line);
-                closeConnection();
+                shutdownConnection();
             }
             break;
         case FISH_PWD:
@@ -905,14 +925,14 @@ void fishProtocol::manageConnection(const QString &l) {
 
         case FISH_RETR:
             if (line.length() == 0) {
-                error(ERR_IS_DIRECTORY,url.url());
+                error(ERR_IS_DIRECTORY,url.prettyURL());
                 recvLen = 0;
                 break;
             }
             recvLen = line.toInt(&isOk);
             if (!isOk) {
-                error(ERR_COULD_NOT_READ,url.url());
-                closeConnection();
+                error(ERR_COULD_NOT_READ,url.prettyURL());
+                shutdownConnection();
             }
             break;
 	default : break;
@@ -925,8 +945,8 @@ void fishProtocol::manageConnection(const QString &l) {
             break;
         case FISH_RETR:
             if (recvLen == -1) {
-                error(ERR_COULD_NOT_READ,url.url());
-                closeConnection();
+                error(ERR_COULD_NOT_READ,url.prettyURL());
+                shutdownConnection();
             } else {
                 rawRead = recvLen;
                 t_start = t_last = time(NULL);
@@ -945,12 +965,12 @@ void fishProtocol::manageConnection(const QString &l) {
         switch (fishCommand) {
         case FISH_STOR:
         case FISH_WRITE:
-            error(ERR_COULD_NOT_WRITE,url.url());
-            closeConnection();
+            error(ERR_COULD_NOT_WRITE,url.prettyURL());
+            shutdownConnection();
             break;
         case FISH_RETR:
-            error(ERR_COULD_NOT_READ,url.url());
-            closeConnection();
+            error(ERR_COULD_NOT_READ,url.prettyURL());
+            shutdownConnection();
             break;
         case FISH_READ:
             mimeType("inode/directory");
@@ -960,21 +980,21 @@ void fishProtocol::manageConnection(const QString &l) {
         case FISH_FISH:
         case FISH_VER:
             error(ERR_SLAVE_DEFINED,line);
-            closeConnection();
+            shutdownConnection();
             break;
         case FISH_PWD:
         case FISH_CWD:
-            error(ERR_CANNOT_ENTER_DIRECTORY,url.url());
+            error(ERR_CANNOT_ENTER_DIRECTORY,url.prettyURL());
             break;
         case FISH_LIST:
             //myDebug( << "list error. reason: " << listReason << endl);
-            if (listReason == LIST || listReason == SIZE) error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
+            if (listReason == LIST || listReason == SIZE) error(ERR_CANNOT_ENTER_DIRECTORY,url.prettyURL());
             else if (listReason == STAT) {
                 listReason = STATCHECK;
                 sendCommand(FISH_LIST,url.path().latin1());
                 udsStatEntry.clear();
             } else if (listReason == STATCHECK) {
-                error(ERR_DOES_NOT_EXIST,url.path());
+                error(ERR_DOES_NOT_EXIST,url.prettyURL());
                 udsStatEntry.clear();
             } else if (listReason == CHECK) {
                 checkExist = false;
@@ -982,24 +1002,24 @@ void fishProtocol::manageConnection(const QString &l) {
             }
             break;
         case FISH_CHMOD:
-            error(ERR_CANNOT_CHMOD,url.url());
+            error(ERR_CANNOT_CHMOD,url.prettyURL());
             break;
         case FISH_CHOWN:
         case FISH_CHGRP:
-            error(ERR_ACCESS_DENIED,url.url());
+            error(ERR_ACCESS_DENIED,url.prettyURL());
             break;
         case FISH_MKD:
-            error(ERR_COULD_NOT_MKDIR,url.url());
+            error(ERR_COULD_NOT_MKDIR,url.prettyURL());
             break;
         case FISH_RMD:
-            error(ERR_COULD_NOT_RMDIR,url.url());
+            error(ERR_COULD_NOT_RMDIR,url.prettyURL());
             break;
         case FISH_DELE:
         case FISH_RENAME:
         case FISH_COPY:
         case FISH_LINK:
         case FISH_SYMLINK:
-            error(ERR_COULD_NOT_WRITE,url.url());
+            error(ERR_COULD_NOT_WRITE,url.prettyURL());
             break;
 	default : break;
         }
@@ -1007,7 +1027,6 @@ void fishProtocol::manageConnection(const QString &l) {
         bool wasSize = false;
         if (fishCommand == FISH_STOR) fishCommand = (hasAppend?FISH_APPEND:FISH_WRITE);
         if (fishCommand == FISH_FISH) {
-            sendCommand(FISH_VER);
             connected();
         } else if (fishCommand == FISH_LIST) {
             if (listReason == LIST) {
@@ -1019,7 +1038,7 @@ void fishProtocol::manageConnection(const QString &l) {
                 } else statEntry(udsStatEntry);
                 udsStatEntry.clear();
             } else if (listReason == CHECK) {
-                if (!checkOverwrite && checkExist) error(ERR_FILE_ALREADY_EXIST,url.url());
+                if (!checkOverwrite && checkExist) error(ERR_FILE_ALREADY_EXIST,url.prettyURL());
             } else if (listReason == SIZE) {
                 wasSize = true;
             } else if (listReason == STATCHECK) {
@@ -1069,7 +1088,7 @@ void fishProtocol::sent()
         if (rawWrite > 0) {
             dataReq();
             if (readData(rawData) <= 0) {
-                closeConnection();
+                shutdownConnection();
             }
         }
         return;
@@ -1237,7 +1256,7 @@ void fishProtocol::run() {
             if (rc < 0) {
                 myDebug( << "select failed, rc: " << rc << ", error: " << strerror(errno) << endl);
                 error(ERR_CONNECTION_BROKEN,connectionHost);
-                closeConnection();
+                shutdownConnection();
                 return;
             }
             if (FD_ISSET(childFd,&wfds) && outBufPos >= 0) {
@@ -1250,7 +1269,7 @@ void fishProtocol::run() {
                 else {
                     myDebug( << "write failed, rc: " << rc << ", error: " << strerror(errno) << endl);
                     error(ERR_CONNECTION_BROKEN,connectionHost);
-                    closeConnection();
+                    shutdownConnection();
                     return;
                 }
                 if (outBufPos >= outBufLen) {
@@ -1270,7 +1289,7 @@ void fishProtocol::run() {
                 } else {
                     myDebug( << "read failed, rc: " << rc << ", error: " << strerror(errno) << endl);
                     error(ERR_CONNECTION_BROKEN,connectionHost);
-                    closeConnection();
+                    shutdownConnection();
                     return;
                 }
             }
@@ -1355,7 +1374,7 @@ void fishProtocol::mkdir(const KURL& u, int permissions) {
 void fishProtocol::rename(const KURL& s, const KURL& d, bool overwrite) {
     myDebug( << "@@@@@@@@@ rename " << s.url() << " " << d.url() << " " << overwrite << endl);
     if (s.host() != d.host() || s.port() != d.port() || s.user() != d.user()) {
-        error(ERR_UNSUPPORTED_ACTION,s.path().latin1());
+        error(ERR_UNSUPPORTED_ACTION,s.prettyURL());
         return;
     }
     setHost(s.host(),s.port(),s.user(),s.pass());
@@ -1416,7 +1435,7 @@ void fishProtocol::chmod(const KURL& u, int permissions){
 void fishProtocol::copy(const KURL &s, const KURL &d, int permissions, bool overwrite) {
     myDebug( << "@@@@@@@@@ copy " << s.url() << " " << d.url() << " " << permissions << " " << overwrite << endl);
     if (s.host() != d.host() || s.port() != d.port() || s.user() != d.user() || !hasCopy) {
-        error(ERR_UNSUPPORTED_ACTION,s.path().latin1());
+        error(ERR_UNSUPPORTED_ACTION,s.prettyURL());
         return;
     }
     //myDebug( << s.url() << endl << d.url() << endl);
