@@ -1,5 +1,5 @@
 #ifndef _IMAP4_H
-#define _IMAP4_H "$Id: imap4.h,v 1.32 2002/09/20 19:48:08 haeckel Exp $"
+#define _IMAP4_H "$Id: imap4.h,v 1.32.2.1 2003/01/18 10:41:15 faure Exp $"
 /**********************************************************************
  *
  *   imap4.h  - IMAP4rev1 KIOSlave
@@ -114,13 +114,6 @@ protected:
 
   bool makeLogin ();
 
-  QString myHost, myUser, myPass, myAuth, myTLS;
-  int myPort;
-  bool mySSL;
-
-  bool relayEnabled, cacheOutput;
-  QByteArray outputCache;
-
   void outputLineStr (const QString & _str)
   {
     outputLine (_str.latin1 ());
@@ -130,6 +123,16 @@ protected:
   void doListEntry (const KURL & _url, const QString & myBox,
                     const imapList & item);
 
+private:
+
+  QString myHost, myUser, myPass, myAuth, myTLS;
+  int myPort;
+  bool mySSL;
+
+  bool relayEnabled, cacheOutput;
+  QByteArray outputCache;
+  KIO::filesize_t mProcessedSize;
+
   char readBuffer[IMAP_BUFFER];
   ssize_t readBufferLen;
   int readSize;
