@@ -1,9 +1,9 @@
 #ifndef _IMAPCOMMAND_H
-#define _IMAPCOMMAND_H "$Id: imapcommand.h,v 1.6 2001/06/02 17:53:24 haeckel Exp $"
+#define _IMAPCOMMAND_H "$Id: imapcommand.h,v 1.10 2002/01/21 21:00:50 haeckel Exp $"
 /**********************************************************************
  *
  *   imapcommand.h  - IMAP4rev1 command handler
- *   Copyright (C) 2000
+ *   Copyright (C) 2000 Sven Carstens
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ public:
   imapCommand (const QString & command, const QString & parameter);
   bool isComplete ();
   const QString & result ();
+  const QString & resultInfo ();
   const QString & parameter ();
   const QString & command ();
   const QString & id ();
@@ -40,6 +41,7 @@ public:
   void setId (const QString &);
   void setComplete ();
   void setResult (const QString &);
+  void setResultInfo (const QString &);
   void setCommand (const QString &);
   void setParameter (const QString &);
   const QString getStr ();
@@ -64,9 +66,11 @@ public:
                                   const QString & sequence, bool nouid =
                                   false);
   static imapCommand *clientAppend (const QString & box,
-                                    const QString & extras, ulong size);
+                                    const QString & flags, ulong size);
   static imapCommand *clientCreate (const QString & path);
   static imapCommand *clientDelete (const QString & path);
+  static imapCommand *clientSubscribe (const QString & path);
+  static imapCommand *clientUnsubscribe (const QString & path);
   static imapCommand *clientExpunge ();
   static imapCommand *clientRename (const QString & src,
                                     const QString & dest);
@@ -82,6 +86,7 @@ protected:
   bool mComplete;
   QString aParameter;
   QString mResult;
+  QString mResultInfo;
 
 private:
     imapCommand & operator = (const imapCommand &);
