@@ -1,8 +1,8 @@
-// $Id: imapinfo.cc,v 1.5 2001/03/21 23:30:03 waba Exp $
+// $Id: imapinfo.cc,v 1.8 2001/11/26 19:24:39 haeckel Exp $
 /**********************************************************************
  *
  *   imapinfo.cc  - IMAP4rev1 SELECT / EXAMINE handler
- *   Copyright (C) 2000
+ *   Copyright (C) 2000 Sven Carstens
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -220,17 +220,16 @@ ulong imapInfo::_flags (const QString & inFlags, QString & userflags)
     0;
   QString
     entry;
-  QString
-    flagsString =
-    inFlags;
+  parseString flagsString;
+  flagsString.data.duplicate(inFlags.latin1(), inFlags.length());
   userflags = "";
 
   if (flagsString[0] == '(')
-    flagsString = flagsString.right (flagsString.length () - 1);
+    flagsString.pos++;
 
   while (!flagsString.isEmpty () && flagsString[0] != ')')
   {
-    entry = imapParser::parseOneWord (flagsString);
+    entry = imapParser::b2c(imapParser::parseOneWord (flagsString));
 
     if (0 != entry.contains ("\\Seen", false))
       flags ^= Seen;
@@ -247,12 +246,10 @@ ulong imapInfo::_flags (const QString & inFlags, QString & userflags)
     else if (0 != entry.contains ("\\*", false))
       flags ^= User;
     else if (entry.isEmpty ())
-      flagsString = "";
+      flagsString.clear();
     else
       userflags += entry + " ";
   }
 
-  kdDebug(7116) << "imapInfo::_flags - " << inFlags << " -> " << flags << "d, " << userflags << endl;
-
   return flags;
 }
