@@ -849,8 +849,8 @@ mimeHeader * imapParser::parseSimplePart (parseString & inWords,
   localPart->setEncoding (b2c(encoding));
 
   //body size
-  if (parseOneNumber (inWords, size));
-  localPart->setLength (size);
+  if (parseOneNumber (inWords, size))
+      localPart->setLength (size);
 
   // type specific extensions
   if (qstrnicmp(type, "MESSAGE", type.size()) == 0
@@ -1110,11 +1110,8 @@ void imapParser::parseBody (parseString & inWords)
   }
 }
 
-void imapParser::parseFetch (ulong value, parseString & inWords)
+void imapParser::parseFetch (ulong /*value*/, parseString & inWords)
 {
-  // just the id
-  if (value);
-
   if (inWords[0] != '(')
     return;
   inWords.pos++;
@@ -1377,19 +1374,17 @@ int imapParser::parseLoop ()
 }
 
 void
-imapParser::parseRelay (const QByteArray & buffer)
+imapParser::parseRelay (const QByteArray & /*buffer*/)
 {
   qWarning
     ("imapParser::parseRelay - virtual function not reimplemented - data lost");
-  if (&buffer);
 }
 
 void
-imapParser::parseRelay (ulong len)
+imapParser::parseRelay (ulong /*len*/)
 {
   qWarning
     ("imapParser::parseRelay - virtual function not reimplemented - announcement lost");
-  if (len);
 }
 
 bool imapParser::parseRead (QByteArray & buffer, ulong len, ulong relay)
@@ -1399,20 +1394,18 @@ bool imapParser::parseRead (QByteArray & buffer, ulong len, ulong relay)
   return FALSE;
 }
 
-bool imapParser::parseReadLine (QByteArray & buffer, ulong relay)
+bool imapParser::parseReadLine (QByteArray & /*buffer*/, ulong /*relay*/)
 {
   qWarning
     ("imapParser::parseReadLine - virtual function not reimplemented - no data read");
-  if (&buffer && relay);
   return FALSE;
 }
 
 void
-imapParser::parseWriteLine (const QString & str)
+imapParser::parseWriteLine (const QString & /*str*/)
 {
   qWarning
     ("imapParser::parseWriteLine - virtual function not reimplemented - no data written");
-  if (&str);
 }
 
 void
