@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: gscreator.cpp,v 1.9 2002/08/17 20:09:21 pfeiffer Exp $
+// $Id: gscreator.cpp,v 1.9.2.2 2003/05/18 12:35:58 mueller Exp $
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -42,7 +42,7 @@ extern "C"
     {
         return new GSCreator;
     }
-};
+}
 
 // This PS snippet will be prepended to the actual file so that only
 // the first page is output.
@@ -59,6 +59,8 @@ static const char *gsargs[] = {
     "gs",
     "-sDEVICE=png16m",
     "-sOutputFile=-",
+    "-dSAFER",
+    "-dPARANOIDSAFER",
     "-dNOPAUSE",
     "-dFirstPage=1",
     "-dLastPage=1",
