@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: htmlcreator.cpp,v 1.7.4.1 2002/12/06 04:43:36 mueller Exp $
+// $Id: htmlcreator.cpp,v 1.7.4.3 2003/05/18 12:35:58 mueller Exp $
 
 #include <time.h>
 
@@ -36,7 +36,7 @@ extern "C"
     {
         return new HTMLCreator;
     }
-};
+}
 
 HTMLCreator::HTMLCreator()
     : m_html(0)
@@ -58,6 +58,7 @@ bool HTMLCreator::create(const QString &path, int width, int height, QImage &img
         m_html->setJavaEnabled(false);
         m_html->setPluginsEnabled(false);
         m_html->setMetaRefreshEnabled(false);
+        m_html->setOnlyLocalReferences(true);
     }
     m_html->openURL(path);
     m_completed = false;
