@@ -18,8 +18,9 @@
 */
 
 #ifndef _TEXTCREATOR_H_
-#define _TEXTCREATOR_H_ "$Id: textcreator.h,v 1.4.2.1 2002/05/11 23:43:52 pfeiffer Exp $"
+#define _TEXTCREATOR_H_ "$Id: textcreator.h,v 1.6 2002/05/12 17:22:08 pfeiffer Exp $"
 
+#include <qpixmap.h>
 #include <kio/thumbcreator.h>
 
 class KPixmapSplitter;
@@ -36,6 +37,7 @@ private:
     KPixmapSplitter *m_splitter;
     char *m_data;
     int m_dataSize;
+    QPixmap m_pixmap;
 };
 
 #endif
