@@ -2,7 +2,7 @@
 
    configdialog.cpp (part of Klipper - Cut & paste history for KDE)
 
-   $Id: configdialog.cpp,v 1.42.2.3 2002/04/14 13:37:09 mkretz Exp $
+   $Id: configdialog.cpp,v 1.61 2002/11/09 17:26:48 pfeiffer Exp $
 
    (C) 2000 by Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -16,9 +16,10 @@
 #include <qpushbutton.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
+#include <qvbuttongroup.h>
 #include <assert.h>
 
-#include <kaboutdialog.h>
+#include <kclipboard.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
@@ -28,11 +29,11 @@
 
 #include "configdialog.h"
 
-ConfigDialog::ConfigDialog( const ActionList *list, KGlobalAccel *accel, 
+ConfigDialog::ConfigDialog( const ActionList *list, KGlobalAccel *accel,
                             bool isApplet )
-    : KDialogBase( KDialogBase::Tabbed, i18n("Klipper Preferences"),
-                    KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::Help,
-                    KDialogBase::Ok, 0L, "config dialog" )
+    : KDialogBase( Tabbed, i18n("Klipper Preferences"),
+                    Ok | Cancel | Help,
+                    Ok, 0L, "config dialog" )
 {
     if ( isApplet )
         setHelp( QString::null, "klipper" );
@@ -47,20 +48,6 @@ ConfigDialog::ConfigDialog( const ActionList *list, KGlobalAccel *accel,
 
     w = addVBoxPage( i18n("&Shortcuts") );
     keysWidget = new KKeyChooser( accel, w );
-
-
-    /* hmmm, this sort of sucks...
-    w = addVBoxPage( i18n("About") );
-    KAboutWidget *about = new KAboutWidget( w, "about widget" );
-
-    about->setAuthor("Andrew Stanley-Jones", "asj@cban.com",
-                     QString::null, QString::null);
-    about->addContributor("Carsten Pfeiffer", "pfeiffer@kde.org",
-                          QString::null, QString::null);
-    about->setMaintainer("Carsten Pfeiffer",
-                         QString::null, QString::null, QString::null);
-    about->setVersion( "0.7" );
-    */
 }
 
 
@@ -105,56 +92,74 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name )
 
     cbMousePos = new QCheckBox( i18n("&Popup menu at mouse-cursor position"),
                                 this );
-    cbSaveContents = new QCheckBox( i18n("Sa&ve clipboard contents on exit"),
+    cbSaveContents = new QCheckBox( i18n("Save clipboard contents on e&xit"),
                                     this );
     cbReplayAIH = new QCheckBox( i18n("&Replay actions on an item selected from history"),
                                     this );
-    cbSynchronize = new QCheckBox( i18n("Sy&nchronize contents of the clipboard and the selection."),
-                                    this );
-    cbSynchronize->hide();
-    QWhatsThis::add( cbSynchronize,
-     i18n("<qt>There are two different clipboard buffers available:<br><br>"
-          "The <b>Clipboard</b>, that you fill by selecting something<br>"
-          "and pressing Ctrl-C or by pressing \"Copy\" in a tool- or<br>"
-          "menubar.<br><br>"
-          "And the <b>Selection</b>, that is available immediately after<br>"
-          "selecting some text. The only way to access the selection<br>"
-          "is to press the middle mouse button.<br><br>"
-          "Selecting this option synchronizes those two buffers, so they<br>"
-          "work the same way as in KDE 1.x and 2.x</qt>") );
 
     cbNoNull = new QCheckBox( i18n("Pre&vent empty clipboard"), this );
-    QWhatsThis::add( cbNoNull, 
+    QWhatsThis::add( cbNoNull,
                      i18n("Selecting this option has the effect, that the "
                           "clipboard can never be emptied. E.g. when an "
                           "application exits, the clipboard would usually be "
                           "emptied.") );
-    
-    // make a QLabel because using popupTimeout->setLabel messes up layout
-    QLabel *lblTimeout = new QLabel( i18n("Tim&eout for Action popups:" ), this );
-    // workaround for KIntNumInput making a huge QSpinBox
-    QHBox *box = new QHBox( this );
-    popupTimeout = new KIntNumInput( box );
-    lblTimeout->setBuddy( popupTimeout );
-    popupTimeout->setRange( 0, 200, 1, false );
+
+    cbIgnoreSelection = new QCheckBox( i18n("&Ignore selection"), this );
+    QWhatsThis::add( cbIgnoreSelection,
+                     i18n("This option prevents the selection being recorded "
+                          "in the clipboard history. Only explicit clipboard "
+                          "changes are recorded.") );
+
+    QVButtonGroup *group = new QVButtonGroup( i18n("Clipboard/Selection Behavior"), this );
+    group->setExclusive( true );
+
+    QWhatsThis::add( group,
+     i18n("<qt>There are two different clipboard buffers available:<br><br>"
+          "<b>Clipboard</b> is filled by selecting something<br>"
+          "and pressing Ctrl+C, or by clicking \"Copy\" in a toolbar or<br>"
+          "menubar.<br><br>"
+          "<b>Selection</b> is available immediately after<br>"
+          "selecting some text. The only way to access the selection<br>"
+          "is to press the middle mouse button.<br><br>"
+          "You can configure the relationship between Clipboard and Selection."
+          "</qt>" ));
+
+    cbSynchronize = new QRadioButton(
+        i18n("Sy&nchronize contents of the clipboard and the selection"),
+        group );
+    QWhatsThis::add( cbSynchronize,
+      i18n("Selecting this option synchronizes these two buffers, so they "
+           "work the same way as in KDE 1.x and 2.x.") );
+
+    cbSeparate = new QRadioButton(
+        i18n("Separate clipboard and selection"), group );
+    QWhatsThis::add(
+        cbSeparate,
+        i18n("Using this option will only set the selection when highlighting "
+             "something and the clipboard when choosing e.g. \"Copy\" "
+             "in a menubar.") );
+
+    cbSynchronize->setChecked( KClipboardSynchronizer::isSynchronizing() );
+    cbSeparate->setChecked( !cbSynchronize->isChecked() );
+
+    popupTimeout = new KIntNumInput( this );
+    popupTimeout->setLabel( i18n( "Tim&eout for action popups:" ) );
+    popupTimeout->setRange( 0, 200, 1, true );
+    popupTimeout->setSuffix( i18n( " sec" ) );
     QToolTip::add( popupTimeout, i18n("A value of 0 disables the timeout") );
 
-    QLabel *lblSeconds = new QLabel( i18n("seconds"), box );
-    box->setStretchFactor( lblSeconds, 10 );
-    box->setSpacing(6);
+    maxItems = new KIntNumInput( this );
+    maxItems->setLabel(  i18n( "C&lipboard history size:" ) );
+    maxItems->setRange( 2, 25, 1, true );
+    connect( maxItems, SIGNAL( valueChanged( int )),
+             SLOT( historySizeChanged( int ) ));
 
-    QLabel *lblMaxItems = new QLabel( i18n("&Clipboard history size:"), this );
-    QHBox *maxItemsBox = new QHBox( this );
-    maxItems = new KIntNumInput( maxItemsBox );
-    lblMaxItems->setBuddy( maxItems );
-    maxItems->setRange( 2, 25, 1, false );
-
-    QLabel *lblItems = new QLabel( i18n("items"), maxItemsBox );
-    maxItemsBox->setStretchFactor( lblItems, 10 );
-    maxItemsBox->setSpacing(6);
+    connect( group, SIGNAL( clicked( int )),
+             SLOT( slotClipConfigChanged() ));
+    slotClipConfigChanged();
 
     // Add some spacing at the end
-    QLabel *dummy = new QLabel( this );
+    QWidget *dummy = new QWidget( this );
     setStretchFactor( dummy, 1 );
 }
 
@@ -162,6 +167,17 @@ GeneralWidget::~GeneralWidget()
 {
 }
 
+void GeneralWidget::historySizeChanged( int value )
+{
+    // Note there is no %n in this string, because value is not supposed
+    // to be put into the suffix of the spinbox.
+    maxItems->setSuffix( i18n( " entry", " entries", value ) );
+}
+
+void GeneralWidget::slotClipConfigChanged()
+{
+    cbIgnoreSelection->setEnabled( !cbSynchronize->isChecked() );
+}
 
 /////////////////////////////////////////
 ////
@@ -205,7 +221,7 @@ ActionWidget::ActionWidget( const ActionList *list, ConfigDialog* configWidget,
 
     listView = new ListView( configWidget, this, "list view" );
     lblAction->setBuddy( listView );
-    listView->addColumn( i18n("Regular expression (see http://doc.trolltech.com/qregexp.html#details)") );
+    listView->addColumn( i18n("Regular Expression (see http://doc.trolltech.com/qregexp.html#details)") );
     listView->addColumn( i18n("Description") );
 
     listView->setRenameable(0);
@@ -396,7 +412,7 @@ void ActionWidget::slotAdvanced()
 AdvancedWidget::AdvancedWidget( QWidget *parent, const char *name )
     : QVBox( parent, name )
 {
-    editListBox = new KEditListBox( i18n("D&isable actions for windows of type WM_CLASS:"), this, "editlistbox", true, KEditListBox::Add | KEditListBox::Remove );
+    editListBox = new KEditListBox( i18n("D&isable Actions for Windows of Type WM_CLASS"), this, "editlistbox", true, KEditListBox::Add | KEditListBox::Remove );
 
     QWhatsThis::add( editListBox,
           i18n("<qt>This lets you specify windows in which klipper should<br>"
