@@ -2,7 +2,7 @@
 
    configdialog.h (part of Klipper - Cut & paste history for KDE)
 
-   $Id: configdialog.h,v 1.25 2002/02/27 14:00:13 pfeiffer Exp $
+   $Id: configdialog.h,v 1.28 2002/08/30 20:55:52 pfeiffer Exp $
 
    (C) 2000 by Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -17,6 +17,7 @@
 #include <qevent.h>
 #include <qgroupbox.h>
 #include <qheader.h>
+#include <qradiobutton.h>
 #include <qvbox.h>
 
 #include <kdialogbase.h>
@@ -44,9 +45,14 @@ public:
     GeneralWidget( QWidget *parent, const char *name );
     ~GeneralWidget();
 
+private slots:
+    void historySizeChanged( int value );
+    void slotClipConfigChanged();
+
 private:
-    QCheckBox *cbMousePos, *cbSaveContents, *cbReplayAIH, *cbSynchronize;
-    QCheckBox *cbNoNull;
+    QCheckBox *cbMousePos, *cbSaveContents, *cbReplayAIH, *cbNoNull;
+    QCheckBox *cbIgnoreSelection;
+    QRadioButton *cbSynchronize, *cbImplicitSelection, *cbSeparate;
     KIntNumInput *popupTimeout, *maxItems;
 
 };
@@ -138,9 +144,6 @@ public:
     bool replayActionInHistory() const {
 	return generalWidget->cbReplayAIH->isChecked();
     }
-    bool synchronize() const {
-        return generalWidget->cbSynchronize->isChecked();
-    }
     bool noNullClipboard() const {
         return generalWidget->cbNoNull->isChecked();
     }
@@ -151,6 +154,10 @@ public:
     int maxItems() const {
 	return generalWidget->maxItems->value();
     }
+    bool ignoreSelection() const
+    {
+        return generalWidget->cbIgnoreSelection->isChecked();
+    }
     QStringList noActionsFor() const {
 	return actionWidget->wmClasses();
     }
@@ -159,6 +166,16 @@ public:
       return actionWidget->cbUseGUIRegExpEditor->isChecked();
     }
 
+
+    // KClipboard configuration
+    bool synchronize() const {
+        return generalWidget->cbSynchronize->isChecked();
+    }
+    bool implicitSelection() const {
+        return generalWidget->cbImplicitSelection->isChecked();
+    }
+    // ------------------------
+
     void setKeepContents( bool enable ) {
 	generalWidget->cbSaveContents->setChecked( enable );
     }
@@ -168,9 +185,6 @@ public:
     void setReplayActionInHistory( bool enable ) {
 	generalWidget->cbReplayAIH->setChecked( enable );
     }
-    void setSynchronize( bool enable ) {
-	generalWidget->cbSynchronize->setChecked( enable );
-    }
     void setNoNullClipboard( bool enable ) {
         generalWidget->cbNoNull->setChecked( enable );
     }
@@ -180,6 +194,9 @@ public:
     void setMaxItems( int items ) {
 	generalWidget->maxItems->setValue( items );
     }
+    void setIgnoreSelection( bool ignore ) {
+        generalWidget->cbIgnoreSelection->setChecked( ignore );
+    }
     void setNoActionsFor( const QStringList& items ) {
 	actionWidget->setWMClasses( items );
     }
@@ -205,7 +222,7 @@ class ListView : public KListView
 {
 public:
     ListView( ConfigDialog* configWidget, QWidget *parent, const char *name )
-	: KListView( parent, name ), _configWidget( configWidget ), 
+	: KListView( parent, name ), _configWidget( configWidget ),
           _regExpEditor(0L) {}
     // QListView has a weird idea of a sizeHint...
     virtual QSize sizeHint () const {
