@@ -2,7 +2,7 @@
 
    urlgrabber.cpp (part of Klipper - Cut & paste history for KDE)
 
-   $Id: urlgrabber.cpp,v 1.33.2.2 2003/01/05 19:28:59 mueller Exp $
+   $Id: urlgrabber.cpp,v 1.33.2.3 2003/06/29 21:53:10 deller Exp $
 
    (C) 2000,2001,2002 by Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -438,7 +438,7 @@ ClipAction::ClipAction( KConfig *kc )
         QString group = actionGroup + "/Command_%1";
         kc->setGroup( group.arg( i ) );
 
-        addCommand( kc->readEntry( "Commandline" ),
+        addCommand( kc->readPathEntry( "Commandline" ),
                     kc->readEntry( "Description" ), // i18n'ed
                     kc->readBoolEntry( "Enabled" ) );
     }
