@@ -89,7 +89,7 @@ void TreeItem::update()
     QString s = _name;
     if (_hidden)
        s += i18n(" [Hidden]");
-    setText(0, s);           
+    setText(0, s);
 }
 
 void TreeItem::setOpen(bool o)
@@ -103,6 +103,19 @@ void TreeItem::setOpen(bool o)
     QListViewItem::setOpen(o);
 }
 
+static QPixmap appIcon(const QString &iconName)
+{
+    QPixmap normal = KGlobal::iconLoader()->loadIcon(iconName, KIcon::Small, 0, KIcon::DefaultState, 0L, true);
+    // make sure they are not larger than 20x20
+    if (normal.width() > 20 || normal.height() > 20)
+    {
+       QImage tmp = normal.convertToImage();
+       tmp = tmp.smoothScale(20, 20);
+       normal.convertFromImage(tmp);
+    }
+    return normal;
+}
+
 
 TreeView::TreeView( KActionCollection *ac, QWidget *parent, const char *name )
     : KListView(parent, name), _ac(ac), _rmb(0)
@@ -149,7 +162,7 @@ void TreeView::setViewMode(bool showHidden)
     // setup rmb menu
     _rmb = new QPopupMenu(this);
     KAction *action;
-    
+
     action = _ac->action("edit_cut");
     if(action) {
         action->plug(_rmb);
@@ -172,7 +185,7 @@ void TreeView::setViewMode(bool showHidden)
     }
 
     _rmb->insertSeparator();
-    
+
     action = _ac->action("delete");
     if(action) {
         action->plug(_rmb);
@@ -217,7 +230,7 @@ QString TreeView::findName(KDesktopFile *df, bool deleted)
        {
           QString file = df->fileName();
           QString res = df->resource();
-          
+
           bool isLocal = true;
           QStringList files = KGlobal::dirs()->findAllResources(res.latin1(), file);
           for(QStringList::ConstIterator it = files.begin();
@@ -229,7 +242,7 @@ QString TreeView::findName(KDesktopFile *df, bool deleted)
                 isLocal = false;
                 continue;
              }
-             
+
              KDesktopFile df2(*it);
              name = df2.readName();
 
@@ -270,13 +283,13 @@ void TreeView::fillBranch(const QString& rPath, TreeItem *parent)
                 continue;
 
             TreeItem* item;
-            if (parent == 0) 
+            if (parent == 0)
                 item = new TreeItem(this, *it);
-            else 
+            else
                 item = new TreeItem(parent, *it);
 
             item->setName(name);
-            item->setPixmap(0, KGlobal::iconLoader()->loadIcon(df.readIcon(),KIcon::Desktop, KIcon::SizeSmall));
+            item->setPixmap(0, appIcon(df.readIcon()));
 
             item->setHidden(hidden);
 	}
@@ -291,7 +304,7 @@ void TreeView::fillBranch(const QString& rPath, TreeItem *parent)
 
 	    QString dirFile = *it + "/.directory";
 	    TreeItem* item;
-	    
+
 	    bool hidden = false;
 	    QString name;
 	    QString icon;
@@ -308,15 +321,14 @@ void TreeView::fillBranch(const QString& rPath, TreeItem *parent)
             icon = df.readIcon();
             if (icon.isEmpty())
                 icon = "package";
-            
+
             if (parent == 0)
                 item = new TreeItem(this,  *it);
             else
                 item = new TreeItem(parent, *it);
 
             item->setName(name);
-            item->setPixmap(0, KGlobal::iconLoader()->
-                               loadIcon(icon,KIcon::Desktop, KIcon::SizeSmall));
+            item->setPixmap(0, appIcon(icon));
 
             item->setHidden(hidden);
             item->setExpandable(true);
@@ -338,7 +350,7 @@ void TreeView::itemSelected(QListViewItem *item)
 #if 0
         // Check if the file is Writeable for us
         QFileInfo finfo((KGlobal::dirs()->findResourceDir("apps", _item->file())) + _item->file());
-       
+
         if (finfo.isWritable() && (_item->name() != i18n("Settings")))
             _ac->action("delete")->setEnabled(true);
         else
@@ -366,8 +378,7 @@ void TreeView::currentChanged()
 
     KDesktopFile df(item->file());
     item->setName(findName(&df, item->isHidden()));
-    item->setPixmap(0, KGlobal::iconLoader()
-		    ->loadIcon(df.readIcon(),KIcon::Desktop, KIcon::SizeSmall));
+    item->setPixmap(0, appIcon(df.readIcon()));
 }
 
 // moving = src will be removed later
@@ -483,7 +494,7 @@ bool TreeView::deleteFile(const QString& deskfile, const bool move)
     // search the selected item in all resource dirs
     QStringList resdirs = KGlobal::dirs()->resourceDirs("apps");
     QString localFile = resdirs.first()+deskfile;
-    
+
     for (QStringList::ConstIterator it = resdirs.begin(); it != resdirs.end(); ++it) {
         QFile f((*it) + deskfile);
 
@@ -495,7 +506,7 @@ bool TreeView::deleteFile(const QString& deskfile, const bool move)
            else
               hasGlobal = true;
         }
-        
+
         isLocal = false;
     }
 
@@ -521,7 +532,7 @@ bool TreeView::deleteFile(const QString& deskfile, const bool move)
         }
         c.sync();
     }
-    
+
     return true;
 }
 
@@ -567,7 +578,7 @@ bool TreeView::deleteDir(const QString& d, const bool move)
             allremoved = false;
     }
 #endif
-    
+
     if(move) {
         KSimpleConfig c(locateLocal("apps", directory + "/.directory"));
         c.setDesktopGroup();
@@ -729,13 +740,24 @@ void TreeView::slotDropped (QDropEvent * e, QListViewItem *parent, QListViewItem
     }
 }
 
+void TreeView::startDrag()
+{
+  QDragObject *drag = dragObject();
+  
+  if (!drag)
+     return;
+            
+  drag->dragMove();
+}                  
+
 QDragObject *TreeView::dragObject()
 {
     TreeItem *item = (TreeItem*)selectedItem();
     if(item == 0) return 0;
 
     QTextDrag *d = new QTextDrag(item->file(), (QWidget*)this);
-    d->setPixmap(*item->pixmap(0));
+    if ( item->pixmap(0) )
+        d->setPixmap(*item->pixmap(0));
     return d;
 }
 
@@ -804,7 +826,7 @@ void TreeView::newsubmenu()
 	dir += '/';
 
     dir += dirname + "/.directory";
-    
+
     QFile f(locateLocal("apps", dir));
     if (f.exists()) {
     	KMessageBox::sorry(0, i18n("A file exists with that name. Please provide another name."), i18n("File Exists"));
@@ -819,7 +841,7 @@ void TreeView::newsubmenu()
 	newitem = new TreeItem(parent, after, dir);
 
     newitem->setName(dirname);
-    newitem->setPixmap(0, KGlobal::iconLoader()->loadIcon("package", KIcon::Desktop, KIcon::SizeSmall));
+    newitem->setPixmap(0, appIcon("package"));
     newitem->setExpandable(true);
 
     KConfig c(locateLocal("apps", dir));
@@ -888,7 +910,7 @@ void TreeView::newitem()
 	newitem = new TreeItem(parent, after, dir);
 
     newitem->setName(filename);
-    newitem->setPixmap(0, KGlobal::iconLoader()->loadIcon("unkown", KIcon::Desktop, KIcon::SizeSmall));
+    newitem->setPixmap(0, appIcon("unkown"));
 
     KConfig c(locateLocal("apps", dir));
     c.setDesktopGroup();
@@ -989,9 +1011,11 @@ void TreeView::paste()
 
     while (f.exists()) {
         pos = newname.findRev(".desktop");
-        newname.insert(pos, " (Copy)");
-
-        f.setName(locate("apps", dest + '/' + newname));
+        if ( pos!=-1)// .directory
+            newname.insert(pos, " (Copy)");
+        else
+            newname.insert(newname.length(), " (Copy)");
+        f.setName(locate("apps", dest + '/' + newname));			
     }
 
     kdDebug() << "### clip: " << _clipboard.local8Bit() << " dest: " << dest.local8Bit() << " ###" << endl;
@@ -1031,7 +1055,7 @@ void TreeView::paste()
         newitem->setFile(dest + '/' + newname);
     else
         newitem->setFile(newname);
-    newitem->setPixmap(0, KGlobal::iconLoader()->loadIcon(df.readIcon(),KIcon::Desktop, KIcon::SizeSmall));
+    newitem->setPixmap(0, appIcon(df.readIcon()));
 
     fillBranch(newitem->file(), newitem);
     setSelected ( newitem, true);
@@ -1089,7 +1113,7 @@ void TreeView::undel()
     df.deleteEntry("Hidden");
     df.deleteEntry("NoDisplay");
     df.sync();
-    
+
     item->setHidden(false);
 
     _ac->action("edit_cut")->setEnabled(false);
