@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kfmclient.cc,v 1.87.2.1 2002/12/17 21:39:07 mueller Exp $
+// $Id: kfmclient.cc,v 1.87.2.6 2003/06/29 21:53:11 deller Exp $
 
 #include <errno.h>
 #include <stdlib.h>
@@ -40,16 +40,22 @@
 #include <kfiledialog.h>
 #include <kdebug.h>
 #include <dcopclient.h>
+#include <kglobalsettings.h>
 
 #include "kfmclient.h"
 #include "KonquerorIface_stub.h"
 #include "KDesktopIface_stub.h"
 
-static const char *appName = "kfmclient";
+#include <X11/Xlib.h>
 
-static const char *description = I18N_NOOP("KDE tool for opening URLs from the command line");
+static const char appName[] = "kfmclient";
 
-static const char *version = "2.0";
+static const char description[] = I18N_NOOP("KDE tool for opening URLs from the command line");
+
+static const char version[] = "2.0";
+
+QCString clientApp::startup_id_str;
+bool clientApp::m_ok;
 
 static const KCmdLineOptions options[] =
 {
@@ -133,14 +139,14 @@ int main( int argc, char **argv )
     return 0;
   }
 
-  clientApp a;
-
-  return a.doIt() ? 0 /*no error*/ : 1 /*error*/;
+  return clientApp::doIt() ? 0 /*no error*/ : 1 /*error*/;
 }
 
 /** Whether to start a new konqueror or reuse an existing process */
 static bool startNewKonqueror( const KURL & url )
 {
+    if( KGlobalSettings::isMultiHead())
+        return true;
     KConfig config( QString::fromLatin1("kfmclientrc") );
     config.setGroup( QString::fromLatin1("Settings") );
     // Current default: reuse an existing process for local urls, create a new one for remote ones
@@ -165,7 +171,7 @@ bool clientApp::createNewWindow(const KURL & url, const QString & mimetype)
 	// check if user wants to use external browser
 	KConfig config( QString::fromLatin1("kfmclientrc"));
 	config.setGroup( QString::fromLatin1("Settings"));
-	QString strBrowser = config.readEntry( QString::fromLatin1("ExternalBrowser"));
+	QString strBrowser = config.readPathEntry( QString::fromLatin1("ExternalBrowser"));
 	if (!strBrowser.isEmpty())
 	{
 		KProcess proc;
@@ -180,13 +186,19 @@ bool clientApp::createNewWindow(const KURL & url, const QString & mimetype)
     {
         kdDebug() << "clientApp::createNewWindow using existing konqueror" << endl;
         KonquerorIface_stub konqy( appId, appObj );
-        konqy.createNewWindowASN( url.url(), mimetype, kapp->startupId());
+        konqy.createNewWindowASN( url.url(), mimetype, startup_id_str );
         KStartupInfoId id;
-        id.initId( kapp->startupId());
+        id.initId( startup_id_str );
         KStartupInfoData data;
         data.addPid( 0 );   // say there's another process for this ASN with unknown PID
         data.setHostname(); // ( no need to bother to get this konqy's PID )
-        KStartupInfo::sendChange( id, data );
+        Display* dpy = qt_xdisplay();
+        if( dpy == NULL ) // we may be running without QApplication here
+            dpy = XOpenDisplay( NULL );
+        if( dpy != NULL )
+            KStartupInfo::sendChangeX( dpy, id, data );
+        if( dpy != NULL && dpy != qt_xdisplay())
+            XCloseDisplay( dpy );
     }
     else
     {
@@ -199,7 +211,7 @@ bool clientApp::createNewWindow(const KURL & url, const QString & mimetype)
             */
             // pass kfmclient's startup id to konqueror using kshell
             KStartupInfoId id; 
-            id.initId( kapp->startupId());
+            id.initId( startup_id_str );
             id.setupStartupEnv();
             KProcess proc;
             if ( mimetype.isEmpty() )
@@ -214,11 +226,8 @@ bool clientApp::createNewWindow(const KURL & url, const QString & mimetype)
     return true;
 }
 
-bool clientApp::openProfile( const QString & filename, const QString & url, const QString & mimetype )
+bool clientApp::openProfile( const QString & profileName, const QString & url, const QString & mimetype )
 {
-  m_profileName = filename;
-  m_url = url;
-  m_mimetype = mimetype;
   QByteArray data;
   QCString appId, appObj;
   if ( startNewKonqueror(KURL(url)) ||
@@ -227,7 +236,7 @@ bool clientApp::openProfile( const QString & filename, const QString & url, cons
   {
     QString error;
     if ( KApplication::startServiceByDesktopPath( QString::fromLatin1("konqueror.desktop"),
-        QString::fromLatin1("--silent"), &error, &appId, NULL, kapp->startupId()) > 0 )
+        QString::fromLatin1("--silent"), &error, &appId, NULL, startup_id_str ) > 0 )
     {
       kdError() << "Couldn't start konqueror from konqueror.desktop: " << error << endl;
       return false;
@@ -236,26 +245,32 @@ bool clientApp::openProfile( const QString & filename, const QString & url, cons
     // so when we arrive here, konq is up and running already, and appId contains the identification
   }
 
-  QString profile = locate( "data", QString::fromLatin1("konqueror/profiles/") + m_profileName );
+  QString profile = locate( "data", QString::fromLatin1("konqueror/profiles/") + profileName );
   if ( profile.isEmpty() )
   {
-      fprintf( stderr, "%s", i18n("Profile %1 not found\n").arg(m_profileName).local8Bit().data() );
+      fprintf( stderr, "%s", i18n("Profile %1 not found\n").arg(profileName).local8Bit().data() );
       ::exit( 0 );
   }
   KonquerorIface_stub konqy( appId, "KonquerorIface" );
-  if ( m_url.isEmpty() )
-      konqy.createBrowserWindowFromProfileASN( profile, m_profileName, kapp->startupId());
-  else if ( m_mimetype.isEmpty() )
-      konqy.createBrowserWindowFromProfileAndURLASN( profile, m_profileName, m_url, kapp->startupId());
+  if ( url.isEmpty() )
+      konqy.createBrowserWindowFromProfileASN( profile, profileName, startup_id_str );
+  else if ( mimetype.isEmpty() )
+      konqy.createBrowserWindowFromProfileAndURLASN( profile, profileName, url, startup_id_str );
   else
-      konqy.createBrowserWindowFromProfileAndURLASN( profile, m_profileName, m_url, m_mimetype, kapp->startupId());
+      konqy.createBrowserWindowFromProfileAndURLASN( profile, profileName, url, mimetype, startup_id_str );
   sleep(2); // Martin Schenk <martin@schenk.com> says this is necessary to let the server read from the socket
   KStartupInfoId id;
-  id.initId( kapp->startupId());
+  id.initId( startup_id_str );
   KStartupInfoData sidata;
   sidata.addPid( 0 );   // say there's another process for this ASN with unknown PID
   sidata.setHostname(); // ( no need to bother to get this konqy's PID )
-  KStartupInfo::sendChange( id, sidata );
+  Display* dpy = qt_xdisplay();
+  if( dpy == NULL ) // we may be running without QApplication here
+      dpy = XOpenDisplay( NULL );
+  if( dpy != NULL )
+      KStartupInfo::sendChangeX( dpy, id, sidata );
+  if( dpy != NULL && dpy != qt_xdisplay())
+      XCloseDisplay( dpy );
   return true;
 }
 
@@ -288,8 +303,17 @@ bool clientApp::doIt()
 
   QCString command = args->arg(0);
 
+  // read ASN env. variable for non-KApp cases  
+  startup_id_str = KStartupInfo::currentStartupIdEnv().id();
+
   if ( command == "openURL" )
   {
+    KInstance inst(appName);
+    if( !KApplication::dcopClient()->attach())
+    {
+	KApplication::startKdeinit();
+	KApplication::dcopClient()->attach();
+    }
     checkArgumentCount(argc, 1, 3);
     if ( argc == 1 )
     {
@@ -308,18 +332,28 @@ bool clientApp::doIt()
   }
   else if ( command == "openProfile" )
   {
+    KInstance inst(appName);
+    if( !KApplication::dcopClient()->attach())
+    {
+	KApplication::startKdeinit();
+	KApplication::dcopClient()->attach();
+    }
     checkArgumentCount(argc, 2, 3);
     QString url;
     if ( argc == 3 )
       url = args->url(2).url();
     return openProfile( QString::fromLocal8Bit(args->arg(1)), url );
   }
-  else if ( command == "openProperties" )
+  
+  // the following commands need KApplication
+  clientApp app;
+  
+  if ( command == "openProperties" )
   {
     checkArgumentCount(argc, 2, 2);
     KPropertiesDialog * p = new KPropertiesDialog( args->url(1) );
-    QObject::connect( p, SIGNAL( destroyed() ), this, SLOT( quit() ));
-    exec();
+    QObject::connect( p, SIGNAL( destroyed() ), &app, SLOT( quit() ));
+    app.exec();
     return m_ok;
   }
   else if ( command == "exec" )
@@ -334,9 +368,9 @@ bool clientApp::doIt()
     {
       KFileOpenWithHandler fowh;
       KRun * run = new KRun( args->url(1) );
-      QObject::connect( run, SIGNAL( finished() ), this, SLOT( delayedQuit() ));
-      QObject::connect( run, SIGNAL( error() ), this, SLOT( delayedQuit() ));
-      exec();
+      QObject::connect( run, SIGNAL( finished() ), &app, SLOT( delayedQuit() ));
+      QObject::connect( run, SIGNAL( error() ), &app, SLOT( delayedQuit() ));
+      app.exec();
       return m_ok;
     }
     else if ( argc == 3 )
@@ -357,8 +391,8 @@ bool clientApp::doIt()
       srcLst.append( args->url(i) );
 
     KIO::Job * job = KIO::move( srcLst, args->url(argc - 1) );
-    connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotResult( KIO::Job * ) ) );
-    exec();
+    connect( job, SIGNAL( result( KIO::Job * ) ), &app, SLOT( slotResult( KIO::Job * ) ) );
+    app.exec();
     return m_ok;
   }
   else if ( command == "download" )
@@ -388,8 +422,8 @@ bool clientApp::doIt()
     if (dst == QString::null)
        return m_ok; // AK - really okay?
     KIO::Job * job = KIO::copy( srcLst, dst );
-    connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotResult( KIO::Job * ) ) );
-    exec();
+    connect( job, SIGNAL( result( KIO::Job * ) ), &app, SLOT( slotResult( KIO::Job * ) ) );
+    app.exec();
     return m_ok;
   }
   else if ( command == "copy" )
@@ -400,8 +434,8 @@ bool clientApp::doIt()
       srcLst.append( args->url(i) );
 
     KIO::Job * job = KIO::copy( srcLst, args->url(argc - 1) );
-    connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotResult( KIO::Job * ) ) );
-    exec();
+    connect( job, SIGNAL( result( KIO::Job * ) ), &app, SLOT( slotResult( KIO::Job * ) ) );
+    app.exec();
     return m_ok;
   }
   else if ( command == "sortDesktop" )
