@@ -297,6 +297,12 @@ bool KonqCombo::eventFilter( QObject *o, QEvent *ev )
         if ( type == QEvent::KeyPress ) {
             QKeyEvent *e = static_cast<QKeyEvent *>( ev );
 
+            if ( e->key() == Key_Return || e->key() == Key_Enter ) {
+                emit activated( currentText(), e->state() );
+                e->accept();
+                return true;
+            }
+
             if ( KStdAccel::isEqual( e, KStdAccel::deleteWordBack() ) ||
                  KStdAccel::isEqual( e, KStdAccel::deleteWordForward() ) ||
                  ((e->state() & ControlButton) &&
@@ -308,7 +314,7 @@ bool KonqCombo::eventFilter( QObject *o, QEvent *ev )
         }
 
         else if ( type == QEvent::MouseButtonDblClick ) {
-            lineEdit()->selectAll();
+            edit->selectAll();
             return true;
         }
     }
