@@ -162,7 +162,7 @@ QString KonqMisc::konqFilteredURL( QWidget* parent, const QString& _url, const Q
 }
 
 KonqDraggableLabel::KonqDraggableLabel( KonqMainWindow* mw, const QString& text )
-  : QLabel( text, 0L, "kde toolbar widget" )	// Use this name for it to be styled!
+  : QLabel( text, mw, "kde toolbar widget" )	// Use this name for it to be styled!
   , m_mw(mw)
 {
   setBackgroundMode( Qt::PaletteButton );
@@ -208,8 +208,15 @@ void KonqDraggableLabel::dragEnterEvent( QDragEnterEvent *ev )
 
 void KonqDraggableLabel::dropEvent( QDropEvent* ev )
 {
-  KURL::List lst;
-  if ( KURLDrag::decode( ev, lst ) ) {
-    m_mw->openURL( 0L, lst.first() );
+  _savedLst.clear();
+  if ( KURLDrag::decode( ev, _savedLst ) ) {
+    QTimer::singleShot(0, this, SLOT(delayedOpenURL()));
   }
 }
+
+void KonqDraggableLabel::delayedOpenURL()
+{
+    m_mw->openURL( 0L, _savedLst.first() );
+}
+
+#include "konq_misc.moc"
