@@ -195,6 +195,12 @@ void KonqRun::slotRedirection( KIO::Job *job, const KURL& redirectedToURL )
        return; // Error will follow
     }
     KonqHistoryManager::kself()->addPending( redirectedToURL );
+
+    // Do not post data on reload if we were redirected to a new URL when
+    // doing a POST request.
+    if (redirectFromURL != redirectedToURL)
+        m_args.setDoPost (false);
+    m_args.setRedirectedRequest(true);
 }
 
 #include "konq_run.moc"
