@@ -57,6 +57,11 @@ KonqView* KonqViewManager::Initialize( const QString &serviceType, const QString
   KService::Ptr service;
   KTrader::OfferList partServiceOffers, appServiceOffers;
   KonqViewFactory newViewFactory = createView( serviceType, serviceName, service, partServiceOffers, appServiceOffers, true );
+  if ( newViewFactory.isNull() )
+  {
+    kdDebug(1202) << "KonqViewManager::Initialize() No suitable factory found." << endl;
+    return 0;
+  }
   KonqView* childView = setupView( m_pMainWindow, newViewFactory, service, partServiceOffers, appServiceOffers, serviceType, false );
   setActivePart( childView->part() );
   m_pDocContainer = childView->frame();
@@ -194,6 +199,10 @@ KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation,
 {
   kdDebug(1202) << "KonqViewManager::splitWindow(default)" << endl;
 
+  // Don't crash when doing things too quickly.
+  if (!m_pMainWindow || !m_pMainWindow->currentView())
+    return 0L;
+
   KURL url = m_pMainWindow->currentView()->url();
   QString locationBarURL = m_pMainWindow->currentView()->locationBarURL();
 
@@ -513,18 +522,25 @@ void KonqViewManager::removeTab( KonqFrameBase* tab )
   printFullHierarchy( m_pMainWindow );
 #endif
 
-  if (m_pDocContainer == 0L) return;
-  if (m_pDocContainer->frameType() != "Tabs") return;
+  if (m_pDocContainer == 0L)
+    return;
+  if (m_pDocContainer->frameType() != "Tabs")
+    return;
 
   KonqFrameTabs* tabContainer = static_cast<KonqFrameTabs*>(m_pDocContainer);
 
   KonqFrameBase* currentFrame;
-  if ( tab == 0L )
-    currentFrame = dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
-  else
+  if ( tab != 0L ) {
     currentFrame = tab;
+  } else {
+    currentFrame = dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
+    if (!currentFrame) {
+      return;
+    }
+  }
 
-  if (currentFrame->widget() == tabContainer->currentPage()) setActivePart( 0L, true );
+  if (currentFrame->widget() == tabContainer->currentPage())
+    setActivePart( 0L, true );
 
   tabContainer->removeChildFrame(currentFrame);
 
@@ -535,14 +551,16 @@ void KonqViewManager::removeTab( KonqFrameBase* tab )
 
   for ( it.toFirst(); it != 0L; ++it )
   {
-    if (it.current()==m_pMainWindow->currentView()) setActivePart( 0L, true );
+    if (it.current() == m_pMainWindow->currentView())
+      setActivePart( 0L, true );
     m_pMainWindow->removeChildView( it.current() );
     delete it.current();
   }
 
   delete currentFrame;
 
-  if (tabContainer->count() == 1) revertDocContainer();
+  if (tabContainer->count() == 1)
+    revertDocContainer();
 
 #ifndef NDEBUG
   m_pMainWindow->dumpViewList();
@@ -628,6 +646,9 @@ void KonqViewManager::removeView( KonqView *view )
   printFullHierarchy( m_pMainWindow );
 #endif
 
+  if (!view)
+    return;
+
   KonqFrame* frame = view->frame();
   KonqFrameContainerBase* parentContainer = frame->parentContainer();
 
@@ -744,7 +765,7 @@ void KonqViewManager::removePart( KParts::Part * part )
   {
       kdDebug(1202) << "Found a child view" << endl;
       view->partDeleted(); // tell the child view that the part auto-deletes itself
-      if (m_pMainWindow->viewCount() == 1)
+      if (m_pMainWindow->mainViewsCount() == 1)
       {
         kdDebug(1202) << "Deleting last view -> closing the window" << endl;
         clear();
@@ -993,7 +1014,7 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
                                        const KURL & forcedURL, const KonqOpenURLRequest &req )
 {
   m_currentProfile = filename;
-  m_currentProfileText = cfg.readEntry("Name",filename);
+  m_currentProfileText = cfg.readPathEntry("Name",filename);
   m_pMainWindow->currentProfileChanged();
   KURL defaultURL;
   if ( m_pMainWindow->currentView() )
@@ -1269,7 +1290,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
     {
       KURL url( defaultURL );
       if ( cfg.hasKey( key ) ) // if it has it, we load it, even if empty
-        url = KURL( cfg.readEntry( key ) );
+        url = KURL( cfg.readPathEntry( key ) );
 
       if ( !url.isEmpty() )
       {
