@@ -48,7 +48,7 @@ ColumnInfo::ColumnInfo()
    ,udsId(0)
    ,displayThisOne(FALSE)
    ,toggleThisOne(0)
-{};
+{}
 
 
 ColumnInfo::ColumnInfo(const char* n, const char* desktopName, int kioUds,int count,bool enabled,KToggleAction* someAction)
@@ -68,7 +68,7 @@ void ColumnInfo::setData(const char* n, const char* desktopName, int kioUds,int
    udsId=kioUds;
    displayThisOne=enabled;
    toggleThisOne=someAction;
-};
+}
 
 
 KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *parentWidget)
@@ -77,6 +77,7 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
 ,m_pBrowserView(parent)
 ,m_dirLister(new KDirLister( true /*m_showIcons==FALSE*/))
 ,m_dragOverItem(0)
+,m_selected(0)
 ,m_scrollTimer(0)
 ,m_rubber(0)
 ,m_showIcons(true)
@@ -172,6 +173,8 @@ KonqBaseListViewWidget::~KonqBaseListViewWidget()
 {
    kdDebug(1202) << "-KonqBaseListViewWidget" << endl;
 
+   delete m_selected;
+
    // TODO: this is a hack, better fix the connections of m_dirLister if possible!
    m_dirLister->disconnect( this );
    delete m_dirLister;
@@ -332,7 +335,7 @@ void KonqBaseListViewWidget::contentsMousePressEvent( QMouseEvent *e )
       m_rubber = 0;
    }
 
-   m_selected.clear();
+   delete m_selected; m_selected = 0;
 
    QPoint vp = contentsToViewport( e->pos() );
    KonqBaseListViewItem *item = isExecuteArea( vp ) ?
@@ -345,7 +348,10 @@ void KonqBaseListViewWidget::contentsMousePressEvent( QMouseEvent *e )
       {
          m_rubber = new QRect( e->x(), e->y(), 0, 0 );
          if ( e->state() & ControlButton )
+         {
+            m_selected = new QPtrList<KonqBaseListViewItem>;
             selectedItems( m_selected );
+         }
          else
             setSelected( itemAt( vp ), false );
       }
@@ -372,7 +378,7 @@ void KonqBaseListViewWidget::contentsMouseReleaseEvent( QMouseEvent *e )
       m_scrollTimer = 0;
    }
 
-   m_selected.clear();
+   delete m_selected; m_selected = 0;
    KListView::contentsMouseReleaseEvent( e );
 }
 
@@ -462,7 +468,7 @@ void KonqBaseListViewWidget::slotAutoScroll()
          {
             if ( !cur->isSelected() && cur->isSelectable() )
                setSelected( cur, true );
-         } else if ( !m_selected.contains( (KonqBaseListViewItem*)cur ) )
+         } else if ( !m_selected || !m_selected->contains( (KonqBaseListViewItem*)cur ) )
             setSelected( cur, false );
 
          cur = cur->itemBelow();
@@ -479,7 +485,7 @@ void KonqBaseListViewWidget::slotAutoScroll()
          {
             if ( !cur->isSelected() && cur->isSelectable() )
                setSelected( cur, true );
-         } else if ( !m_selected.contains( (KonqBaseListViewItem*)cur ) )
+         } else if ( !m_selected || !m_selected->contains( (KonqBaseListViewItem*)cur ) )
             setSelected( cur, false );
 
          cur = cur->itemAbove();
@@ -725,12 +731,12 @@ void KonqBaseListViewWidget::slotExecuted( QListViewItem* item )
   }
 }
 
-void KonqBaseListViewWidget::selectedItems( QValueList<KonqBaseListViewItem*>& _list )
+void KonqBaseListViewWidget::selectedItems( QPtrList<KonqBaseListViewItem>* _list )
 {
    iterator it = begin();
    for( ; it != end(); it++ )
       if ( it->isSelected() )
-         _list.append( &*it );
+         _list->append( &*it );
 }
 
 KFileItemList KonqBaseListViewWidget::selectedFileItems()
@@ -790,11 +796,10 @@ void KonqBaseListViewWidget::popupMenu( const QPoint& _global, bool alwaysForSel
    // a popup for the current dir instead.
    if ((alwaysForSelectedFiles) || (isExecuteArea( viewport()->mapFromGlobal( _global ) )))
    {
-       QValueList<KonqBaseListViewItem*> items;
-       selectedItems( items );
-       QValueList<KonqBaseListViewItem*>::Iterator it = items.begin();
-       for( ; it != items.end(); ++it )
-          lstItems.append( (*it)->item() );
+       QPtrList<KonqBaseListViewItem> items;
+       selectedItems( &items );
+       for(KonqBaseListViewItem *item = items.first(); item; item = items.next())
+          lstItems.append( item->item() );
    }
 
    KFileItem * rootItem = 0L;
@@ -968,6 +973,7 @@ void KonqBaseListViewWidget::slotClear()
 {
    kdDebug(1202) << k_funcinfo << endl;
 
+   delete m_selected; m_selected = 0;
    m_pBrowserView->resetCount();
    m_pBrowserView->lstPendingMimeIconItems().clear();
 
