@@ -248,14 +248,16 @@ void HistorySidebarConfig::slotOlderChanged( int value )
 
 void HistorySidebarConfig::slotGetFontNewer()
 {
-    (void) KFontDialog::getFont( m_fontNewer, false, this );
-    configChanged();
+    int result = KFontDialog::getFont( m_fontNewer, false, this );
+    if ( result == KFontDialog::Accepted )
+        configChanged();
 }
 
 void HistorySidebarConfig::slotGetFontOlder()
 {
-    (void) KFontDialog::getFont( m_fontOlder, false, this );
-    configChanged();
+    int result = KFontDialog::getFont( m_fontOlder, false, this );
+    if ( result == KFontDialog::Accepted )
+        configChanged();
 }
 
 void HistorySidebarConfig::slotClearHistory()
