@@ -93,9 +93,19 @@
 
 #include <sys/types.h>
 #include <sys/ioctl.h>
+#include <time.h>
+
+#ifdef HAVE_SYS_TIME_H
 #ifdef TIME_WITH_SYS_TIME
-  #include <sys/time.h>
+#include <sys/time.h>
+#include <time.h>
+#else
+#include <sys/time.h>
 #endif
+#else
+#include <time.h>
+#endif
+
 #include <sys/resource.h>
 #ifdef HAVE_SYS_STROPTS_H
 #include <sys/stropts.h>
@@ -144,6 +154,10 @@ extern "C" {
 #include <bsdtty.h>
 #endif
 
+#if defined(HAVE_PTY_H)
+#include <pty.h>
+#endif
+
 #include <qintdict.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
@@ -151,23 +165,31 @@ extern "C" {
 #include "TEPty.h"
 #include "TEPty.moc"
 
+#define TTY_GROUP "tty"
 
 #include <kstandarddirs.h>
+#include <klocale.h>
 #include <kdebug.h>
 
 #ifndef HERE
 #define HERE fprintf(stdout,"%s(%d): here\n",__FILE__,__LINE__)
 #endif
 
+// Small hack to keep it still compiling with KDE 3.0
+#include "kdeversion.h"
+#if KDE_VERSION <306
+  #undef HAVE_OPENPTY
+#endif
+
 template class QIntDict<TEPty>;
 
 class KUtmpProcess : public KProcess
 {
 public:
-   int commSetupDoneC() 
+   int commSetupDoneC()
    {
-     dup2(cmdFd, 0);   
-     dup2(cmdFd, 1);   
+     dup2(cmdFd, 0);
+     dup2(cmdFd, 1);
      dup2(cmdFd, 3);
      return 1;
    }
@@ -179,9 +201,9 @@ FILE* syslog_file = NULL; //stdout;
 #define PTY_FILENO 3
 #define BASE_CHOWN "konsole_grantpty"
 
-int chownpty(int fd, int grant)
+int chownpty(int fd, bool grant)
 // param fd: the fd of a master pty.
-// param grant: 1 to grant, 0 to revoke
+// param grant: true to grant, false to revoke
 // returns 1 on success 0 on fail
 {
   struct sigaction newsa, oldsa;
@@ -209,8 +231,9 @@ int chownpty(int fd, int grant)
 
   if (pid > 0) {
     int w;
+
 retry:
-    int rc = waitpid (pid, &w, 0);
+    int rc = waitpid(pid, &w, 0);
     if ((rc == -1) && (errno == EINTR))
       goto retry;
 
@@ -233,20 +256,19 @@ retry:
 void TEPty::setSize(int lines, int columns)
 {
   //kdDebug(1211)<<"TEPty::setSize()"<<endl;
-  wsize.ws_row = (unsigned short)lines;
-  wsize.ws_col = (unsigned short)columns;
-  if(fd < 0) return;
-  ioctl(fd,TIOCSWINSZ,(char *)&wsize);
+  m_WSize.ws_row = (unsigned short)lines;
+  m_WSize.ws_col = (unsigned short)columns;
+  if(m_MasterFd < 0) return;
+  ioctl(m_MasterFd, TIOCSWINSZ,(char *)&m_WSize);
   //kdDebug(1211)<<"TEPty::setSize() done"<<endl;
 }
 
-void TEPty::donePty()
+void TEPty::commClose()
 {
-  int status = exitStatus();
 #ifdef HAVE_UTEMPTER
   {
      KUtmpProcess utmp;
-     utmp.cmdFd = fd;
+     utmp.cmdFd = m_MasterFd;
      utmp << "/usr/sbin/utempter" << "-d" << ttynam;
      utmp.start(KProcess::Block);
   }
@@ -259,7 +281,14 @@ void TEPty::donePty()
         logout(tty_name);
   }
 #endif
-  if (needGrantPty) chownpty(fd,FALSE);
+  if (m_bNeedGrantPty) chownpty(m_MasterFd, false);
+
+  KProcess::commClose();
+}
+
+void TEPty::donePty()
+{
+  int status = exitStatus();
   emit done(status);
 }
 
@@ -272,7 +301,7 @@ const char* TEPty::deviceName()
 /*!
     start the client program.
 */
-int TEPty::run(const char* _pgm, QStrList & _args, const char* _term, int _addutmp,
+int TEPty::run(const char* _pgm, QStrList & _args, const char* _term, bool _addutmp,
                const char* _konsole_dcop, const char* _konsole_dcop_session)
 {
   clearArguments();
@@ -285,11 +314,19 @@ int TEPty::run(const char* _pgm, QStrList & _args, const char* _term, int _addut
   term = _term;
   konsole_dcop = _konsole_dcop;
   konsole_dcop_session = _konsole_dcop_session;
-  addutmp = _addutmp;
+  m_bAddUtmp = _addutmp;
+  if (m_MasterFd < 0)
+     return -1;
 
   if (!start(NotifyOnExit, (Communication) (Stdout | NoRead)))
      return -1;
 
+  if (m_SlaveFd >= 0)
+  {
+     close(m_SlaveFd);
+     m_SlaveFd = -1;
+  }
+
   resume(); // Start...
   return 0;
 
@@ -305,9 +342,14 @@ void TEPty::setWriteable(bool writeable)
     chmod(deviceName(), sbuf.st_mode & ~(S_IWGRP|S_IWOTH));
 }
 
-int TEPty::openPty()
-{ int ptyfd = -1;
-  needGrantPty = TRUE;
+void TEPty::openPty()
+{
+  m_bNeedGrantPty = true;
+
+#include <kdeversion.h>
+#if KDE_VERSION <306
+  #undef HAVE_OPENPTY  // Hack to make it compile for binner
+#endif
 
   // Find a master pty that we can open ////////////////////////////////
 
@@ -315,129 +357,118 @@ int TEPty::openPty()
   // be opened by several different methods.
 
   // We try, as we know them, one by one.
-
-#if defined(HAVE_OPENPTY) && 0 //FIXME: some work needed.
-#warning wheee
-  if (ptyfd < 0)
-  {
+#if defined(HAVE_OPENPTY) //FIXME: some work needed.
+  if (m_MasterFd < 0) {
     int master_fd, slave_fd;
-    char name[10]; // RTSL it shouldn't be any longer
-    if (!openpty(&master_fd, &slave_fd, name, 0/*no termios*/,0 /*and again*/)) {
-      ptyfd=master_fd;
-      strncpy(ptynam, name, 50);
-      strncpy(ttynam, name, 50);
-      ttynam[5]='t';
-      // one needs to look into who owns what to make sure chownpty is needed
-      // FIXME: further, the logic of openPty has to adjusted to pass a file
-      //        handle instead of a name.
+    if (openpty(&master_fd, &slave_fd, NULL, NULL, NULL) == 0) {
+      m_MasterFd = master_fd;
+      m_SlaveFd = slave_fd;
+#ifdef HAVE_PTSNAME
+      strncpy(ptynam, ptsname(master_fd), 50);
+#else
+      // Just a guess, maybe ttyname with return nothing.
+      strncpy(ptynam, ttyname(master_fd),50);
+#endif
+      strncpy(ttynam, ttyname(slave_fd), 50);
+
+      m_bNeedGrantPty = false;
+
+      /* Get the group ID of the special `tty' group.  */
+      struct group* p = getgrnam(TTY_GROUP);    /* posix */
+      gid_t gid = p ? p->gr_gid : getgid ();    /* posix */
+
+      if (fchown(slave_fd, (uid_t) -1, gid) < 0)
+      {
+         m_bNeedGrantPty = true;
+         fprintf(stderr,"konsole: cannot chown %s.\n",ttynam);
+         perror("Reason");
+      }
+      else if (chmod(ttynam, S_IRUSR|S_IWUSR|S_IWGRP) < 0)
+      {
+         m_bNeedGrantPty = true;
+         fprintf(stderr,"konsole: cannot chmod %s.\n",ttynam);
+         perror("Reason");
+      }
     }
   }
 #endif
 
 //#if defined(__sgi__) || defined(__osf__) || defined(__svr4__)
 #if defined(HAVE_GRANTPT) && defined(HAVE_PTSNAME)
-  if (ptyfd < 0)
+  if (m_MasterFd < 0)
   {
 #ifdef _AIX
-    ptyfd = open("/dev/ptc",O_RDWR);
+    m_MasterFd = open("/dev/ptc",O_RDWR);
 #else
-    ptyfd = open("/dev/ptmx",O_RDWR);
+    m_MasterFd = open("/dev/ptmx",O_RDWR);
 #endif
-    if (ptyfd >= 0)
+    if (m_MasterFd >= 0)
     {
-      char *ptsn = ptsname(ptyfd);
+      char *ptsn = ptsname(m_MasterFd);
       if (ptsn) {
-          strncpy(ttynam, ptsname(ptyfd), 50);
-          grantpt(ptyfd);
-          needGrantPty = FALSE;
+          strncpy(ttynam, ptsname(m_MasterFd), 50);
+          grantpt(m_MasterFd);
+          m_bNeedGrantPty = false;
       } else {
       	  perror("ptsname");
-	  close(ptyfd);
-	  ptyfd = -1;
-      }
-    }
-  }
-#endif
-
-#if defined(TIOCGPTN) && 0 //FIXME: obsolete, to be removed if no one complains
-  if (ptyfd > 0)
-  {
-    strcpy(ptynam,"/dev/ptmx");
-    strcpy(ttynam,"/dev/pts/");
-    ptyfd = open(ptynam,O_RDWR);
-    if (ptyfd >= 0) // got the master pty
-    { int ptyno;
-      if (ioctl(ptyfd, TIOCGPTN, &ptyno) == 0)
-      { struct stat sbuf;
-        sprintf(ttynam,"/dev/pts/%d",ptyno);
-        if (stat(ttynam,&sbuf) == 0 && S_ISCHR(sbuf.st_mode))
-          needGrantPty = FALSE;
-        else
-        {
-          close(ptyfd);
-          ptyfd = -1;
-        }
-      }
-      else
-      {
-        close(ptyfd);
-        ptyfd = -1;
+	  close(m_MasterFd);
+	  m_MasterFd = -1;
       }
     }
   }
 #endif
 
 #if defined(_SCO_DS) || defined(__USLC__) // SCO OSr5 and UnixWare, might be obsolete
-  if (ptyfd < 0)
+  if (m_MasterFd < 0)
   { for (int idx = 0; idx < 256; idx++)
     { sprintf(ptynam, "/dev/ptyp%d", idx);
       sprintf(ttynam, "/dev/ttyp%d", idx);
       if (access(ttynam, F_OK) < 0) { idx = 256; break; }
-      if ((ptyfd = open (ptynam, O_RDWR)) >= 0)
+      if ((m_MasterFd = open (ptynam, O_RDWR)) >= 0)
       { if (access (ttynam, R_OK|W_OK) == 0) break;
-        close(ptyfd); ptyfd = -1;
+        close(m_MasterFd); m_MasterFd = -1;
       }
     }
   }
 #endif
 
-  if (ptyfd < 0) // Linux device names, FIXME: Trouble on other systems?
+  if (m_MasterFd < 0) // Linux device names, FIXME: Trouble on other systems?
   { for (const char* s3 = "pqrstuvwxyzabcdefghijklmno"; *s3 != 0; s3++)
     { for (const char* s4 = "0123456789abcdefghijklmnopqrstuvwxyz"; *s4 != 0; s4++)
       { sprintf(ptynam,"/dev/pty%c%c",*s3,*s4);
         sprintf(ttynam,"/dev/tty%c%c",*s3,*s4);
-        if ((ptyfd = open(ptynam,O_RDWR)) >= 0)
+        if ((m_MasterFd = open(ptynam,O_RDWR)) >= 0)
         { if (geteuid() == 0 || access(ttynam,R_OK|W_OK) == 0) break;
-          close(ptyfd); ptyfd = -1;
+          close(m_MasterFd); m_MasterFd = -1;
         }
       }
-      if (ptyfd >= 0) break;
+      if (m_MasterFd >= 0) break;
     }
   }
 
-  if (ptyfd < 0)
+  if (m_MasterFd < 0)
   {
-    //FIXME: handle more gracefully.
-    fprintf(stderr,"Can't open a pseudo teletype\n"); exit(1);
+    fprintf(stderr,"Can't open a pseudo teletype\n");
+    m_strError = i18n("Unable to open a suitable terminal device.");
+    return;
   }
 
-  if (needGrantPty && !chownpty(ptyfd,TRUE))
+  if (m_bNeedGrantPty && !chownpty(m_MasterFd, true))
   {
     fprintf(stderr,"konsole: chownpty failed for device %s::%s.\n",ptynam,ttynam);
     fprintf(stderr,"       : This means the session can be eavesdroped.\n");
     fprintf(stderr,"       : Make sure konsole_grantpty is installed in\n");
     fprintf(stderr,"       : %s and setuid root.\n",
-            KGlobal::dirs()->findResourceDir("exe", "konsole").local8Bit().data());
+            KGlobal::dirs()->findResourceDir("exe",
+                                             "konsole").local8Bit().data());
   }
 
-  fcntl(ptyfd,F_SETFL,O_NDELAY);
-
-  return ptyfd;
+  fcntl(m_MasterFd,F_SETFL,O_NDELAY);
 }
 
 int TEPty::makePty(bool _addutmp)
 {
-  if (fd < 0) // no master pty could be opened
+  if (m_MasterFd < 0) // no master pty could be opened
   {
   //FIXME:
     fprintf(stderr,"opening master pty failed.\n");
@@ -445,15 +476,18 @@ int TEPty::makePty(bool _addutmp)
   }
 
 #ifdef HAVE_UNLOCKPT
-  unlockpt(fd);
+  unlockpt(m_MasterFd);
 #endif
 
 #if defined(TIOCSPTLCK) && 0 //FIXME: obsolete, to removed if no one complains
-  int flag = 0; ioctl(fd,TIOCSPTLCK,&flag); // unlock pty
+  int flag = 0; ioctl(m_MasterFd,TIOCSPTLCK,&flag); // unlock pty
 #endif
 
   // open and set all standard files to slave tty
-  int tt = open(ttynam, O_RDWR);
+  int tt = m_SlaveFd; // Already opened?
+
+  if (tt < 0)
+    tt = open(ttynam, O_RDWR);
 
   if (tt < 0) // the slave pty could be opened
   {
@@ -473,7 +507,7 @@ int TEPty::makePty(bool _addutmp)
   if (_addutmp)
   {
      KUtmpProcess utmp;
-     utmp.cmdFd = fd;
+     utmp.cmdFd = m_MasterFd;
      utmp << "/usr/sbin/utempter" << "-a" << ttynam << "";
      utmp.start(KProcess::Block);
   }
@@ -502,7 +536,7 @@ int TEPty::makePty(bool _addutmp)
   if (strncmp(str_ptr, "/dev/", 5) == 0)
        str_ptr += 5;
   strncpy(l_struct.ut_line, str_ptr, UT_LINESIZE);
-  time(&l_struct.ut_time); 
+  time(&l_struct.ut_time);
 
   login(&l_struct);
 #endif
@@ -511,9 +545,9 @@ int TEPty::makePty(bool _addutmp)
 
 //! only used internally. See `run' for interface
 void TEPty::startPgm(const char* pgm, QValueList<QCString> & args, const char* term)
-{ 
+{
   int sig;
-  int tt = makePty(addutmp);
+  int tt = makePty(m_bAddUtmp);
 
   //reset signal handlers for child process
   for (sig = 1; sig < NSIG; sig++)
@@ -527,7 +561,7 @@ void TEPty::startPgm(const char* pgm, QValueList<QCString> & args, const char* t
   // We need to close all remaining fd's.
   // Especially the one used by KProcess::start to see if we are running ok.
   for (int i = 0; i < (int)rlp.rlim_cur; i++)
-    if (i != tt && i != fd) close(i); //FIXME: (result of merge) Check if not closing fd is OK)
+    if (i != tt && i != m_MasterFd) close(i); //FIXME: (result of merge) Check if not closing fd is OK)
 
   dup2(tt,fileno(stdin));
   dup2(tt,fileno(stdout));
@@ -573,7 +607,7 @@ void TEPty::startPgm(const char* pgm, QValueList<QCString> & args, const char* t
 // #define CERASE 0177
 // #endif
 
-#if defined (__FreeBSD__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__bsdi__)
+#if defined (__FreeBSD__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__bsdi__) || defined(__APPLE__)
       ioctl(0,TIOCGETA,(char *)&ttmode);
 #else
 #   if defined (_HPUX_SOURCE) || defined(__Lynx__)
@@ -582,10 +616,12 @@ void TEPty::startPgm(const char* pgm, QValueList<QCString> & args, const char* t
       ioctl(0,TCGETS,(char *)&ttmode);
 #   endif
 #endif
+      if (!m_bXonXoff)
+         ttmode.c_iflag &= ~(IXOFF | IXON);
       ttmode.c_cc[VINTR] = CTRL('C');
       ttmode.c_cc[VQUIT] = CTRL('\\');
       ttmode.c_cc[VERASE] = 0177;
-#if defined (__FreeBSD__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__bsdi__)
+#if defined (__FreeBSD__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__bsdi__) || defined(__APPLE__)
       ioctl(0,TIOCSETA,(char *)&ttmode);
 #else
 #   ifdef _HPUX_SOURCE
@@ -595,51 +631,30 @@ void TEPty::startPgm(const char* pgm, QValueList<QCString> & args, const char* t
 #   endif
 #endif
 
-  close(fd);
+  close(m_MasterFd);
 
   // drop privileges
-  setgid(getgid()); setuid(getuid()); 
+  setgid(getgid()); setuid(getuid());
 
   // propagate emulation
   if (term && term[0]) setenv("TERM",term,1);
   if (konsole_dcop && konsole_dcop[0]) setenv("KONSOLE_DCOP",konsole_dcop,1);
   if (konsole_dcop_session && konsole_dcop_session[0]) setenv("KONSOLE_DCOP_SESSION",konsole_dcop_session,1);
 
-//  kdDebug() << "In TEPty.  args.count() is  " << args.count() << endl;
-//  kdDebug() << "In TEPty.  i is " << i << endl;
-//  kdDebug() << "In TEPty.  pgm  is " << pgm << endl;
-
-//  for (int k=1; k < 500000 ; k++) {
-//    for (int j=1; j < 5000 ; j++) {}
-//    }
-
   // convert QStrList into char*[]
   unsigned int i;
   char **argv = (char**)malloc(sizeof(char*)*(args.count()+1));
-//  char **argv = (char**)malloc(sizeof(char*)*(args.count()+0));
   for (i = 0; i<args.count(); i++) {
      argv[i] = strdup(args[i]);
-//      kdDebug() << "argv[" << i << "]=" << argv[i] << endl;
      }
-//  for (i = 1; i<args.count(); i++) argv[i-1] = strdup(args.at(i));
-//   kdDebug() << "pgm WAS = " << pgm << endl;
-   //pgm = strdup(args.at(0));
-//  kdDebug() << "pgm WAS CHANGED TO = " << pgm << endl;
-//  kdDebug() << "In TEPty.  first arg is " << argv[0] << endl;
-//  kdDebug() << "In TEPty.  i is " << i << endl;
-//  kdDebug() << "In TEPty.  pgm  is " << pgm << endl;
-//   for (int k=1; k < 500000 ; k++) {
-//     for (int j=1; j < 8000 ; j++) {}
-//   }
 
   argv[i] = 0L;
 
-  ioctl(0,TIOCSWINSZ,(char *)&wsize);  // set screen size
+  ioctl(0,TIOCSWINSZ,(char *)&m_WSize);  // set screen size
 
   // finally, pass to the new program
   //  kdDebug(1211) << "We are ready to run the program " << pgm << endl;
   execvp(pgm, argv);
-  //execvp("/bin/bash", argv);
   perror("exec failed");
   exit(1);                             // control should never come here.
 }
@@ -648,10 +663,13 @@ void TEPty::startPgm(const char* pgm, QValueList<QCString> & args, const char* t
     Create an instance.
 */
 TEPty::TEPty() : pSendJobTimer(NULL)
-{ 
-  memset(&wsize, 0, sizeof(struct winsize));
-  fd = openPty();
-  connect(this, SIGNAL(receivedStdout(int, int &)), 
+{
+  m_bXonXoff = false;
+  memset(&m_WSize, 0, sizeof(struct winsize));
+  m_SlaveFd = -1;
+  m_MasterFd = -1;
+  openPty();
+  connect(this, SIGNAL(receivedStdout(int, int &)),
 	  this, SLOT(DataReceived(int, int&)));
   connect(this, SIGNAL(processExited(KProcess *)),
           this, SLOT(donePty()));
@@ -668,8 +686,8 @@ TEPty::~TEPty()
 
 int TEPty::setupCommunication(Communication comm)
 {
-   if (fd <= 0) return 0;
-   out[0] = fd;
+   if (m_MasterFd <= 0) return 0;
+   out[0] = m_MasterFd;
    out[1] = dup(2); // Dummy
    communication = comm;
    return 1;
@@ -699,7 +717,7 @@ void TEPty::doSendJobs() {
   int written;
   while(!pendingSendJobs.isEmpty()) {
     SendJob& job = pendingSendJobs.first();
-    written = write(fd, job.buffer.data() + job.start, job.length);
+    written = write(m_MasterFd, job.buffer.data() + job.start, job.length);
     if (written==-1) {
       if ( errno!=EAGAIN && errno!=EINTR )
         pendingSendJobs.remove(pendingSendJobs.begin());
@@ -723,17 +741,19 @@ void TEPty::appendSendJob(const char* s, int len)
     connect(pSendJobTimer, SIGNAL(timeout()), this, SLOT(doSendJobs()) );
   }
   pSendJobTimer->start(0);
-}  
+}
 
 /*! sends len bytes through the line */
 void TEPty::send_bytes(const char* s, int len)
 {
+  if (m_MasterFd < 0)
+    return;
   if (!pendingSendJobs.isEmpty()) {
     appendSendJob(s,len);
   }else {
     int written;
     do {
-      written = write(fd,s,len);
+      written = write(m_MasterFd,s,len);
       if (written==-1) {
         if ( errno==EAGAIN || errno==EINTR )
           appendSendJob(s,len);
@@ -747,9 +767,9 @@ void TEPty::send_bytes(const char* s, int len)
 
 /*! indicates that a block of data is received */
 void TEPty::DataReceived(int,int &len)
-{ 
+{
   char buf[4096];
-  len = read(fd, buf, 4096);
+  len = read(m_MasterFd, buf, 4096);
   if (len < 0)
      return;
 
@@ -761,3 +781,12 @@ void TEPty::DataReceived(int,int &len)
     fflush(syslog_file);
   }
 }
+
+void TEPty::lockPty(bool lock)
+{
+  if (lock)
+    suspend();
+  else
+    resume();
+}
+
