@@ -103,7 +103,7 @@ void TEmuVt102::changeGUI(TEWidget* newgui)
   }
   TEmulation::changeGUI(newgui);
   QObject::connect(gui,SIGNAL(mouseSignal(int,int,int)),
-                   this,SLOT(onMouse(int,int,int)));  
+                   this,SLOT(onMouse(int,int,int)));
   QObject::connect(gui, SIGNAL(sendStringToEmu(const char*)),
 		   this, SLOT(sendString(const char*)));
 }
@@ -581,8 +581,8 @@ void TEmuVt102::tau( int token, int p, int q )
 
     case TY_CSI_PR('l',    2) :        resetMode      (MODE_Ansi     ); break; //VT100
 
-    case TY_CSI_PR('h',    3) : /* IGNORED:  setColumns (       132) */ break; //VT100
-    case TY_CSI_PR('l',    3) : /* IGNORED:  setColumns (        80) */ break; //VT100
+    case TY_CSI_PR('h',    3) :                setColumns (       132); break; //VT100
+    case TY_CSI_PR('l',    3) :                setColumns (        80); break; //VT100
 
     case TY_CSI_PR('h',    4) : /* IGNORED: soft scrolling           */ break; //VT100
     case TY_CSI_PR('l',    4) : /* IGNORED: soft scrolling           */ break; //VT100
@@ -804,11 +804,11 @@ void TEmuVt102::reportAnswerBack()
 
 void TEmuVt102::onMouse( int cb, int cx, int cy )
 { char tmp[20];
-  if (!connected) return;
+  if (!connected || cx<1 || cy<1) return;
   // normal buttons are passed as 0x20 + button,
-  // mouse wheel (buttons 4,5) as 0x60 + button
-  if (cb >= 4) cb += 0x40;
-  sprintf(tmp,"\033[M%c%c%c",cb+040,cx+040,cy+040);
+  // mouse wheel (buttons 4,5) as 0x5c + button
+  if (cb >= 4) cb += 0x3c;
+  sprintf(tmp,"\033[M%c%c%c",cb+0x20,cx+0x20,cy+0x20);
   sendString(tmp);
 }
 
@@ -886,7 +886,17 @@ void TEmuVt102::onKeyPress( QKeyEvent* ev )
        case CMD_scrollLock     : onScrollLock(                ); return;
      }
   }
-
+  if (holdScreen)
+  {
+    switch(ev->key())
+    {
+    case Key_Down : gui->doScroll(+1); return;
+    case Key_Up : gui->doScroll(-1); return;
+    case Key_PageUp : gui->doScroll(-gui->Lines()/2); return;
+    case Key_PageDown : gui->doScroll(gui->Lines()/2); return;
+    }
+  }
+  
   // revert to non-history when typing
   if (scr->getHistCursor() != scr->getHistLines() && (!ev->text().isEmpty()
     || ev->key()==Key_Down || ev->key()==Key_Up || ev->key()==Key_Left || ev->key()==Key_Right
@@ -1171,7 +1181,9 @@ void TEmuVt102::scan_buffer_report()
 
 void TEmuVt102::ReportErrorToken()
 {
+#ifndef NDEBUG
   printf("undecodable "); scan_buffer_report();
+#endif
 }
 
 /*
