@@ -11,9 +11,6 @@ class SessionIface : virtual public DCOPObject
     virtual bool closeSession() =0;
     virtual bool sendSignal(int signal) =0;
 
-    virtual void feedSession(const QString &text) =0;
-    virtual void sendSession(const QString &text) =0;
-
     virtual void renameSession(const QString &name) =0;
 };
 
