@@ -46,7 +46,7 @@ KPagerConfigDialog::KPagerConfigDialog (QWidget *parent)
  : KDialogBase ( parent, "configdialog", true, i18n("KPager Settings"), Ok|Cancel, Ok, true )
 {
     QVBox *box = new QVBox( this );
-    m_chkWindowDragging=new QCheckBox(i18n("Enable Window Dragging"),box,0);
+    m_chkWindowDragging=new QCheckBox(i18n("Enable window dragging"),box,0);
     (void ) new KSeparator( box );
     connect(m_chkWindowDragging, SIGNAL(toggled(bool)), this, SLOT(enableWindowDragging(bool)));
 
@@ -54,13 +54,13 @@ KPagerConfigDialog::KPagerConfigDialog (QWidget *parent)
     QVBox *lpage = new QVBox( page );
     setMainWidget(box);
 
-    m_chkShowName=new QCheckBox(i18n("Show Name"),lpage,0);
+    m_chkShowName=new QCheckBox(i18n("Show name"),lpage,0);
     connect(m_chkShowName, SIGNAL(toggled(bool)), this, SLOT(setShowName(bool)));
-    m_chkShowNumber=new QCheckBox(i18n("Show Number"),lpage,0);
+    m_chkShowNumber=new QCheckBox(i18n("Show number"),lpage,0);
     connect(m_chkShowNumber, SIGNAL(toggled(bool)), this, SLOT(setShowNumber(bool)));
-    m_chkShowBackground=new QCheckBox(i18n("Show Background"),lpage,0);
+    m_chkShowBackground=new QCheckBox(i18n("Show background"),lpage,0);
     connect(m_chkShowBackground, SIGNAL(toggled(bool)), this, SLOT(setShowBackground(bool)));
-    m_chkShowWindows=new QCheckBox(i18n("Show Windows"),lpage,0);
+    m_chkShowWindows=new QCheckBox(i18n("Show windows"),lpage,0);
     connect(m_chkShowWindows, SIGNAL(toggled(bool)), this, SLOT(setShowWindows(bool)));
 
     m_grpWindowDrawMode=new QButtonGroup(i18n("Type of Window"),page);
