@@ -22,6 +22,7 @@
 #include <kstandarddirs.h>
 #include <kapplication.h>
 #include <kglobal.h>
+#include <kiconloader.h>
 #include "krefinepage.h"
 #include "kpersonalizer.h"
 
@@ -33,6 +34,7 @@ KRefinePage::KRefinePage(QWidget *parent, const char *name ) : KRefinePageDlg(pa
        pb_kcontrol->hide();
        lb_kcontrol->hide();
    }
+   px_kcontrol->setPixmap(KGlobal::iconLoader()->loadIcon("kcontrol", KIcon::Panel, KIcon::SizeMedium));
 }
 KRefinePage::~KRefinePage(){
 }
