@@ -774,7 +774,7 @@ static Status KSMNewClientProc ( SmsConn conn, SmPointer manager_data,
                 SmsDeletePropertiesProcMask |
                 SmsGetPropertiesProcMask;
     return 1;
-};
+}
 
 
 #ifdef HAVE__ICETRANSNOLISTEN
@@ -1314,7 +1314,7 @@ void KSMServer::discardSession()
         // case up to KDE and Qt < 3.1
         int i = 1;
         while ( i <= count &&
-                config->readListEntry( QString("discardCommand") + QString::number(i) ) != discardCommand )
+                config->readPathListEntry( QString("discardCommand") + QString::number(i) ) != discardCommand )
             i++;
         if ( i <= count )
             executeCommand( discardCommand );
@@ -1327,7 +1327,7 @@ void KSMServer::storeSession()
     config->setGroup( sessionGroup );
     int count =  config->readNumEntry( "count" );
     for ( int i = 1; i <= count; i++ ) {
-        QStringList discardCommand = config->readListEntry( QString("discardCommand") + QString::number(i) );
+        QStringList discardCommand = config->readPathListEntry( QString("discardCommand") + QString::number(i) );
         if ( discardCommand.isEmpty())
             continue;
         // check that non of the new clients uses the exactly same
