@@ -20,7 +20,7 @@
 	<cs@kde.org>. Please do not commit any changes without consulting
 	me first. Thanks!
 
-	$Id: KSysGuardApplet.h,v 1.11 2002/02/20 22:47:54 arbab Exp $
+	$Id: KSysGuardApplet.h,v 1.12 2002/06/23 19:15:22 nhasan Exp $
 */
 
 #ifndef __KSysGuardApplet_h__
@@ -36,7 +36,7 @@ namespace KSGRD
 class QDragEnterEvent;
 class QDropEvent;
 class QPoint;
-class KSysGuardAppletSettings;
+class KSGAppletSettings;
 
 class KSysGuardApplet : public KPanelApplet, public KSGRD::SensorBoard
 {
@@ -74,7 +74,7 @@ private:
 	uint dockCnt;
 	QWidget** docks;
 	double sizeRatio;
-	KSysGuardAppletSettings* ksgas;
+	KSGAppletSettings* ksgas;
 };
 
 #endif
