@@ -19,11 +19,14 @@
 	KSysGuard is currently maintained by Chris Schlaeger <cs@kde.org>.
 	Please do not commit any changes without consulting me first. Thanks!
 
-	$Id: ProcessController.cc,v 1.1 2002/03/02 22:31:34 cschlaeg Exp $
+	$Id: ProcessController.cc,v 1.6 2002/09/16 14:12:36 tokoe Exp $
 */
 
 #include <assert.h>
 
+#include <qtimer.h>
+
+#include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -73,10 +76,10 @@ ProcessController::ProcessController(QWidget* parent, const char* name)
 	 * pList constructor sets cbFilter to its start value. */
 	cbFilter = new QComboBox(this, "pList_cbFilter");
 	Q_CHECK_PTR(cbFilter);
-	cbFilter->insertItem(i18n("All processes"), 0);
-	cbFilter->insertItem(i18n("System processes"), 1);
-	cbFilter->insertItem(i18n("User processes"), 2);
-	cbFilter->insertItem(i18n("Own processes"), 3);
+	cbFilter->insertItem(i18n("All Processes"), 0);
+	cbFilter->insertItem(i18n("System Processes"), 1);
+	cbFilter->insertItem(i18n("User Processes"), 2);
+	cbFilter->insertItem(i18n("Own Processes"), 3);
 	cbFilter->setMinimumSize(cbFilter->sizeHint());
 
 	/* When the both cbFilter and pList are constructed we can connect the
@@ -85,13 +88,14 @@ ProcessController::ProcessController(QWidget* parent, const char* name)
 			this, SLOT(filterModeChanged(int)));
 
 	// Create the 'Refresh' button.
-	bRefresh = new QPushButton(i18n("&Refresh"), this, "bRefresh");
+    bRefresh = new KPushButton( KGuiItem(  i18n( "&Refresh" ), "reload" ), 
+            this, "bRefresh" );
 	Q_CHECK_PTR(bRefresh);
 	bRefresh->setMinimumSize(bRefresh->sizeHint());
 	connect(bRefresh, SIGNAL(clicked()), this, SLOT(updateList()));
 
 	// Create the 'Kill' button.
-	bKill = new QPushButton(i18n("&Kill"), this, "bKill");
+	bKill = new KPushButton(i18n("&Kill"), this, "bKill");
 	Q_CHECK_PTR(bKill);
 	bKill->setMinimumSize(bKill->sizeHint());
 	connect(bKill, SIGNAL(clicked()), this, SLOT(killProcess()));
@@ -125,10 +129,6 @@ ProcessController::ProcessController(QWidget* parent, const char* name)
 	registerPlotterWidget(pList);
 
 	setMinimumSize(sizeHint());
-
-	/* If the process list is not visible there is no need to update
-	 * it. */
-	pauseOnHide = true;
 }
 
 void
@@ -174,7 +174,12 @@ ProcessController::killProcess(int pid, int sig)
 {
 	sendRequest(sensors.at(0)->hostName,
 				QString("kill %1 %2" ).arg(pid).arg(sig), 3);
-	updateList();
+
+	if (paused())
+	    // give ksysguardd time to update its proccess list
+	    QTimer::singleShot(3000, this, SLOT(updateList()));
+	else
+	    updateList();
 }
 
 void
@@ -193,7 +198,7 @@ ProcessController::killProcess()
 		QString  msg = i18n("Do you want to kill the selected process?", 
 				"Do you want to kill the %n selected processes?", 
 				selectedPIds.count());
-		if (KMessageBox::warningYesNo(this, msg) != KMessageBox::Yes)
+		if (KMessageBox::warningContinueCancel(this, msg, kapp->makeStdCaption(i18n("Kill Process")), i18n("&Kill")) != KMessageBox::Continue)
 		{
 			return;
 		}
@@ -204,6 +209,11 @@ ProcessController::killProcess()
 	for (it = selectedPIds.begin(); it != selectedPIds.end(); ++it)
 		sendRequest(sensors.at(0)->hostName, QString("kill %1 %2" ).arg(*it)
 					.arg(MENU_ID_SIGKILL), 3);
+	
+	if (paused())
+	    // give ksysguardd time to update its proccess list
+	    QTimer::singleShot(3000, this, SLOT(updateList()));
+	else
 	updateList();
 }
 
