@@ -1,5 +1,5 @@
 /*
-    KTop, the KDE Task Manager
+    KSysGuard, the KDE System Guard
    
 	Copyright (c) 1999 Chris Schlaeger <cs@kde.org>
     
@@ -17,19 +17,22 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: ProcessList.h,v 1.3 2001/09/18 14:03:53 tokoe Exp $
+	$Id: ProcessList.h,v 1.4 2002/04/15 05:41:38 tokoe Exp $
 */
 
 #ifndef _process_list_h_
 #define _process_list_h_
 
-void initProcessList(void);
+void initProcessList(struct SensorModul* sm);
 void exitProcessList(void);
+
 int updateProcessList(void);
+
 void printProcessList(const char*);
 void printProcessListInfo(const char*);
 void printProcessCount(const char* cmd);
 void printProcessCountInfo(const char* cmd);
+
 void killProcess(const char* cmd);
 void setPriority(const char* cmd);
 
