@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: Memory.c,v 1.26 2002/11/06 14:50:06 cschlaeg Exp $
+	$Id: Memory.c,v 1.26.2.2 2003/05/08 14:12:06 cschlaeg Exp $
 */
 
 #include <sys/types.h>
@@ -31,7 +31,7 @@
 #include "Memory.h"
 #include "ksysguardd.h"
 
-#define MEMINFOBUFSIZE 1024
+#define MEMINFOBUFSIZE (2 * 1024)
 static char MemInfoBuf[MEMINFOBUFSIZE];
 static int Dirty = 1;
 
