@@ -1,5 +1,5 @@
 /*
-    KSysGuard, the KDE Task Manager
+    KSysGuard, the KDE System Guard
 	   
     Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
     
@@ -16,14 +16,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: lmsensors.h,v 1.1 2001/01/27 20:53:44 cschlaeg Exp $
+    $Id: lmsensors.h,v 1.3 2002/04/15 05:41:39 tokoe Exp $
 */
 
 #ifndef _lmsensors_h_
 #define _lmsensors_h_
 
-void initLmSensors(void);
+void initLmSensors(struct SensorModul* sm);
 void exitLmSensors(void);
+
 void printLmSensor(const char* cmd);
 void printLmSensorInfo(const char* cmd);
 
