@@ -1,5 +1,5 @@
 /*
-    KTop, the KDE Task Manager
+    KSysGuard, the KDE System Guard
    
 	Copyright (c) 1999, 2000 Chris Schlaeger <cs@kde.org>
     
@@ -16,14 +16,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: loadavg.h,v 1.1 2000/12/17 21:07:28 cschlaeg Exp $
+	$Id: loadavg.h,v 1.3 2002/04/15 05:41:39 tokoe Exp $
 */
 
 #ifndef _loadavg_h_
 #define _loadavg_h_
 
-void initLoadAvg(void);
+void initLoadAvg(struct SensorModul* sm);
 void exitLoadAvg(void);
+
 int updateLoadAvg(void);
 
 void printLoadAvg1(const char*);
