@@ -1,5 +1,5 @@
 /*
-    KTop, the KDE Task Manager
+    KSysGuard, the KDE System Guard
    
 	Copyright (c) 1999, 2000 Chris Schlaeger <cs@kde.org>
     
@@ -16,14 +16,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: stat.h,v 1.4 2001/02/18 23:18:43 cschlaeg Exp $
+	$Id: stat.h,v 1.6 2002/04/15 05:41:39 tokoe Exp $
 */
 
 #ifndef _stat_h_
 #define _stat_h_
 
-void initStat(void);
-
+void initStat(struct SensorModul* sm);
 void exitStat(void);
 
 int updateStat(void);
