@@ -1,5 +1,5 @@
 /*
-    KTop, the KDE Task Manager
+    KSysGuard, the KDE System Guard
    
 	Copyright (c) 1999 Chris Schlaeger <cs@kde.org>
 
@@ -19,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: LoadAvg.h,v 1.1 2001/03/06 11:09:47 cschlaeg Exp $
+	$Id: LoadAvg.h,v 1.2 2002/04/15 05:41:39 tokoe Exp $
 */
 
 #ifndef _LoadAvg_h_
@@ -27,7 +27,7 @@
 
 #define LOAD(a) ((double)(a) / (1 << 8 ))
 
-void initLoadAvg(void);
+void initLoadAvg(struct SensorModul* sm);
 void exitLoadAvg(void);
 
 int updateLoadAvg(void);
