@@ -13,7 +13,7 @@ class KWinModule;
  * Provides a system tray icon for a normal window.
  *
  * @author Richard Moore, rich@kde.org
- * @version $Id: ksystraycmd.h,v 1.4 2002/07/29 00:13:45 rich Exp $
+ * @version $Id: ksystraycmd.h,v 1.4.2.1 2003/05/21 14:55:15 lunakl Exp $
  */
 class KSysTrayCmd : public QLabel
 {
@@ -60,7 +60,9 @@ protected:
   void setTargetWindow( const KWin::Info &info );
 
   void mousePressEvent( QMouseEvent *e );
+#if QT_VERSION < 0x030200
   void enterEvent( QEvent* );
+#endif
 
 private:
   QString command;
