@@ -89,7 +89,12 @@ private:
 class WindowWrapperPrivate
 {
 public:
-    WindowWrapperPrivate() {};
+    WindowWrapperPrivate()
+     : not_obscured( false ),
+       active( false )
+     {};
+    uint not_obscured : 1; // as in 'not obscured', may be true also if the client is hidden
+    uint active : 1;
 };
 
 class ClientPrivate
@@ -99,7 +104,7 @@ public:
     QCString windowRole;
 };
 
-};
+}
 
 // put all externs before the namespace statement to allow the linker
 // to resolve them properly
@@ -199,6 +204,7 @@ const long ClientWinMask = KeyPressMask | KeyReleaseMask |
                   EnterWindowMask | LeaveWindowMask |
                   FocusChangeMask |
                   ExposureMask |
+                  VisibilityChangeMask |
                   StructureNotifyMask |
                   SubstructureRedirectMask;
 
@@ -235,10 +241,7 @@ WindowWrapper::WindowWrapper( WId w, Client *parent, const char* name)
                   );
 
     // install a passive grab to catch mouse button events
-    XGrabButton(qt_xdisplay(), AnyButton, AnyModifier, winId(), FALSE,
-                ButtonPressMask,
-                GrabModeSync, GrabModeAsync,
-                None, None );
+    updateMouseGrab();
 
     reparented = FALSE;
 }
@@ -251,36 +254,77 @@ WindowWrapper::~WindowWrapper()
 
 
 
+#define XCapL KKeyNative::modXLock()
+#define XNumL KKeyNative::modXNumLock()
+#define XScrL KKeyNative::modXScrollLock()
+static void grabButton( WId winId, int modifier )
+{
+    unsigned int mods[ 8 ] = {
+        0, XCapL, XNumL, XNumL | XCapL,
+        XScrL, XScrL | XCapL,
+        XScrL | XNumL, XScrL | XNumL | XCapL };
+    for( int i = 0;
+         i < 8;
+         ++i )
+        XGrabButton( qt_xdisplay(), AnyButton,
+            modifier | mods[ i ],
+            winId,  FALSE, ButtonPressMask,
+            GrabModeSync, GrabModeAsync, None, None );
+}
 
 static void ungrabButton( WId winId, int modifier )
 {
-    XUngrabButton( qt_xdisplay(), AnyButton, modifier, winId );
-    XUngrabButton( qt_xdisplay(), AnyButton, modifier | LockMask, winId );
+    unsigned int mods[ 8 ] = {
+        0, XCapL, XNumL, XNumL | XCapL,
+        XScrL, XScrL | XCapL,
+        XScrL | XNumL, XScrL | XNumL | XCapL };
+    for( int i = 0;
+         i < 8;
+         ++i )
+        XUngrabButton( qt_xdisplay(), AnyButton,
+            modifier | mods[ i ], winId );
 }
+#undef XCapL
+#undef XNumL
+#undef XScrL
 
 /*!
   Called by the client to notify the window wrapper when activation
   state changes.
+ */
+void WindowWrapper::setActive( bool active )
+{
+    d->active = active;
+    updateMouseGrab();
+}
 
+ 
+/*
   Releases the passive grab for some modifier combinations when a
   window becomes active. This helps broken X programs that
   missinterpret LeaveNotify events in grab mode to work properly
   (Motif, AWT, Tk, ...)
  */
-void WindowWrapper::setActive( bool active )
+void WindowWrapper::updateMouseGrab()
 {
-    if ( active ) {
-      if ( options->focusPolicy == Options::ClickToFocus ||  !options->clickRaise )
-	ungrabButton( winId(),  None );
-      ungrabButton( winId(),  ShiftMask );
-      ungrabButton( winId(),  ControlMask );
-      ungrabButton( winId(),  ControlMask | ShiftMask );
-    } else {
+    if( d->active )
+        {
+        // remove the grab for no modifiers only if the window
+        // is unobscured or if the user doesn't want click raise
+        if( !options->clickRaise || d->not_obscured )
+	    ungrabButton( winId(),  None );
+        else
+            grabButton( winId(), None );
+        ungrabButton( winId(),  ShiftMask );
+        ungrabButton( winId(),  ControlMask );
+        ungrabButton( winId(),  ControlMask | ShiftMask );
+        }
+    else
+        // simply grab all modifier combinations
         XGrabButton(qt_xdisplay(), AnyButton, AnyModifier, winId(), FALSE,
-                    ButtonPressMask,
-                    GrabModeSync, GrabModeAsync,
-                    None, None );
-    }
+            ButtonPressMask,
+            GrabModeSync, GrabModeAsync,
+            None, None );
 }
 
 QSize WindowWrapper::sizeHint() const
@@ -414,11 +458,9 @@ bool WindowWrapper::x11Event( XEvent * e)
         bool bModKeyHeld = ( e->xbutton.state & KKeyNative::accelModMaskX()) == keyModX;
 
         if ( ((Client*)parentWidget())->isActive()
-             && ( options->focusPolicy != Options::ClickToFocus
-                  &&  options->clickRaise && !bModKeyHeld ) ) {
+             && ( options->clickRaise && !bModKeyHeld ) ) {
             if ( e->xbutton.button < 4 ) // exclude wheel
                 ((Client*)parentWidget())->autoRaise();
-            ungrabButton( winId(), None );
         }
 
         Options::MouseCommand com = Options::MouseNothing;
@@ -464,6 +506,14 @@ bool WindowWrapper::x11Event( XEvent * e)
     case ButtonRelease:
         XAllowEvents(qt_xdisplay(), SyncPointer, CurrentTime ); //qt_x_time);
         break;
+    case VisibilityNotify:
+        {
+        bool old_not_obscured = d->not_obscured;
+        d->not_obscured = ( e->xvisibility.state == VisibilityUnobscured );
+        if( old_not_obscured != d->not_obscured )
+            updateMouseGrab();
+        break;
+        }
     default:
         break;
     }
@@ -602,8 +652,6 @@ Client::~Client()
     if (moveResizeMode)
        stopMoveResize();
     releaseWindow();
-    if( workspace()->activeClient() == this ) // this really shouldn't happen,
-        workspace()->setActiveClient( NULL ); // but just in case
     delete info;
     delete d;
 }
@@ -621,6 +669,7 @@ void Client::startMoveResize()
 
 void Client::stopMoveResize()
 {
+    clearbound();
     if ( ( isMove() && options->moveMode != Options::Opaque )
       || ( isResize() && options->resizeMode != Options::Opaque ) )
         XUngrabServer( qt_xdisplay() );
@@ -628,6 +677,7 @@ void Client::stopMoveResize()
     releaseMouse();
     workspace()->setClientIsMoving(0);
     moveResizeMode = false;
+    update();
 }
 
 /*!
@@ -877,6 +927,9 @@ bool Client::manage( bool isMapped, bool doNotShow, bool isInitial )
         }
     }
 
+    if( isTopMenu() && workspace()->activeClient() != mainClient())
+	doNotShow = true;
+	
     bool showMe = (state == NormalState) && isOnDesktop( workspace()->currentDesktop() );
 
     workspace()->clientReady( this ); // will call Workspace::propagateClients()
@@ -1086,7 +1139,9 @@ bool Client::windowEvent( XEvent * e)
             break; // we don't care
         if ( isShade() )
             break; // we neither
-        if ( e->xfocus.detail != NotifyNonlinear )
+        if ( e->xfocus.detail != NotifyNonlinear
+            && e->xfocus.detail != NotifyNonlinearVirtual )
+            // SELI check all this
             return TRUE; // hack for motif apps like netscape
         if ( QApplication::activePopupWidget() )
             break;
@@ -1552,8 +1607,14 @@ bool Client::isMaximizable() const
  */
 bool Client::isMinimizable() const
 {
-    return ( !isTransient() || !workspace()->findClient( transientFor() ) )
-        && wantsTabFocus() && may_minimize;
+    if( isTransient())
+    {
+	Client* trans = workspace()->findClient( transientFor());
+	// TODO should it be allowed to have WM_TRANSIENT_FOR pointing to itself?
+	if( trans != NULL && trans != this )
+	    return false;
+    }
+    return wantsTabFocus() && may_minimize;
 }
 
 /*
@@ -1561,8 +1622,7 @@ bool Client::isMinimizable() const
  */
 bool Client::isCloseable() const
 {
-    return may_close && !isDesktop() && !isDock() && !isTopMenu()
-	&&  windowType() != NET::Override;
+    return may_close && !isDesktop() && !isDock() && !isTopMenu();
 }
 
 
@@ -1622,7 +1682,6 @@ void Client::mouseReleaseEvent( QMouseEvent * e)
     if ( (e->stateAfter() & MouseButtonMask) == 0 ) {
         buttonDown = FALSE;
         if ( moveResizeMode ) {
-            clearbound();
             stopMoveResize();
             setGeometry( geom );
             mode = mousePosition( e->pos() );
@@ -1655,7 +1714,9 @@ void Client::mouseMoveEvent( QMouseEvent * e)
         return;
     }
 
-    if ( !isMovable() || (isShade() && mode != Center)) return;
+    if(( mode == Center && !isMovable())
+        || ( mode != Center && ( isShade() || !isResizable())))
+        return;
 
     if ( !moveResizeMode ) {
         QPoint p( e->pos() - moveOffset );
@@ -1998,7 +2059,7 @@ void Client::closeWindow()
         if( isNormalWindow())
             Events::raise( Events::Delete );
         XKillClient(qt_xdisplay(), win );
-        workspace()->destroyClient( this );
+	QTimer::singleShot( 0, this, SLOT( destroyClient()));
     }
 }
 
@@ -2014,9 +2075,16 @@ void Client::killWindow()
 
     // always kill this client at the server
     XKillClient(qt_xdisplay(), win );
-    workspace()->destroyClient( this );
+    // needs to be delayed, because this may be called from the client
+    // popup menu, and there may be possibly code still touching
+    // this instance after returning from killWindow()
+    QTimer::singleShot( 0, this, SLOT( destroyClient()));
 }
 
+void Client::destroyClient()
+{
+    workspace()->destroyClient( this );
+}
 
 
 /*!
@@ -2108,14 +2176,6 @@ void Client::maximize( MaximizeMode m)
     case MaximizeFull: {
         QSize adjSize = adjustedSize(clientArea.size());
         QRect r = QRect(clientArea.topLeft(), adjSize);
-
-        // hide right and left border of maximized windows
-        if ( !options->moveResizeMaximizedWindows && adjSize == clientArea.size()) {
-            if ( r.left() == 0 )
-                r.setLeft( r.left() - windowWrapper()->x() );
-            if ( r.right() == workspace()->geometry().right() )
-                r.setRight( r.right() + width() -  windowWrapper()->geometry().right() );
-        }
         setGeometry( r );
         info->setState( NET::Max, NET::Max );
     } break;
@@ -2451,8 +2511,7 @@ void Client::setShade( bool s, int hus )
             workspace()->requestFocus( this );
     }
 
-    if(!hus)
-        info->setState( shaded?NET::Shaded:0, NET::Shaded );
+    info->setState( shaded?NET::Shaded:0, NET::Shaded );
 
     workspace()->iconifyOrDeiconifyTransientsOf( this );
     shadeChange( shaded );
@@ -2601,15 +2660,8 @@ void Client::getWindowProtocols(){
  */
 void Client::takeFocus( bool force )
 {
-    if ( !force && ( isTopMenu() || isDock() ) ) {
-	if ( isDock() && !staysOnTop() && workspace()->activeClient() ) {
-	    // the active client might get covered by a dock
-	    // window. Re-enable ourselves passive grabs to make
-	    // click-raise work again
-	    workspace()->activeClient()->windowWrapper()->setActive( FALSE );
-	}
+    if ( !force && ( isTopMenu() || isDock() ) )
         return; // toplevel menus and dock windows don't take focus if not forced
-    }
 
     if ( input ) {
         // Matthias Ettrich says to comment it so that we avoid two consecutive setActive
@@ -2713,6 +2765,7 @@ bool Client::performMouseCommand( Options::MouseCommand command, QPoint globalPo
             workspace()->raiseClient( this );
         break;
     case Options::MouseActivateAndRaise:
+        replay = isActive(); // for clickraise mode
         workspace()->requestFocus( this );
         workspace()->raiseClient( this );
         break;
@@ -2721,6 +2774,7 @@ bool Client::performMouseCommand( Options::MouseCommand command, QPoint globalPo
         workspace()->lowerClient( this );
         break;
     case Options::MouseActivate:
+        replay = isActive(); // for clickraise mode
         workspace()->requestFocus( this );
         break;
     case Options::MouseActivateRaiseAndPassClick:
@@ -2751,7 +2805,7 @@ bool Client::performMouseCommand( Options::MouseCommand command, QPoint globalPo
         startMoveResize();
         break;
     case Options::MouseResize: {
-        if (!isMovable())
+        if (!isResizable() || isShade())
             break;
         geom=geometry();
         if ( isMaximized() ) {
@@ -2795,7 +2849,7 @@ void Client::NETMoveResize( int x_root, int y_root, NET::Direction direction )
     else if( direction >= NET::TopLeft && direction <= NET::Left ) {
         static const MousePosition convert[] = { TopLeft, Top, TopRight, Right, BottomRight, Bottom,
             BottomLeft, Left };
-        if (!isMovable())
+        if(!isResizable() || isShade())
             return;
         geom=geometry();
         if ( isMaximized() ) {
@@ -2839,7 +2893,6 @@ void Client::keyPressEvent( uint key_code )
     case Key_Return:
     case Key_Enter:
     case Key_Escape:
-        clearbound();
         stopMoveResize();
         setGeometry( geom );
         buttonDown = FALSE;
