@@ -327,7 +327,6 @@ private slots:
     void sendToDesktop( int );
     void clientPopupActivated( int );
     void configureWM();
-    void focusEnsurance();
 
 protected:
     bool keyPress( XKeyEvent& ev );
@@ -469,7 +468,7 @@ private:
     // Timer to collect requests for 'reconfigure'
     QTimer reconfigureTimer;
 
-    QTimer focusEnsuranceTimer;
+    QTimer focusEnsuranceTimer; // unused
 
     WorkspacePrivate* d;
     static Workspace *_self;
@@ -508,6 +507,6 @@ inline void Workspace::showWindowMenu(QPoint pos, Client* cl)
 }
 
 
-};
+}
 
 #endif
