@@ -24,6 +24,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+
 #include <config.h>
 
 #include <qfileinfo.h>
@@ -38,6 +39,7 @@
 #include <knuminput.h>
 
 #include "kcmmisc.h"
+#include "kcmmiscwidget.h"
 #include <X11/Xlib.h>
 
 KeyboardConfig::KeyboardConfig (QWidget * parent, const char *)
@@ -45,80 +47,65 @@ KeyboardConfig::KeyboardConfig (QWidget * parent, const char *)
 {
   QString wtstr;
   QBoxLayout* lay = new QVBoxLayout(this, 10);
+  ui = new KeyboardConfigWidget(this, "ui");
+  lay->addWidget(ui);
 
-  repeatBox = new QCheckBox(i18n("&Keyboard repeat"), this);
-  lay->addWidget(repeatBox);
-  connect(repeatBox, SIGNAL(clicked()), this, SLOT(changed()));
+  ui->click->setRange(0, 100, 10);
+  ui->click->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,
+                                       QSizePolicy::Fixed,
+                                       10, 0));
+  ui->slowKeysDelay->setRange(100, 2000, 100);
+  ui->slowKeysDelay->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,
+                                               QSizePolicy::Fixed,
+                                               10, 0));
+  ui->bounceKeysDelay->setRange(100, 2000, 100);
+  ui->bounceKeysDelay->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,
+                                                 QSizePolicy::Fixed,
+                                                 10, 0));
 
-  wtstr = i18n("If you check this option, pressing and holding down a key"
-     " emits the same character over and over again. For example,"
-     " pressing and holding down the Tab key will have the same effect"
-     " as that of pressing that key several times in succession:"
-     " Tab characters continue to be emitted until you release the key.");
-  QWhatsThis::add( repeatBox, wtstr );
+  connect(ui->repeatBox, SIGNAL(clicked()), this, SLOT(changed()));
+  connect(ui->click, SIGNAL(valueChanged(int)), this, SLOT(changed()));
+  connect(ui->numlockGroup, SIGNAL(released(int)), this, SLOT(changed()));
 
-  lay->addSpacing(10);
-  click = new KIntNumInput(100, this);
-  click->setLabel(i18n("Key click &volume:"));
-  click->setRange(0, 100, 10);
-  click->setSuffix("%");
-  click->setSteps(5,25);
-  connect(click, SIGNAL(valueChanged(int)), this, SLOT(changed()));
+  connect(ui->stickyKeys, SIGNAL(clicked()), this, SLOT(changed()));
+  connect(ui->stickyKeysLock, SIGNAL(clicked()), this, SLOT(changed()));
 
-  lay->addWidget(click);
+  connect(ui->slowKeys, SIGNAL(clicked()), this, SLOT(changed()));
+  connect(ui->slowKeysDelay, SIGNAL(valueChanged(int)), this, SLOT(changed()));
+
+  connect(ui->bounceKeys, SIGNAL(clicked()), this, SLOT(changed()));
+  connect(ui->bounceKeysDelay, SIGNAL(valueChanged(int)), this, SLOT(changed()));
 
-  wtstr = i18n("If supported, this option allows you to hear audible"
-     " clicks from your computer's speakers when you press the keys"
-     " on your keyboard. This might be useful if your keyboard"
-     " does not have mechanical keys, or if the sound that the keys"
-     " make is very soft.<p>"
-     " You can change the loudness of the key click feedback"
-     " by dragging the slider button or by clicking the up/down"
-     " arrows on the spin-button. Setting the volume to 0 % turns off"
-     " the key click.");
-  QWhatsThis::add( click, wtstr );
-  
-  numlockGroup = new QVButtonGroup( i18n( "NumLock on KDE startup" ), this );
-  ( void ) new QRadioButton( i18n( "T&urn on" ), numlockGroup );
-  ( void ) new QRadioButton( i18n( "Turn o&ff" ), numlockGroup );
-  ( void ) new QRadioButton( i18n( "Leave &unchanged" ), numlockGroup );
-  connect(numlockGroup, SIGNAL(released(int)), this, SLOT(changed()));
-  lay->addWidget( numlockGroup );
 #if !defined(HAVE_XTEST) && !defined(HAVE_XKB)
-  numlockGroup->setDisabled( true );
+  ui->numlockGroup->setDisabled( true );
 #endif
-  wtstr = i18n("If supported, this option allows you to setup"
-     " the state of NumLock after KDE startup.<p> "
-     " You can configure NumLock to be turned on or off,"
-     " or configure KDE not to set NumLock state." );
-  QWhatsThis::add( numlockGroup, wtstr );
 
-  lay->addStretch();
+//  lay->addStretch();
   load();
 }
 
 int  KeyboardConfig::getClick()
 {
-    return click->value();
+    return ui->click->value();
 }
 
 // set the slider and LCD values
 void KeyboardConfig::setRepeat(int r)
 {
-    repeatBox->setChecked(r == AutoRepeatModeOn);
+    ui->repeatBox->setChecked(r == AutoRepeatModeOn);
 }
 
 void KeyboardConfig::setClick(int v)
 {
-    click->setValue(v);
+    ui->click->setValue(v);
 }
 
 int KeyboardConfig::getNumLockState()
 {
-    QButton* selected = numlockGroup->selected();
+    QButton* selected = ui->numlockGroup->selected();
     if( selected == NULL )
         return 2;
-    int ret = numlockGroup->id( selected );
+    int ret = ui->numlockGroup->id( selected );
     if( ret == -1 )
         ret = 2;
     return ret;
@@ -126,53 +113,82 @@ int KeyboardConfig::getNumLockState()
 
 void KeyboardConfig::setNumLockState( int s )
 {
-    numlockGroup->setButton( s );
+    ui->numlockGroup->setButton( s );
 }
 
 void KeyboardConfig::load()
 {
-  KConfig *config = new KConfig("kcminputrc");
+  {
+  KConfig config("kcminputrc");
 
-    XKeyboardState kbd;
+  XKeyboardState kbd;
 
-    XGetKeyboardControl(kapp->getDisplay(), &kbd);
+  XGetKeyboardControl(kapp->getDisplay(), &kbd);
 
-    config->setGroup("Keyboard");
-    bool key = config->readBoolEntry("KeyboardRepeating", true);
-    keyboardRepeat = (key ? AutoRepeatModeOn : AutoRepeatModeOff);
-    clickVolume = config->readNumEntry("ClickVolume", kbd.key_click_percent);
-    numlockState = config->readNumEntry( "NumLock", 2 );
+  config.setGroup("Keyboard");
+  bool key = config.readBoolEntry("KeyboardRepeating", true);
+  keyboardRepeat = (key ? AutoRepeatModeOn : AutoRepeatModeOff);
+  clickVolume = config.readNumEntry("ClickVolume", kbd.key_click_percent);
+  numlockState = config.readNumEntry( "NumLock", 2 );
 
-    setClick(kbd.key_click_percent);
-    setRepeat(kbd.global_auto_repeat);
-    setNumLockState( numlockState );
+  setClick(kbd.key_click_percent);
+  setRepeat(kbd.global_auto_repeat);
+  setNumLockState( numlockState );
+  }
 
-  delete config;
+  {
+  KConfig cf("kaccessrc", true);
+
+  cf.setGroup("Keyboard");
+
+  ui->stickyKeys->setChecked(cf.readBoolEntry("StickyKeys", false));
+  ui->stickyKeysLock->setChecked(cf.readBoolEntry("StickyKeysLatch", true));
+  ui->slowKeys->setChecked(cf.readBoolEntry("SlowKeys", false));
+  ui->slowKeysDelay->setValue(cf.readNumEntry("SlowKeysDelay", 500));
+  ui->bounceKeys->setChecked(cf.readBoolEntry("BounceKeys", false));
+  ui->bounceKeysDelay->setValue(cf.readNumEntry("BounceKeysDelay", 500));
+  }
 }
 
 void KeyboardConfig::save()
 {
-  KConfig *config = new KConfig("kcminputrc");
+  {
+  KConfig config("kcminputrc");
 
-    XKeyboardControl kbd;
+  XKeyboardControl kbd;
 
-    clickVolume = getClick();
-    keyboardRepeat = repeatBox->isChecked() ? AutoRepeatModeOn : AutoRepeatModeOff;
-    numlockState = getNumLockState();
+  clickVolume = getClick();
+  keyboardRepeat = ui->repeatBox->isChecked() ? AutoRepeatModeOn : AutoRepeatModeOff;
+  numlockState = getNumLockState();
 
-    kbd.key_click_percent = clickVolume;
-    kbd.auto_repeat_mode = keyboardRepeat;
-    XChangeKeyboardControl(kapp->getDisplay(),
+  kbd.key_click_percent = clickVolume;
+  kbd.auto_repeat_mode = keyboardRepeat;
+  XChangeKeyboardControl(kapp->getDisplay(),
                            KBKeyClickPercent | KBAutoRepeatMode,
                            &kbd);
 
-    config->setGroup("Keyboard");
-    config->writeEntry("ClickVolume",clickVolume);
-    config->writeEntry("KeyboardRepeating", (keyboardRepeat == AutoRepeatModeOn));
-    config->writeEntry("NumLock", numlockState );
-    config->sync();
+  config.setGroup("Keyboard");
+  config.writeEntry("ClickVolume",clickVolume);
+  config.writeEntry("KeyboardRepeating", (keyboardRepeat == AutoRepeatModeOn));
+  config.writeEntry("NumLock", numlockState );
+  config.sync();
+  }
 
-  delete config;
+  { // access
+  KConfig cf("kaccessrc", false);
+  cf.setGroup("Keyboard");
+
+  cf.writeEntry("StickyKeys", ui->stickyKeys->isChecked());
+  cf.writeEntry("StickyKeysLatch", ui->stickyKeysLock->isChecked());
+
+  cf.writeEntry("SlowKeys", ui->slowKeys->isChecked());
+  cf.writeEntry("SlowKeysDelay", ui->slowKeysDelay->value());
+
+  cf.writeEntry("BounceKeys", ui->bounceKeys->isChecked());
+  cf.writeEntry("BounceKeysDelay", ui->bounceKeysDelay->value());
+
+  kapp->startServiceByDesktopName("kaccess");
+  }
 }
 
 void KeyboardConfig::defaults()
@@ -180,6 +196,13 @@ void KeyboardConfig::defaults()
     setClick(50);
     setRepeat(true);
     setNumLockState( 2 );
+
+    ui->stickyKeys->setChecked( false);
+    ui->stickyKeysLock->setChecked(true);
+    ui->slowKeys->setChecked(false);
+    ui->slowKeysDelay->setValue(500);
+    ui->bounceKeys->setChecked(false);
+    ui->bounceKeysDelay->setValue( 500);
 }
 
 QString KeyboardConfig::quickHelp() const
@@ -191,7 +214,7 @@ QString KeyboardConfig::quickHelp() const
      " setting these options depends upon the features provided by your"
      " keyboard hardware and the X server on which KDE is running.<p>"
      " For example, you may find that changing the key click volume"
-     " has no effect because this feature is not available on your system." */ 
+     " has no effect because this feature is not available on your system." */
 }
 
 void KeyboardConfig::changed()
@@ -203,7 +226,7 @@ void KeyboardConfig::changed()
  Originally comes from NumLockX http://dforce.sh.cvut.cz/~seli/en/numlockx
 
  NumLockX
- 
+
  Copyright (C) 2000-2001 Lubos Lunak        <l.lunak@kde.org>
  Copyright (C) 2001      Oswald Buddenhagen <ossi@kde.org>
 
@@ -254,7 +277,7 @@ int xkb_init()
         && XkbQueryExtension( qt_xdisplay(), &xkb_opcode, &xkb_event, &xkb_error,
 			       &xkb_lmaj, &xkb_lmin );
     }
-    
+
 unsigned int xkb_mask_modifier( XkbDescPtr xkb, const char *name )
     {
     int i;
@@ -286,7 +309,7 @@ unsigned int xkb_numlock_mask()
         }
     return 0;
     }
-        
+
 int xkb_set_on()
     {
     unsigned int mask;
@@ -298,7 +321,7 @@ int xkb_set_on()
     XkbLockModifiers ( qt_xdisplay(), XkbUseCoreKbd, mask, mask);
     return 1;
     }
-    
+
 int xkb_set_off()
     {
     unsigned int mask;
