@@ -30,6 +30,7 @@ DESCRIPTION
 #include <qregexp.h>
 #include <qfile.h>
 #include <qtooltip.h>
+#include <qstringlist.h>
 
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -43,6 +44,7 @@ DESCRIPTION
 #include <kwinmodule.h>
 #include <kwin.h>
 #include <ktempfile.h>
+#include <kstandarddirs.h>
 
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -305,12 +307,15 @@ void KXKBApp::setLayout(const QString &layout)
 // map from the X server into our local buffer.
 void KXKBApp::precompileLayouts()
 {
+    QStringList dirs = KGlobal::dirs()->findDirs ( "tmp", "" );
+    QString tempDir = dirs.count() == 0 ? "/tmp/" : dirs[0]; 
+
     QStringList::ConstIterator end = m_list.end();
 
     for (QStringList::ConstIterator it = m_list.begin(); it != end; ++it)
     {
         setLayout(*it);
-        QString compiledLayoutFileName = KTempFile(QString::null, ".xkm").name();
+        QString compiledLayoutFileName = tempDir + *it + ".xkm";
         m_extension->getCompiledLayout(compiledLayoutFileName);
         m_compiledLayoutFileNames[*it]  = compiledLayoutFileName;
     }
