@@ -7,6 +7,6 @@
 #endif
 
 	keys->insert( "Program:kxkb", i18n("Keyboard") );
-	DEF( I18N_NOOP("Switch To Next Keyboard Layout"), ALT+CTRL+Qt::Key_K, KKey::QtWIN+CTRL+Qt::Key_K, toggled() );
+	DEF( I18N_NOOP("Switch to Next Keyboard Layout"), ALT+CTRL+Qt::Key_K, KKey::QtWIN+CTRL+Qt::Key_K, toggled() );
 
 #undef DEF
