@@ -4,30 +4,26 @@
 #include <qstringlist.h>
 #include <qdir.h>
 
-
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <config.h>
 
+// #include <X11/Xatom.h>
+// #include <X11/Xos.h>
+#include <X11/Xlib.h>
+#include <X11/XKBlib.h>
+#include <X11/extensions/XKBrules.h>
+
 #include "rules.h"
 
-const char* X11_DIR = "/usr/X11R6/lib/X11/";
+const QString X11_DIR( "/usr/X11R6/lib/X11/" );
 
-KeyRules::KeyRules(QString rule, QString path):
+KeyRules::KeyRules(QString rule):
     _layouts(80)
 {
-  // try to load the right files
-  if (!path.isEmpty())
-    {
-      loadRules(QString("%1/%2.lst").arg(path).arg(rule));
-      loadRules(QString("%1/%2-%3.lst").arg(path).arg(rule).arg(KGlobal::locale()->language()));
-    }
-  
-  loadRules(QString("/usr/X11R6/lib/X11/xkb/rules/%1.lst").arg(rule));
-  loadRules(QString("/usr/X11R6/lib/X11/xkb/rules/%1-%2.lst").arg(rule).arg(KGlobal::locale()->language()));
-
-  loadEncodings(QString("/usr/X11R6/lib/X11/locale/locale.alias"));
+  loadRules(X11_DIR + QString("xkb/rules/%1").arg(rule));
+  loadEncodings(X11_DIR + QString("locale/locale.alias"));
 }
 
 
@@ -43,81 +39,35 @@ static struct {
 } fixedLayouts[] = {
     { "ben", "Bengali" },
     { "ar", "Arabic" },
+    { "ir", "Farsi" },
     { 0, 0 }
 };
 
-  QFile f(file);
-  if (f.open(IO_ReadOnly))
-    {
-      QTextStream ts(&f);
+  XkbRF_RulesPtr rules;
 
-      QString line;
-      bool model=false, layout=false, option=false;
-      while (!ts.eof())
-	{
-	  line = ts.readLine().stripWhiteSpace();
-
-	  if (!model && line.left(7) == "! model")
-	    {
-	      model = true;
-	      continue;
-	    }
-	  if (!layout && line.left(8) == "! layout")
-	    {
-	      layout = true;
-	      continue;
-	    }
-	  if (!option && line.left(8) == "! option")
-	    {
-	      option = true;
-	      continue;
-	    }
-
-	  if (model)
-	    if (line.isEmpty())
-	      model = false;
-	    else
-	      {
-		int pos = line.find(QRegExp("\\s"));
-		if (pos > 0)		  
-		  {
-		    _models.remove(line.left(pos));		    
-		    _models.insert(line.left(pos), strdup(line.mid(pos).stripWhiteSpace().latin1()));
-		  }
-	      }
-	  
-	  if (layout)
-	    if (line.isEmpty())
-	      layout = false;
-	    else
-	      {
-		int pos = line.find(QRegExp("\\s"));
-		if (pos > 0)
-		  {
-		    _layouts.remove(line.left(pos));
-		    _layouts.insert(line.left(pos), strdup(line.mid(pos).stripWhiteSpace().latin1()));
-		  }
-	      }
-
-	  if (option)
-	    if (line.isEmpty())
-	      option = false;
-	    else
-	      {
-		int pos = line.find(QRegExp("\\s"));
-		if (pos > 0)
-		  {
-		    _options.remove(line.left(pos));
-		    _options.insert(line.left(pos), strdup(line.mid(pos).stripWhiteSpace().latin1()));
-		  }
-	      }
-	}
-
-      f.close();
-    }
+  rules = XkbRF_Load(QFile::encodeName(file).data(), KGlobal::locale()->language().utf8().data(), true, true);
+  
+  if (rules == NULL)
+  {
+     kdDebug() << "Unable to load rules" << endl;
+     return;
+  }
+  
+  int i;
+  for (i = 0; i < rules->models.num_desc; ++i)
+      _models.replace(rules->models.desc[i].name, qstrdup( rules->models.desc[i].desc ) );
+  for (i = 0; i < rules->layouts.num_desc; ++i)
+      _layouts.replace(rules->layouts.desc[i].name, qstrdup( rules->layouts.desc[i].desc ) );
+  for (i = 0; i < rules->options.num_desc; ++i)
+      _options.replace(rules->options.desc[i].name, qstrdup( rules->options.desc[i].desc ) );
+  
+  XkbRF_Free(rules, true);
+  
+  // Knowing which variants we have won't help us
+  // We want to know which particular variants are available for each language
 
   for(int i=0; fixedLayouts[i].layout != 0; i++ ) {
-// shall we replace or skip when exists
+      // shall we replace or skip when exists
       _layouts.replace(fixedLayouts[i].locale, fixedLayouts[i].layout);
   }
 }
@@ -129,13 +79,14 @@ void KeyRules::loadEncodings(QString file)
 static struct {
     const char * locale;
     const char * encoding;
-    unsigned int group;
+    unsigned int initialGroup;
 } encs[] = {
     { "ar", "ISO8859-6", 1 },
     { "be", "ISO8859-1", 0 },
     { "ben", "ISO10646-1", 0 },
     { "br", "ISO8859-1", 0 },
     { "bg", "ISO8859-5", 1 },
+    { "by", "CP 1251", 1 },
     { "ca", "ISO8859-1", 0 },
     { "cs", "ISO8859-2", 0 },
     { "cz", "ISO8859-2", 0 },
@@ -147,7 +98,6 @@ static struct {
     { "el", "ISO8859-7", 1 },
     { "es", "ISO8859-1", 0 },
     { "eo", "ISO8859-3", 0 },
-    { "fa", "ISO8859-6", 1 },
     { "fi", "ISO8859-1", 0 },
     { "fr", "ISO8859-1", 0 },
     { "fr_CH", "ISO8859-1", 0 },
@@ -155,6 +105,7 @@ static struct {
     { "hu", "ISO8859-2", 0 },
     { "hr", "ISO8859-2", 0 },
     { "il", "ISO8859-8-i", 1 },
+    { "ir", "UTF-8", 1 },
     { "it", "ISO8859-1", 0 },
     { "kl", "ISO8859-1", 0 },
     { "lt", "ISO8859-13", 1 },
@@ -184,7 +135,7 @@ static struct {
       while (!ts.eof()) {
 	  line = ts.readLine().simplifyWhiteSpace();
 
-	    if (line[0] == '#' || line.isEmpty())
+	    if ( line.isEmpty() || line[0] == '#' )
 		continue;
 
 	    int pos = line.find(' ');
@@ -202,7 +153,7 @@ static struct {
   while ( encs[i].encoding != 0 ) {
       _encodings.remove(encs[i].locale);
       _encodings.insert(encs[i].locale, encs[i].encoding);
-      _group.insert(encs[i].locale, &encs[i].group);
+      _initialGroup.insert(encs[i].locale, &encs[i].initialGroup);
       i++;
   }
 }
@@ -213,7 +164,7 @@ QStringList KeyRules::rules(QString path)
   QStringList result;
 
   if (path.isEmpty())
-    path = "/usr/X11R6/lib/X11/xkb/rules";
+    path = X11_DIR + "xkb/rules";
   
   QDir dir(path);
   dir.setFilter(QDir::Files);
@@ -226,7 +177,10 @@ QStringList KeyRules::rules(QString path)
 }
 
 
-
+/* pretty simple algorithm - reads the layout file and 
+    tries to find "xkb_symbols"
+    also checks whether previous line contains "hidden" to skip it
+*/
 QStringList
 KeyRules::getVariants(const QString& layout)
 {
@@ -239,16 +193,17 @@ KeyRules::getVariants(const QString& layout)
 	
   QStringList* result = new QStringList();
 	
-  QString file(X11_DIR);
-  file.append("xkb/symbols/");
-  file.append(layout);
+  QString file = X11_DIR + "xkb/symbols/" + layout;
   QFile f(file);
   if (f.open(IO_ReadOnly))
     {
       QTextStream ts(&f);
 
       QString line;
+      QString prev_line;
+      
       while (!ts.eof()) {
+    	  prev_line = line;
 	  line = ts.readLine().simplifyWhiteSpace();
 
 	    if (line[0] == '#' || line.left(2) == "//" || line.isEmpty())
@@ -258,6 +213,9 @@ KeyRules::getVariants(const QString& layout)
 	    if (pos < 0)
 		continue;
 		
+	    if( prev_line.find("hidden") >=0 )
+		continue;
+		
 	    pos = line.find('"', pos) + 1;
 	    int pos2 = line.find('"', pos);
 	    if( pos < 0 || pos2 < 0 )
@@ -273,3 +231,34 @@ KeyRules::getVariants(const QString& layout)
 
     return *result;
 }
+
+void KeyRules::parseVariants(const QStringList& vars, QDict<char>& variants) 
+{
+  static const char* LAYOUT_PATTERN = "[a-z0-9_]*";
+  static const char* VARIANT_PATTERN = "\\([a-z0-9_]*\\)";
+  for (QStringList::ConstIterator it = vars.begin(); it != vars.end(); ++it)
+  {
+      QString varLine = (*it).stripWhiteSpace();
+      QRegExp rx(LAYOUT_PATTERN);
+      int pos = rx.search(varLine, 0);
+      int len = rx.matchedLength();
+  // check for errors
+      if( pos < 0 || len < 2 )
+        continue;
+      QString layout = varLine.mid(pos, len);
+      rx.setPattern(VARIANT_PATTERN);
+      pos = rx.search(varLine, pos+len);
+      len = rx.matchedLength();
+  // check for errors
+      if( pos < 2 || len < 3 )
+        continue;
+      QString variant_ = varLine.mid(pos+1, len-2);
+
+
+      QStringList addVars = getVariants(layout);
+      if( !variant_.isEmpty() && addVars.contains(variant_) )
+      {
+        variants.insert(layout, strdup(variant_.latin1()));
+      }
+  }
+}
