@@ -19,13 +19,13 @@
 */
 
 #include <qcombobox.h>
-#include <qlayout.h>
 #include <qpushbutton.h>
+#include <qlayout.h>
 
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kimagefilepreview.h>
 #include <krecentdocument.h>
@@ -36,7 +36,7 @@
 KonqBgndDialog::KonqBgndDialog( const QString & pixmapFile,
 				KInstance *instance )
   : KDialogBase( Plain,
-		 i18n("Select background image"),
+		 i18n("Select Background Image"),
                  Ok|Cancel,
                  Ok,
 		 0L, // no parent,
@@ -99,7 +99,7 @@ KBgndDialogPage::~KBgndDialogPage()
 {
 }
 
-void KBgndDialogPage::showSettings( QString fileName )
+void KBgndDialogPage::showSettings( const QString& fileName )
 {
   for ( int i = 1; i < m_wallBox->count(); i++ )
     {
@@ -124,24 +124,12 @@ void KBgndDialogPage::showSettings( QString fileName )
 
 void KBgndDialogPage::slotBrowse( )
 {
-    KFileDialog *dlg = new KFileDialog( QString::null, QString::null, this, "filedialog", true );
-    dlg->setCaption( i18n("Open") );
+    KURL url = KFileDialog::getImageOpenURL( QString::null, this, 
+                                             i18n("Select Image" ) );
 
-    KImageFilePreview *preview = new KImageFilePreview( dlg );
-    preview->show();
-    dlg->setPreviewWidget( preview );
-
-    dlg->exec();
-
-    KURL url = dlg->selectedURL();
-
-    delete dlg;
-
-    if (url.isEmpty() || url.isMalformed())
+    if (url.isMalformed())
       return;
 
-    KRecentDocument::add( url );
-
     if (!url.isLocalFile()) {
       KMessageBox::sorry(this, i18n("Currently only local wallpapers are allowed."));
     } else
