@@ -20,6 +20,7 @@
 #include "konq_dirpart.h"
 #include "konq_bgnddlg.h"
 #include "konq_propsview.h"
+#include "konq_settings.h"
 
 #include <kaction.h>
 #include <kdatastream.h>
@@ -27,6 +28,7 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 #include <konq_drag.h>
 #include <kparts/browserextension.h>
 #include <kurldrag.h>
@@ -34,6 +36,7 @@
 
 #include <qapplication.h>
 #include <qclipboard.h>
+#include <qfile.h>
 #include <assert.h>
 
 class KonqDirPart::KonqDirPartPrivate
@@ -162,6 +165,48 @@ void KonqDirPart::slotBackgroundImage()
     }
 }
 
+void KonqDirPart::lmbClicked( KFileItem * fileItem )
+{
+    KURL url = fileItem->url();
+    if ( !fileItem->isReadable() )
+    {
+        // No permissions or local file that doesn't exist - need to find out which
+        if ( ( !fileItem->isLocalFile() ) || QFile::exists( url.path() ) )
+        {
+            KMessageBox::error( widget(), i18n("<p>You do not have enough permissions to read <b>%1</b></p>").arg(url.prettyURL()) );
+            return;
+        }
+        KMessageBox::error( widget(), i18n("<p><b>%1</b> doesn't seem to exist anymore</p>").arg(url.prettyURL()) );
+        return;
+    }
+
+    KParts::URLArgs args;
+    fileItem->determineMimeType();
+    if ( fileItem->isMimeTypeKnown() )
+        args.serviceType = fileItem->mimetype();
+    args.trustedSource = true;
+
+    if ( fileItem->isLink() && fileItem->isLocalFile() ) // see KFileItem::run
+        url = KURL( url, fileItem->linkDest() );
+
+    if (KonqFMSettings::settings()->alwaysNewWin() && fileItem->isDir()) {
+        //args.frameName = "_blank"; // open new window
+        // We tried the other option, passing the path as framename so that
+        // an existing window for that dir is reused (like MSWindows does when
+        // the similar option is activated and the sidebar is hidden (!)).
+        // But this requires some work, including changing the framename
+        // when navigating, etc. Not very much requested yet, in addition.
+        KParts::WindowArgs wargs;
+        KParts::ReadOnlyPart* dummy;
+        emit m_extension->createNewWindow( url, args, wargs, dummy );
+    }
+    else
+    {
+        kdDebug() << "emit m_extension->openURLRequest( " << url.url() << "," << args.serviceType << ")" << endl;
+        emit m_extension->openURLRequest( url, args );
+    }
+}
+
 void KonqDirPart::mmbClicked( KFileItem * fileItem )
 {
     if ( fileItem )
@@ -182,8 +227,7 @@ void KonqDirPart::mmbClicked( KFileItem * fileItem )
     else
     {
         // MMB on background, try opening clipboard URL
-        QApplication::clipboard()->setSelectionMode( true );
-        QMimeSource *data = QApplication::clipboard()->data();
+        QMimeSource *data = QApplication::clipboard()->data(QClipboard::Selection);
         if ( data->provides("text/plain") )
         {
             QString url;
@@ -209,65 +253,52 @@ void KonqDirPart::mmbClicked( KFileItem * fileItem )
                     emit m_extension->openURLRequest( u );
             }
         }
-
     }
 }
 
-void KonqDirPart::saveNameFilter( QDataStream &stream )
+void KonqDirPart::saveState( QDataStream& stream )
 {
     stream << m_nameFilter;
 }
 
-void KonqDirPart::saveState( QDataStream &stream )
-{
-    //kdDebug(1203) << " -- void KonqDirPart::saveState( QDataStream &stream )" << endl;
-    if ( !m_findPart )
-        stream << false;
-    else
-    {
-        //kdDebug(1203) << "KonqDirPart::saveState -> saving TRUE" << endl;
-        stream << true;
-        // TODO save the kfindpart in there
-        KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( m_findPart );
-        if(m_findPart==NULL) {
-                kdDebug() << "m_findpart is null\n";
-                return;
-        }
-        if(ext==NULL) {
-                kdDebug() << "ext is null\n";
-                return;
-        }
-        else
-                ext->saveState( stream );
-    }
-}
-
-void KonqDirPart::restoreNameFilter( QDataStream &stream )
+void KonqDirPart::restoreState( QDataStream& stream )
 {
     stream >> m_nameFilter;
-    //kdDebug(1203) << "KonqDirPart::restoreNameFilter " << m_nameFilter << endl;
 }
 
-void KonqDirPart::restoreState( QDataStream &stream )
+void KonqDirPart::saveFindState( QDataStream& stream )
+{
+    if ( !m_findPart ) {
+        stream << false;
+        return;
+    }
+        
+    stream << true;
+       
+    KParts::BrowserExtension* ext = KParts::BrowserExtension::childObject( m_findPart );
+    if( !ext )
+        return;
+
+    ext->saveState( stream );
+}
+
+void KonqDirPart::restoreFindState( QDataStream& stream )
 {
-    // Warning: see comment in IconViewBrowserExtension::restoreState about order
-    //kdDebug(1203) << " -- void KonqDirPart::restoreState( QDataStream &stream )" << endl;
     bool bFindPart;
     stream >> bFindPart;
-    //kdDebug(1203) << "KonqDirPart::restoreState " << bFindPart << endl;
-    if ( bFindPart )
-    {
-        emit findOpen( this );
-        // TODO restore the kfindpart data
-        KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( m_findPart );
-        slotClear();
-        if(m_findPart==NULL)
-                kdDebug() << "\n*************\nrestore m_findpart is null\n";
-        if(ext==NULL)
-                kdDebug() << "\n*************\nrestore ext is null\n";
-        else
-                ext->restoreState( stream );
-    }
+    
+    if ( !bFindPart )
+        return;
+        
+    emit findOpen( this );
+        
+    KParts::BrowserExtension* ext = KParts::BrowserExtension::childObject( m_findPart );
+    slotClear();
+    
+    if( !ext )
+        return;
+                
+    ext->restoreState( stream );
 }
 
 void KonqDirPart::slotClipboardDataChanged()
@@ -391,6 +422,11 @@ void KonqDirPart::emitCounts( const KFileItemList & lst, bool selectionChanged )
         emit m_extension->selectionInfo( lst );
 }
 
+void KonqDirPart::emitMouseOver( const KFileItem* item )
+{
+    emit m_extension->mouseOverInfo( item );
+}
+
 void KonqDirPart::slotIconSizeToggled( bool )
 {
     //kdDebug(1203) << "KonqDirPart::slotIconSizeToggled" << endl;
@@ -467,7 +503,7 @@ bool KonqDirPart::openURL(const KURL& url)
         m_findPart = 0L;
         emit findClosed( this );
     }
-    
+
     m_url = url;
     emit aboutToOpenURL ();
 
