@@ -281,6 +281,11 @@ protected:
      */
     virtual void notifyRemove( KURL::List urls, QCString saveId );
 
+    /**
+     * @returns a list of all urls in the history.
+     */
+    virtual QStringList allURLs() const;
+
     /**
      * Does the work for @ref addPending() and @ref confirmPending().
      *
@@ -324,6 +329,11 @@ private slots:
     void slotEmitUpdated();
 
 private:
+    /**
+     * Returns whether the DCOP call we are handling was a call from us self
+     */
+    bool isSenderOfBroadcast();
+
     void clearPending();
     /**
      * a little optimization for KonqHistoryList::findEntry(),
