@@ -89,10 +89,17 @@ public:
   void setShowingDotFiles( bool show );
   bool isShowingDotFiles() const { return m_bShowDot; }
 
+  void setCaseInsensitiveSort( bool show );
+  bool isCaseInsensitiveSort() const;
+
+  void setShowingDirectoryOverlays( bool show );
+  bool isShowingDirectoryOverlays() const { return m_bShowDirectoryOverlays; }
+
   void setShowingPreview( const QString &preview, bool show );
-  bool isShowingPreview( const QString &preview ) const { return m_preview.contains(preview); }
-  bool isShowingPreview() const { return m_preview.count() > 0; }
-  const QStringList &previewSettings() const { return m_preview; }
+  void setShowingPreview( bool show );
+  bool isShowingPreview( const QString &preview ) const { return ! m_dontPreview.contains(preview); }
+  bool isShowingPreview();
+  const QStringList &previewSettings();
 
   void setBgColor( const QColor & color );
   const QColor& bgColor(QWidget * widget) const;
@@ -124,8 +131,8 @@ private:
   int m_iIconSize;
   int m_iItemTextPos;
   bool m_bShowDot;
-  bool m_bShowFolderMimeTypes; // Feature to be implemented in 3.1
-  QStringList m_preview;
+  bool m_bShowDirectoryOverlays;
+  QStringList m_dontPreview;
   QColor m_textColor;
   QColor m_bgColor;
   QString m_bgPixmapFile;
