@@ -11,6 +11,7 @@
 class KAboutData;
 class KInstance;
 class PluginBrowserExtension;
+class PluginLiveConnectExtension;
 class QLabel;
 class NSPluginInstance;
 class PluginPart;
@@ -24,8 +25,10 @@ class NSPluginCallback : public NSPluginCallbackIface
 public:
   NSPluginCallback(PluginPart *part);
 
+  ASYNC reloadPage();
   ASYNC requestURL(QString url, QString target);
   ASYNC statusMessage( QString msg );
+  QString evalJavaScript( QString script );
 
 private:
   PluginPart *_part;
@@ -61,7 +64,7 @@ class PluginCanvasWidget : public QWidget
 public:
 
   PluginCanvasWidget(QWidget *parent=0, const char *name=0)
-    : QWidget(parent,name) {};
+    : QWidget(parent,name) {}
 
 protected:
   void resizeEvent(QResizeEvent *e);
@@ -79,8 +82,12 @@ public:
              const char *name, const QStringList &args = QStringList());
   virtual ~PluginPart();
 
-  void requestURL(QCString url, QCString target);
+  void requestURL(const QString& url, const QString& target);
   void statusMessage( QString msg );
+  QString evalJavaScript( const QString& script );
+  void reloadPage();
+
+  void changeSrc(const QString& url);
 
 protected:
   virtual bool openURL(const KURL &url);
@@ -94,10 +101,32 @@ private:
   QGuardedPtr<QWidget> _widget;
   PluginCanvasWidget *_canvas;
   PluginBrowserExtension *_extension;
+  PluginLiveConnectExtension *_liveconnect;
   NSPluginCallback *_callback;
   QStringList _args;
   class NSPluginLoader *_loader;
 };
 
 
+class PluginLiveConnectExtension : public KParts::LiveConnectExtension
+{
+Q_OBJECT
+public:
+    PluginLiveConnectExtension(PluginPart* part);
+    virtual ~PluginLiveConnectExtension();
+    virtual bool put(const unsigned long, const QString &field, const QString &value);
+    virtual bool get(const unsigned long, const QString&, Type&, unsigned long&, QString&);
+    virtual bool call(const unsigned long, const QString&, const QStringList&, Type&, unsigned long&, QString&);
+
+    QString evalJavaScript( const QString & script );
+
+signals:
+    virtual void partEvent( const unsigned long objid, const QString & event, const KParts::LiveConnectExtension::ArgList & args );
+
+private:
+    QString __nsplugin;
+    PluginPart *_part;
+};
+
+
 #endif
