@@ -55,6 +55,41 @@
 
 #include "sdk/npupp.h"
 
+// provide these symbols when compiling with gcc 3.x
+
+#if defined(__GNUC__) && defined(__GNUC_MINOR__)
+#define KDE_GNUC_PREREQ(maj,min) \
+  ((__GNUC__ << 16) + __GNUC_MINOR__ >= ((maj) << 16) + (min))
+#else
+#define KDE_GNUC_PREREQ(maj,min) 0
+#endif 
+
+#if defined(__GNUC__) && KDE_GNUC_PREREQ(3,0)
+extern "C" void* __builtin_new(size_t s)
+{
+   return operator new(s);
+}
+
+extern "C" void __builtin_delete(void* p)
+{
+   operator delete(p);
+}
+
+extern "C" void* __builtin_vec_new(size_t s)
+{
+   return operator new[](s);
+}
+
+extern "C" void __builtin_vec_delete(void* p)
+{
+   operator delete[](p);
+}
+
+extern "C" void __pure_virtual()
+{
+   abort();
+}
+#endif
 
 KConfig *infoConfig = 0;
 
@@ -402,6 +437,7 @@ QStringList getSearchPaths()
         QStringList paths;
         paths.append("$HOME/.netscape/plugins");
         paths.append("/usr/local/netscape/plugins");
+        paths.append("/opt/mozilla/plugins");
         paths.append("/opt/netscape/plugins");
         paths.append("/opt/netscape/communicator/plugins");
         paths.append("/usr/lib/netscape/plugins");
