@@ -21,7 +21,7 @@
 */
 
 /****************************************************************************
-** $Id: kxt.cpp,v 1.16 2001/12/29 17:33:05 mueller Exp $
+** $Id: kxt.cpp,v 1.17 2002/08/22 16:39:59 knoll Exp $
 **
 ** Implementation of Qt extension classes for Xt/Motif support.
 **
@@ -45,6 +45,9 @@
 **
 *****************************************************************************/
 
+#include <qglobal.h>
+#if QT_VERSION < 0x030100
+
 #include <kapplication.h>
 #include <qwidget.h>
 #include <qobjectlist.h>
@@ -623,3 +626,5 @@ void KXtWidget::resizeEvent( QResizeEvent* )
 }
 
 #include "kxt.moc"
+
+#endif
