@@ -1,7 +1,7 @@
 /*
 
   kxt.h  -  Xt enabled Qt classed (derived from Qt Extension QXt)
-  
+
   Copyright (c) 2000 Stefan Schimanski <1Stein@gmx.de>
 
   This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 */
 
 /****************************************************************************
-** $Id: kxt.h,v 1.5 2000/07/19 23:27:09 sschiman Exp $
+** $Id: kxt.h,v 1.7 2002/08/22 16:39:59 knoll Exp $
 **
 ** Definition of Qt extension classes for Xt/Motif support.
 **
@@ -43,11 +43,14 @@
 ** information about the Professional Edition licensing, or see
 ** http://www.trolltech.com/qpl/ for QPL licensing information.
 **
-*****************************************************************************/ 
+*****************************************************************************/
 #ifndef KXT_H
 #define KXT_H
 
-#include <kapp.h>
+#include <qglobal.h>
+#if QT_VERSION < 0x030100
+
+#include <kapplication.h>
 #include <qwidget.h>
 #include <X11/Intrinsic.h>
 
@@ -75,7 +78,7 @@ class KXtWidget : public QWidget {
 		    bool managed);
     friend void qwidget_realize( Widget widget, XtValueMask* mask,
 				 XSetWindowAttributes* attributes );
-    
+
 public:
     KXtWidget(const char* name, Widget parent, bool managed=FALSE);
     KXtWidget(const char* name, WidgetClass widget_class,
@@ -94,3 +97,4 @@ protected:
 };
 
 #endif
+#endif
