@@ -5,6 +5,7 @@
 
   Copyright (c) 2000 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
                      Stefan Schimanski <1Stein@gmx.de>
+                2003 George Staikos <staikos@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -46,6 +47,9 @@
 #include <dcopclient.h>
 #include <kprotocolmanager.h>
 #include <klocale.h>
+#include <kglobal.h>
+#include <kprocess.h>
+#include <kstddirs.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/Composite.h>
@@ -98,7 +102,7 @@ void *g_NPN_MemAlloc(uint32 size)
 {
    void *mem = ::malloc(size);
 
-   kdDebug(1431) << "g_NPN_MemAlloc(), size=" << size << " allocated at " << mem << endl;
+   //kdDebug(1431) << "g_NPN_MemAlloc(), size=" << size << " allocated at " << mem << endl;
 
    return mem;
 }
@@ -107,14 +111,16 @@ void *g_NPN_MemAlloc(uint32 size)
 // free memory
 void g_NPN_MemFree(void *ptr)
 {
-   kdDebug(1431) << "g_NPN_MemFree() at " << ptr << endl;
+   //kdDebug(1431) << "g_NPN_MemFree() at " << ptr << endl;
    if (ptr)
      ::free(ptr);
 }
 
-uint32 g_NPN_MemFlush(uint32 /*size*/)
+uint32 g_NPN_MemFlush(uint32 size)
 {
-   kdDebug(1431) << "g_NPN_MemFlush()" << endl;
+   Q_UNUSED(size);
+   //kdDebug(1431) << "g_NPN_MemFlush()" << endl;
+   // MAC OS only..  we don't use this
    return 0;
 }
 
@@ -122,6 +128,8 @@ uint32 g_NPN_MemFlush(uint32 /*size*/)
 // redraw
 void g_NPN_ForceRedraw(NPP /*instance*/)
 {
+   // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api3.html#999401
+   // FIXME
    kdDebug(1431) << "g_NPN_ForceRedraw() [unimplemented]" << endl;
 }
 
@@ -129,6 +137,8 @@ void g_NPN_ForceRedraw(NPP /*instance*/)
 // invalidate rect
 void g_NPN_InvalidateRect(NPP /*instance*/, NPRect* /*invalidRect*/)
 {
+   // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api7.html#999503
+   // FIXME
    kdDebug(1431) << "g_NPN_InvalidateRect() [unimplemented]" << endl;
 }
 
@@ -136,6 +146,8 @@ void g_NPN_InvalidateRect(NPP /*instance*/, NPRect* /*invalidRect*/)
 // invalidate region
 void g_NPN_InvalidateRegion(NPP /*instance*/, NPRegion /*invalidRegion*/)
 {
+   // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api8.html#999528
+   // FIXME
    kdDebug(1431) << "g_NPN_InvalidateRegion() [unimplemented]" << endl;
 }
 
@@ -153,17 +165,17 @@ NPError g_NPN_GetValue(NPP /*instance*/, NPNVariable variable, void *value)
       case NPNVxtAppContext:
          *(void**)value = XtDisplayToApplicationContext(qt_xdisplay());
          return NPERR_NO_ERROR;
-#ifdef NP4
       case NPNVjavascriptEnabledBool:
-         (bool)(*value) = false; // FIXME: Let's have a talk with Harri :-)
+         *(bool*)value = true;
          return NPERR_NO_ERROR;
       case NPNVasdEnabledBool:
-         (bool)(*value) = false; // FIXME: No clue what this means...
+         // SmartUpdate - we don't do this
+         *(bool*)value = false;
          return NPERR_NO_ERROR;
-      case NPNVOfflineBool:
-         (bool)(*value) = false;
+      case NPNVisOfflineBool:
+         // Offline browsing - no thanks
+         *(bool*)value = false;
          return NPERR_NO_ERROR;
-#endif
       default:
          return NPERR_INVALID_PARAM;
    }
@@ -171,36 +183,54 @@ NPError g_NPN_GetValue(NPP /*instance*/, NPNVariable variable, void *value)
 
 
 NPError g_NPN_DestroyStream(NPP instance, NPStream* stream,
-                          NPReason /*reason*/)
+                          NPReason reason)
 {
+   // FIXME: is this correct?  I imagine it is not.  (GS)
    kdDebug(1431) << "g_NPN_DestroyStream()" << endl;
 
    NSPluginInstance *inst = (NSPluginInstance*) instance->ndata;
    inst->streamFinished( (NSPluginStream *)stream->ndata );
 
-   return NPERR_GENERIC_ERROR;
+   switch (reason) {
+   case NPRES_DONE:
+      return NPERR_NO_ERROR;
+   case NPRES_USER_BREAK:
+      // FIXME: notify the user
+   case NPRES_NETWORK_ERR:
+      // FIXME: notify the user
+   default:
+      return NPERR_GENERIC_ERROR;
+   }
 }
 
 
 NPError g_NPN_RequestRead(NPStream* /*stream*/, NPByteRange* /*rangeList*/)
 {
+   // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api16.html#999734
    kdDebug(1431) << "g_NPN_RequestRead() [unimplemented]" << endl;
 
+   // FIXME
    return NPERR_GENERIC_ERROR;
 }
 
 NPError g_NPN_NewStream(NPP /*instance*/, NPMIMEType /*type*/,
                       const char* /*target*/, NPStream** /*stream*/)
 {
+   // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api12.html#999628
    kdDebug(1431) << "g_NPN_NewStream() [unimplemented]" << endl;
 
+   // FIXME
+   // This creates a stream from the plugin to the browser of type "type" to
+   // display in "target"
    return NPERR_GENERIC_ERROR;
 }
 
 int32 g_NPN_Write(NPP /*instance*/, NPStream* /*stream*/, int32 /*len*/, void* /*buf*/)
 {
+   // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api21.html#999859
    kdDebug(1431) << "g_NPN_Write() [unimplemented]" << endl;
 
+   // FIXME
    return 0;
 }
 
@@ -210,7 +240,7 @@ NPError g_NPN_GetURL(NPP instance, const char *url, const char *target)
 {
    kdDebug(1431) << "g_NPN_GetURL: url=" << url << " target=" << target << endl;
 
-   NSPluginInstance *inst = (NSPluginInstance*) instance->ndata;
+   NSPluginInstance *inst = static_cast<NSPluginInstance*>(instance->ndata);
    inst->requestURL( QString::fromLatin1(url), QString::null,
                      QString::fromLatin1(target), 0 );
 
@@ -222,7 +252,7 @@ NPError g_NPN_GetURLNotify(NPP instance, const char *url, const char *target,
                          void* notifyData)
 {
     kdDebug(1431) << "g_NPN_GetURLNotify: url=" << url << " target=" << target << " inst=" << (void*)instance << endl;
-   NSPluginInstance *inst = (NSPluginInstance*) instance->ndata;
+   NSPluginInstance *inst = static_cast<NSPluginInstance*>(instance->ndata);
    kdDebug(1431) << "g_NPN_GetURLNotify: ndata=" << (void*)inst << endl;
    inst->requestURL( QString::fromLatin1(url), QString::null,
                      QString::fromLatin1(target), notifyData );
@@ -231,21 +261,110 @@ NPError g_NPN_GetURLNotify(NPP instance, const char *url, const char *target,
 }
 
 
-NPError g_NPN_PostURL(NPP /*instance*/, const char* /*url*/, const char* /*target*/,
-                    uint32 /*len*/, const char* /*buf*/, NPBool /*file*/)
+NPError g_NPN_PostURLNotify(NPP instance, const char* url, const char* target,
+                     uint32 len, const char* buf, NPBool file, void* notifyData)
 {
-   kdDebug(1431) << "g_NPN_PostURL() [unimplemented]" << endl;
+// http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api14.html
+   kdDebug(1431) << "g_NPN_PostURLNotify() [incomplete]" << endl;
+   kdDebug(1431) << "url=[" << url << "] target=[" << target << "]" << endl;
+   QByteArray postdata;
+   KParts::URLArgs args;
 
-   return NPERR_GENERIC_ERROR;
+   if (len == 0) {
+      return NPERR_NO_DATA;
+   }
+
+   if (file) { // buf is a filename
+      QFile f(buf);
+      if (!f.open(IO_ReadOnly)) {
+         return NPERR_FILE_NOT_FOUND;
+      }
+
+      // FIXME: this will not work because we need to strip the header out!
+      postdata = f.readAll();
+      f.close();
+   } else {    // buf is raw data
+      // First strip out the header
+      const char *previousStart = buf;
+      uint32 l;
+      bool previousCR = true;
+
+      for (l = 1;; l++) {
+         if (l == len) {
+            break;
+         }
+
+         if (buf[l-1] == '\n' || (previousCR && buf[l-1] == '\r')) {
+            if (previousCR) { // header is done!
+               if ((buf[l-1] == '\r' && buf[l] == '\n') ||
+                   (buf[l-1] == '\n' &&  buf[l] == '\r'))
+                  l++;
+               l++;
+               previousStart = &buf[l-1];
+               break;
+            }
+
+            QString thisLine = QString::fromLatin1(previousStart, &buf[l-1] - previousStart).stripWhiteSpace();
+
+            previousStart = &buf[l];
+            previousCR = true;
+
+            kdDebug(1431) << "Found header line: [" << thisLine << "]" << endl;
+            if (thisLine.startsWith("Content-Type: ")) {
+               args.setContentType(thisLine);
+            }
+         } else {
+            previousCR = false;
+         }
+      }
+
+      postdata.duplicate(previousStart, len - l + 1);
+   }
+
+   kdDebug(1431) << "Post data: " << postdata.size() << " bytes" << endl;
+#if 0
+   QFile f("/tmp/nspostdata");
+   f.open(IO_WriteOnly);
+   f.writeBlock(postdata);
+   f.close();
+#endif
+
+   if (!target || !*target) {
+      // Send the results of the post to the plugin
+      // (works by default)
+   } else if (!strcmp(target, "_current") || !strcmp(target, "_self") ||
+              !strcmp(target, "_top")) {
+      // Unload the plugin, put the results in the frame/window that the
+      // plugin was loaded in
+      // FIXME
+   } else if (!strcmp(target, "_new") || !strcmp(target, "_blank")){
+      // Open a new browser window and write the results there
+      // FIXME
+   } else {
+      // Write the results to the specified frame
+      // FIXME
+   }
+
+   NSPluginInstance *inst = static_cast<NSPluginInstance*>(instance->ndata);
+   if (inst && !inst->normalizedURL(QString::fromLatin1(url)).isNull()) {
+      inst->postURL( QString::fromLatin1(url), postdata, QString::null,
+                     QString::fromLatin1(target), notifyData, args );
+   } else {
+      // Unsupported / insecure
+      return NPERR_INVALID_URL;
+   }
+
+   return NPERR_NO_ERROR;
 }
 
 
-NPError g_NPN_PostURLNotify(NPP /*instance*/, const char* /*url*/, const char* /*target*/,
-                          uint32 /*len*/, const char* /*buf*/, NPBool /*file*/, void* /*notifyData*/)
+NPError g_NPN_PostURL(NPP instance, const char* url, const char* target,
+                    uint32 len, const char* buf, NPBool file)
 {
-   kdDebug(1431) << "g_NPN_PostURL() [unimplemented]" << endl;
+// http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api13.html
+   kdDebug(1431) << "g_NPN_PostURL()" << endl;
 
-   return NPERR_GENERIC_ERROR;
+   return g_NPN_PostURLNotify(instance, url, target, len, buf, file, 0L);
 }
 
 
@@ -288,9 +407,25 @@ void g_NPN_Version(int *plugin_major, int *plugin_minor, int *browser_major, int
 }
 
 
-void g_NPN_ReloadPlugins(NPBool /*reloadPages*/)
+void g_NPN_ReloadPlugins(NPBool reloadPages)
 {
-   kdDebug(1431) << "g_NPN_ReloadPlugins() [unimplemented]" << endl;
+   // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api15.html#999713
+   kdDebug(1431) << "g_NPN_ReloadPlugins()" << endl;
+   KProcess p;
+   p << KGlobal::dirs()->findExe("nspluginscan");
+
+   if (reloadPages) {
+      // This is the proper way, but it cannot be done because we have no
+      // handle to the caller!  How stupid!  We cannot force all konqi windows
+      // to reload - that would be evil.
+      //p.start(KProcess::Block);
+      // Let's only allow the caller to be reloaded, not everything.
+      //if (_callback)
+      //   _callback->reloadPage();
+      p.start(KProcess::DontCare);
+   } else {
+      p.start(KProcess::DontCare);
+   }
 }
 
 
@@ -298,6 +433,8 @@ void g_NPN_ReloadPlugins(NPBool /*reloadPages*/)
 JRIEnv *g_NPN_GetJavaEnv()
 {
    kdDebug(1431) << "g_NPN_GetJavaEnv() [unimplemented]" << endl;
+   // FIXME - what do these do?  I can't find docs, and even Mozilla doesn't
+   //         implement them
    return 0;
 }
 
@@ -305,15 +442,25 @@ JRIEnv *g_NPN_GetJavaEnv()
 jref g_NPN_GetJavaPeer(NPP /*instance*/)
 {
    kdDebug(1431) << "g_NPN_GetJavaPeer() [unimplemented]" << endl;
+   // FIXME - what do these do?  I can't find docs, and even Mozilla doesn't
+   //         implement them
    return 0;
 }
 
 
-NPError g_NPN_SetValue(NPP /*instance*/, NPPVariable /*variable*/, void* /*value*/)
+NPError g_NPN_SetValue(NPP /*instance*/, NPPVariable variable, void* /*value*/)
 {
    kdDebug(1431) << "g_NPN_SetValue() [unimplemented]" << endl;
-
-   return NPERR_GENERIC_ERROR;
+   switch (variable) {
+   case NPPVpluginWindowBool:
+      // FIXME
+      // If true, the plugin is windowless.  If false, it is in a window.
+   case NPPVpluginTransparentBool:
+      // FIXME
+      // If true, the plugin is displayed transparent
+   default:
+      return NPERR_GENERIC_ERROR;
+   }
 }
 
 
@@ -322,6 +469,21 @@ NPError g_NPN_SetValue(NPP /*instance*/, NPPVariable /*variable*/, void* /*value
 
 /******************************************************************/
 
+void
+NSPluginInstance::forwarder(Widget w, XtPointer cl_data, XEvent * event, Boolean * cont)
+{
+  Q_UNUSED(w);
+  NSPluginInstance *inst = (NSPluginInstance*)cl_data;
+  *cont = True;
+  if (inst->_area == 0 || event->xkey.window == XtWindow(inst->_area))
+    return;
+  *cont = False;
+  event->xkey.window = XtWindow(inst->_area);
+  event->xkey.subwindow = None;
+  XtDispatchEvent(event);
+}
+
+
 NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
                                    KLibrary *handle, int width, int height,
                                    QString src, QString /*mime*/,
@@ -330,6 +492,7 @@ NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
                                    QObject *parent, const char* name )
    : QObject( parent, name ), DCOPObject()
 {
+    Q_UNUSED(embed);
    _visible = false;
    _npp = privateData;
    _npp->ndata = this;
@@ -355,6 +518,12 @@ NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
    kdDebug(1431) << "pdata = " << _npp->pdata << endl;
    kdDebug(1431) << "ndata = " << _npp->ndata << endl;
 
+   if (width == 0)
+      width = 1600;
+
+   if (height == 0)
+      height = 1200;
+
    // create drawing area
    Arg args[5];
    Cardinal nargs=0;
@@ -378,9 +547,16 @@ NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
    XtRealizeWidget(_form);
 
    // Create widget that is passed to the plugin
+   XtInitializeWidgetClass(xmDrawingAreaWidgetClass);
    _area = XmCreateDrawingArea( _form, (char*)("drawingArea"), args, nargs);
    XtRealizeWidget(_area);
    XtMapWidget(_area);
+   
+   // Register forwarder
+   XtAddEventHandler(_toplevel, (KeyPressMask|KeyReleaseMask), 
+                     False, forwarder, (XtPointer)this );
+   XtAddEventHandler(_form, (KeyPressMask|KeyReleaseMask), 
+                     False, forwarder, (XtPointer)this );
 }
 
 NSPluginInstance::~NSPluginInstance()
@@ -398,6 +574,8 @@ void NSPluginInstance::destroy()
         kdDebug(1431) << "delete streams" << endl;
         _waitingRequests.clear();
 
+	shutdown();
+
         for( NSPluginStreamBase *s=_streams.first(); s!=0; ) {
             NSPluginStreamBase *next = _streams.next();
             s->stop();
@@ -429,9 +607,16 @@ void NSPluginInstance::destroy()
         if (saved)
           g_NPN_MemFree(saved);
 
+        XtRemoveEventHandler(_form, (KeyPressMask|KeyReleaseMask), 
+                             False, forwarder, (XtPointer)this);
+        XtRemoveEventHandler(_toplevel, (KeyPressMask|KeyReleaseMask), 
+                             False, forwarder, (XtPointer)this);
         XtDestroyWidget(_area);
+	_area = 0;
         XtDestroyWidget(_form);
+	_form = 0;
         XtDestroyWidget(_toplevel);
+	_toplevel = 0;
 
         ::free(_npp);   // matched with malloc() in newInstance
 
@@ -480,7 +665,7 @@ void NSPluginInstance::timer()
             url = req.url;
 
         // non empty target = frame target
-        if ( !req.target.isEmpty() )
+        if ( !req.target.isEmpty())
         {
             if (_callback)
             {
@@ -493,9 +678,20 @@ void NSPluginInstance::timer()
             {
                 kdDebug(1431) << "Starting new stream " << req.url << endl;
 
-                // hack to get java vm and HyperCosm 3d working
-                if ( url.lower()=="javascript:document.location" ||
-                     url.lower()=="javascript:window.location.href" ) {
+                if (req.post) {
+                    // create stream
+                    NSPluginStream *s = new NSPluginStream( this );
+                    connect( s, SIGNAL(finished(NSPluginStreamBase*)),
+                             SLOT(streamFinished(NSPluginStreamBase*)) );
+                    _streams.append( s );
+
+                    kdDebug() << "posting to " << url << endl;
+
+                    emitStatus( i18n("Submitting data to %1").arg(url) );
+                    s->post( url, req.data, req.mime, req.notify, req.args );
+                } else if (url.lower().startsWith("javascript:document.location") ||
+                     url.lower().startsWith("javascript:window.location.href")) {
+                    // hack to get java vm and HyperCosm 3d working
                     NSPluginBufStream *s = new NSPluginBufStream( this );
                     connect( s, SIGNAL(finished(NSPluginStreamBase*)),
                              SLOT(streamFinished(NSPluginStreamBase*)) );
@@ -504,6 +700,12 @@ void NSPluginInstance::timer()
                     QByteArray buf;
                     buf.setRawData( _baseURL.latin1(), _baseURL.length()+1 );
                     s->get( url, "text/html", buf, req.notify, true );
+                } else if (url.lower().startsWith("javascript:history.back")){
+                    if (_callback) {
+                        _callback->requestURL( url, req.target );
+                        if ( req.notify )
+                            NPURLNotify( req.url, NPRES_DONE, req.notify );
+                    }
                 } else {
                     // create stream
                     NSPluginStream *s = new NSPluginStream( this );
@@ -524,14 +726,54 @@ void NSPluginInstance::timer()
 }
 
 
+QString NSPluginInstance::normalizedURL(const QString& url) const {
+    KURL inURL(_baseURL, url);
+
+    if (inURL.protocol() == "http" ||
+        inURL.protocol() == "https" ||
+        inURL.protocol() == "javascript") {
+        return inURL.url();
+    }
+
+    // Allow: javascript:, http, https, or no protocol (match loading)
+    kdDebug(1431) << "NSPluginInstance::normalizedURL - I don't think so.  http or https only!" << endl;
+    return QString::null;
+}
+
+
 void NSPluginInstance::requestURL( const QString &url, const QString &mime,
                                    const QString &target, void *notify )
 {
-    kdDebug(1431) << "NSPluginInstance::requestURL url=" << url << " target=" <<
-        target << " notify=" << notify << endl;
-    _waitingRequests.enqueue( new Request( url, mime, target, notify ) );
-    if ( _streams.count()==0 )
+    // Generally this should already be done, but let's be safe for now.
+    QString nurl = normalizedURL(url);
+    if (nurl.isNull()) {
+        return;
+    }
+
+    kdDebug(1431) << "NSPluginInstance::requestURL url=" << nurl << " target=" << target << " notify=" << notify << endl;
+    _waitingRequests.enqueue( new Request( nurl, mime, target, notify ) );
+    if ( _streams.count() == 0 ) {
         _timer->start( 0, true );
+    }
+}
+
+
+void NSPluginInstance::postURL( const QString &url, const QByteArray& data,
+                                const QString &mime,
+                                const QString &target, void *notify,
+                                const KParts::URLArgs& args )
+{
+    // Generally this should already be done, but let's be safe for now.
+    QString nurl = normalizedURL(url);
+    if (nurl.isNull()) {
+        return;
+    }
+
+    kdDebug(1431) << "NSPluginInstance::postURL url=" << nurl << " target=" << target << " notify=" << notify << endl;
+    _waitingRequests.enqueue( new Request( nurl, data, mime, target, notify, args) );
+    if ( _streams.count() == 0 ) {
+        _timer->start( 0, true );
+    }
 }
 
 
@@ -591,11 +833,29 @@ int NSPluginInstance::setWindow(int remove)
 }
 
 
+static void resizeWidgetTree(Window w, int width, int height) {
+   Window rroot, parent, *children;
+   unsigned int nchildren = 0;
+
+   if (XQueryTree(qt_xdisplay(), w, &rroot, &parent, &children, &nchildren)) {
+      for (unsigned int i = 0; i < nchildren; i++) {
+         XResizeWindow(qt_xdisplay(), children[i], width, height);
+         resizeWidgetTree(children[i], width, height);
+      }
+      XFree(children);
+   }
+
+}
+
+
 void NSPluginInstance::resizePlugin(int w, int h)
 {
    if (!_visible)
       return;
 
+   if (w == _width && h == _height)
+      return;
+
    kdDebug(1431) << "-> NSPluginInstance::resizePlugin( w=" << w << ", h=" << h << " ) " << endl;
 
    _width = w;
@@ -609,6 +869,8 @@ void NSPluginInstance::resizePlugin(int w, int h)
    XtSetValues(_form, args, nargs);
    XtSetValues(_area, args, nargs);
 
+   resizeWidgetTree(XtWindow(_area), _width, _height);
+
    setWindow();
 
    kdDebug(1431) << "<- NSPluginInstance::resizePlugin" << endl;
@@ -890,7 +1152,6 @@ NSPluginClass::~NSPluginClass()
     _instances.clear();
     _trash.clear();
     shutdown();
-    //KLibLoader::self()->unloadLibrary( QFile::encodeName(libname) );
     if (_handle)
       _handle->unload();
 }
@@ -956,6 +1217,7 @@ QString NSPluginClass::getMIMEDescription()
 
 void NSPluginClass::shutdown()
 {
+    kdDebug(1431) << "NSPluginClass::shutdown error=" << _error << endl;
     if( _NP_Shutdown && !_error )
         _NP_Shutdown();
 }
@@ -975,8 +1237,8 @@ DCOPRef NSPluginClass::newInstance( QString url, QString mimeType, bool embed,
    char **_argn = new char*[argc];
    char **_argv = new char*[argc];
    QString src = url;
-   int width = 1600;
-   int height = 1200;
+   int width = 0;
+   int height = 0;
    QString baseURL = url;
 
    for (unsigned int i=0; i<argc; i++)
@@ -1001,6 +1263,7 @@ DCOPRef NSPluginClass::newInstance( QString url, QString mimeType, bool embed,
                                            // malloc here, just to be safe,
                                            // since the nsplugin plays with
                                            // this thing
+   memset(npp, 0, sizeof(NPP_t));
    npp->ndata = NULL;
 
    // Create plugin instance object
@@ -1039,7 +1302,7 @@ void NSPluginClass::destroyInstance( NSPluginInstance* inst )
 {
     // mark for destruction
     _trash.append( inst );
-    _timer->start( 0, TRUE );
+    timer(); //_timer->start( 0, TRUE );
 }
 
 
@@ -1056,11 +1319,16 @@ NSPluginStreamBase::~NSPluginStreamBase()
 {
    if (_stream) {
       _instance->NPDestroyStream( _stream, NPRES_USER_BREAK );
+      if (_stream && _stream->url)
+          free(const_cast<char*>(_stream->url));
       delete _stream;
+      _stream = 0;
    }
 
    delete _tempFile;
+   _tempFile = 0;
    delete _queue;
+   _queue = 0;
 }
 
 
@@ -1113,7 +1381,7 @@ void NSPluginStreamBase::inform()
 
 }
 
-bool NSPluginStreamBase::create( QString url, QString mimeType, void *notify )
+bool NSPluginStreamBase::create( const QString& url, const QString& mimeType, void *notify )
 {
     if ( _stream )
         return false;
@@ -1182,7 +1450,7 @@ int NSPluginStreamBase::process( const QByteArray &data, int start )
 
 bool NSPluginStreamBase::pump()
 {
-    kdDebug(1431) << "queue pos " << _queuePos << ", size " << _queue.size() << endl;
+    //kdDebug(1431) << "queue pos " << _queuePos << ", size " << _queue.size() << endl;
 
     inform();
 
@@ -1215,15 +1483,15 @@ bool NSPluginStreamBase::pump()
 
 void NSPluginStreamBase::queue( const QByteArray &data )
 {
-    kdDebug(1431) << "new queue size " << data.size() << endl;
-    kdDebug(1431) << "data=" << (void*)data.data() << " size=" << data.size() << endl;
-
     _queue = data;
     _queue.detach();
     _queuePos = 0;
     _tries = 0;
 
-    kdDebug(1431) << "queue=" << (void*)_queue.data() << " size=" << _queue.size() << endl;
+    kdDebug(1431) << "new queue size=" << data.size()
+                  << " data=" << (void*)data.data() 
+                  << " queue=" << (void*)_queue.data() << " qsize="
+                  << _queue.size() << endl;
 }
 
 
@@ -1264,6 +1532,8 @@ void NSPluginStreamBase::finish( bool err )
     }
 
     // delete stream
+    if (_stream && _stream->url)
+        free(const_cast<char *>(_stream->url));
     delete _stream;
     _stream = 0;
 
@@ -1288,8 +1558,9 @@ NSPluginBufStream::~NSPluginBufStream()
 }
 
 
-bool NSPluginBufStream::get( QString url, QString mimeType, const QByteArray &buf,
-                             void *notifyData, bool singleShot )
+bool NSPluginBufStream::get( const QString& url, const QString& mimeType,
+                             const QByteArray &buf, void *notifyData,
+                             bool singleShot )
 {
     _singleShot = singleShot;
     if ( create( url, mimeType, notifyData ) ) {
@@ -1334,7 +1605,8 @@ NSPluginStream::~NSPluginStream()
 }
 
 
-bool NSPluginStream::get( QString url, QString mimeType, void *notify )
+bool NSPluginStream::get( const QString& url, const QString& mimeType,
+                          void *notify )
 {
     // create new stream
     if ( create( url, mimeType, notify ) ) {
@@ -1353,6 +1625,27 @@ bool NSPluginStream::get( QString url, QString mimeType, void *notify )
 }
 
 
+bool NSPluginStream::post( const QString& url, const QByteArray& data, 
+           const QString& mimeType, void *notify, const KParts::URLArgs& args )
+{
+    // create new stream
+    if ( create( url, mimeType, notify ) ) {
+        // start the kio job
+        _job = KIO::http_post(url, data, false);
+        _job->addMetaData("content-type", args.contentType());
+        connect(_job, SIGNAL(data(KIO::Job *, const QByteArray &)),
+                SLOT(data(KIO::Job *, const QByteArray &)));
+        connect(_job, SIGNAL(result(KIO::Job *)), SLOT(result(KIO::Job *)));
+        connect(_job, SIGNAL(totalSize(KIO::Job *, KIO::filesize_t )),
+                SLOT(totalSize(KIO::Job *, KIO::filesize_t)));
+        connect(_job, SIGNAL(mimetype(KIO::Job *, const QString &)),
+                SLOT(mimetype(KIO::Job *, const QString &)));
+    }
+
+    return false;
+}
+
+
 void NSPluginStream::data(KIO::Job * job, const QByteArray &data)
 {
     kdDebug(1431) << "NSPluginStream::data - job=" << (void*)job << " data size=" << data.size() << endl;
